@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -80,15 +80,6 @@ SetupCovWeighting(CdsArray *cdsA)
 
     if (cdsA->tmpmatKK2 == NULL)
         cdsA->tmpmatKK2 = MatAlloc(vlen, vlen);
-
-    if (cdsA->tmpmatK3a == NULL)
-        cdsA->tmpmatK3a = MatAlloc(vlen, 3);
-
-    if (cdsA->tmpmatK3b == NULL)
-        cdsA->tmpmatK3b = MatAlloc(vlen, 3);
-
-    if (cdsA->tmpmat3K == NULL)
-        cdsA->tmpmat3K = MatAlloc(3, vlen);
 }
 
 
@@ -96,33 +87,36 @@ SetupCovWeighting(CdsArray *cdsA)
 int
 CheckZeroVariances(CdsArray *cdsA)
 {
-    Algorithm      *algo = cdsA->algo;
     int             i, zeroflag = 1;
 
-    if (algo->varweight != 0)
+    if (algo->varweight)
     {
         for (i = 0; i < cdsA->vlen; ++i)
             if (cdsA->var[i] > DBL_EPSILON)
                 zeroflag = 0;
     }
-    else if (algo->covweight != 0)
+    else if (algo->covweight)
     {
         for (i = 0; i < cdsA->vlen; ++i)
             if (cdsA->CovMat[i][i] > DBL_EPSILON)
                 zeroflag = 0;
     }
+    else if (algo->leastsquares)
+    {
+        zeroflag = 0;
+    }
 
     return(zeroflag);
 
-/*     if (zeroflag == 1) */
+/*     if (zeroflag) */
 /*     { */
-/*         double var = cdsA->stats->wRMSD_from_mean * cdsA->stats->wRMSD_from_mean; */
+/*         double var = stats->wRMSD_from_mean * stats->wRMSD_from_mean; */
 /*  */
-/*      if (algo->varweight != 0) */
+/*      if (algo->varweight) */
 /*      { */
 /*          memsetd(cdsA->var, var, cdsA->vlen); */
 /*      } */
-/*      else if (algo->covweight != 0) */
+/*      else if (algo->covweight) */
 /*      { */
 /*          for (i = 0; i < cdsA->vlen; ++i) */
 /*              cdsA->CovMat[i][i] = var; */
@@ -135,88 +129,42 @@ void
 CalcBfactC(CdsArray *cdsA)
 {
     int         i, j;
-    double      trBS, occsum;
+    double      trBS, nusum;
 
     for (i = 0; i < cdsA->cnum; ++i)
     {
-        trBS = occsum = 0.0;
+        trBS = nusum = 0.0;
         for (j = 0; j < cdsA->vlen; ++j)
         {
-            if (cdsA->cds[i]->o[j] > 0)
+            if (cdsA->cds[i]->nu[j])
             {
-                occsum += 1.0;
+                nusum += 1;
                 trBS += cdsA->cds[i]->prvar[j] / cdsA->var[j];
                 /*printf("trBS[%d] = % f\n", j, cdsA->cds[i]->prvar[j] / cdsA->var[j]);*/
             }
         }
 
-        cdsA->cds[i]->bfact_c = occsum / trBS;
+        cdsA->cds[i]->bfact_c = nusum / trBS;
         /*printf("bfact_c[%d] = % f\n", i, cdsA->cds[i]->bfact_c);*/
     }
 }
 
 
-/* Weighting by dimensional, axial Xi covariance matrix, here diagonal. */
 /* Holding the superposition constant, calculates the covariance
-   matrices and corresponding weight matrices, looping till 
+   matrices and corresponding weight matrices, looping till
    convergence. */
 void
 CalcCovariances(CdsArray *cdsA)
 {
-    Algorithm      *algo = cdsA->algo;
-
-	if (algo->varweight != 0 || algo->leastsquares != 0)
-	{
-		if (algo->alignment == 1)
-			VarianceCdsOcc(cdsA);
-		else
-			VarianceCds(cdsA);
-	}
-	else if (algo->covweight != 0)
-		CalcCovMat(cdsA);
-}
-
-
-void
-MVCovMat(CdsArray *cdsA)
-{
-    int             i, j;
-    const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const double    idf = 1.0 / (double)(cnum * vlen);
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    const Cds   *cdsi;
-    double        **MVCovMat = NULL;
-
-    if (cdsA->MVCovMat == NULL)
-        MVCovMat = cdsA->MVCovMat = MatAlloc(3, 3);
-    else
-        MVCovMat = cdsA->MVCovMat;
-
-    for (i = 0; i < 3; ++i)
-        for (j = 0; j < 3; ++j)
-            MVCovMat[i][j] = 0.0;
-
-    for (i = 0; i < cnum; ++i)
+    if (algo->varweight || algo->leastsquares)
     {
-        for (j = 0; j < vlen; ++j)
-        {
-            cdsi = (Cds *) cds[i];
-            MVCovMat[0][0] += mysquare(cdsi->residual_x[j]);
-            MVCovMat[1][1] += mysquare(cdsi->residual_y[j]);
-            MVCovMat[2][2] += mysquare(cdsi->residual_z[j]);
-            MVCovMat[0][1] += cdsi->residual_x[j] * cdsi->residual_y[j];
-            MVCovMat[0][2] += cdsi->residual_x[j] * cdsi->residual_z[j];
-            MVCovMat[1][2] += cdsi->residual_y[j] * cdsi->residual_z[j];
-        }
+        if (algo->alignment)
+            VarianceCdsNu(cdsA);
+        else
+            VarianceCds(cdsA);
     }
-
-    MVCovMat[1][0] = MVCovMat[0][1];
-    MVCovMat[2][0] = MVCovMat[0][2];
-    MVCovMat[2][1] = MVCovMat[1][2];
-
-    for (i = 0; i < 3; ++i)
-        for (j = 0; j < 3; ++j)
-            MVCovMat[i][j] *= idf;
+    else if (algo->covweight)
+        CalcCovMat(cdsA);
 }
 
 
@@ -224,13 +172,14 @@ void
 CalcCovMat(CdsArray *cdsA)
 {
     double          newx1, newy1, newz1, newx2, newy2, newz2;
+    double          avexi, aveyi, avezi, avexj, aveyj, avezj;
     double          covsum;
-    double         *cdskx, *cdsky, *cdskz;
+    double         *cdskx = NULL, *cdsky = NULL, *cdskz = NULL;
     int             i, j, k;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     const double    normalize = 1.0 / (3.0 * cnum);
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    const Cds   *cdsk;
+    const Cds     **cds = (const Cds **) cdsA->cds;
+    const Cds      *cdsk = NULL;
     double        **CovMat = cdsA->CovMat;
     const double   *avex = (const double *) cdsA->avecds->x,
                    *avey = (const double *) cdsA->avecds->y,
@@ -246,28 +195,36 @@ CalcCovMat(CdsArray *cdsA)
        based upon current superposition, put in CovMat */
     for (i = 0; i < vlen; ++i)
     {
+        avexi = avex[i];
+        aveyi = avey[i];
+        avezi = avez[i];
+
         for (j = 0; j <= i; ++j)
         {
+            avexj = avex[j];
+            aveyj = avey[j];
+            avezj = avez[j];
+
             covsum = 0.0;
             for (k = 0; k < cnum; ++k)
             {
-                cdsk = cds[k];
+                cdsk  = cds[k];
                 cdskx = cdsk->x;
                 cdsky = cdsk->y;
                 cdskz = cdsk->z;
 
-                newx1 = cdskx[i] - avex[i];
-                newy1 = cdsky[i] - avey[i];
-                newz1 = cdskz[i] - avez[i];
+                newx1 = cdskx[i] - avexi;
+                newy1 = cdsky[i] - aveyi;
+                newz1 = cdskz[i] - avezi;
 
-                newx2 = cdskx[j] - avex[j];
-                newy2 = cdsky[j] - avey[j];
-                newz2 = cdskz[j] - avez[j];
+                newx2 = cdskx[j] - avexj;
+                newy2 = cdsky[j] - aveyj;
+                newz2 = cdskz[j] - avezj;
 
                 #ifdef FP_FAST_FMA
                 covsum += fma(newx1, newx2, fma(newy1, newy2, newz1 * newz2));
                 #else
-                covsum += (newx1 * newx2 + newy1 * newy2 + newz1 * newz2);
+                covsum += newx1 * newx2 + newy1 * newy2 + newz1 * newz2;
                 #endif
             }
 
@@ -280,22 +237,23 @@ CalcCovMat(CdsArray *cdsA)
 }
 
 
-/* Same as CalcCovMat() but weights by the occupancies */
+/* Same as CalcCovMat() but weights by the nu missing flag */
 void
-CalcCovMatOcc(CdsArray *cdsA)
+CalcCovMatNu(CdsArray *cdsA)
 {
     double          newx1, newy1, newz1, newx2, newy2, newz2;
     double          covsum;
-    double         *cdskx, *cdsky, *cdskz;
+    double         *cdskx = NULL, *cdsky = NULL, *cdskz = NULL;
     int             i, j, k;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    const Cds   *cdsk;
+    const Cds     **cds = (const Cds **) cdsA->cds;
+    const Cds      *cdsk = NULL;
     double        **CovMat = cdsA->CovMat;
     const double   *avex = (const double *) cdsA->avecds->x,
                    *avey = (const double *) cdsA->avecds->y,
                    *avez = (const double *) cdsA->avecds->z;
-    double         *occ, osum;
+    int            *nu = NULL;
+    double          nusum;
 
     if (cdsA->CovMat == NULL)
     {
@@ -309,11 +267,11 @@ CalcCovMatOcc(CdsArray *cdsA)
     {
         for (j = 0; j <= i; ++j)
         {
-            covsum = osum = 0.0;
+            covsum = nusum = 0.0;
             for (k = 0; k < cnum; ++k)
             {
                 cdsk = cds[k];
-                occ = cdsk->o;
+                nu = cdsk->nu;
                 cdskx = cdsk->x;
                 cdsky = cdsk->y;
                 cdskz = cdsk->z;
@@ -326,14 +284,14 @@ CalcCovMatOcc(CdsArray *cdsA)
                 newy2 = cdsky[j] - avey[j];
                 newz2 = cdskz[j] - avez[j];
 
-                covsum += occ[i] * occ[j] * 
+                covsum += nu[i] * nu[j] *
                           (newx1 * newx2 + newy1 * newy2 + newz1 * newz2);
 
-                osum += occ[i] * occ[j];
+                nusum += nu[i] * nu[j];
             }
 
-            if (osum > 0.0)
-                CovMat[i][j] = CovMat[j][i] = covsum / osum; /* sample variance, ML biased not n-1 definition */
+            if (nusum > 0)
+                CovMat[i][j] = CovMat[j][i] = covsum / nusum; /* sample variance, ML biased not n-1 definition */
             else
                 CovMat[i][j] = CovMat[j][i] = 0.0;
         }
@@ -341,46 +299,6 @@ CalcCovMatOcc(CdsArray *cdsA)
 }
 
 
-void
-CalcStructCovMat(CdsArray *cdsA)
-{
-    double          invdf, cov_sum;
-    int             i, j, k;
-    const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    const Cds   *cdsi = NULL, *cdsj = NULL;
-    double        **SCovMat = NULL;
-
-    invdf = 1.0 / (double) vlen; /* ML, biased */
-
-    if (cdsA->SCovMat == NULL)
-        cdsA->SCovMat = MatAlloc(cnum, cnum);
-    else
-        memset(&cdsA->SCovMat[0][0], 0, cnum * cnum * sizeof(double));
-
-    SCovMat = cdsA->SCovMat;
-
-    /* calculate covariance matrix of structures across atoms, put in SCovMat */
-    for (i = 0; i < cnum; ++i)
-    {
-        for (j = 0; j < cnum; ++j)
-        {
-            cov_sum = 0.0;
-            for (k = 0; k < vlen; ++k)
-            {
-                cdsi = cds[i];
-                cdsj = cds[j];
-                cov_sum += cdsi->x[k] * cdsj->x[k];
-                cov_sum += cdsi->y[k] * cdsj->y[k];
-                cov_sum += cdsi->z[k] * cdsj->z[k];
-            }
-
-            SCovMat[i][j] = cov_sum * invdf; /* sample variance, ML biased not n-1 definition */
-        }
-    }
-}
-
-
 void
 CalcFullCovMat(CdsArray *cdsA)
 {
@@ -392,12 +310,13 @@ CalcFullCovMat(CdsArray *cdsA)
                    *avez = (const double *) cdsA->avecds->z;
     const int       vlen = cdsA->vlen, cnum = cdsA->cnum;
     int             i, j, k, m, n, p, q0, q1, q2;
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    Cds         *cdsk;
+    const Cds     **cds = (const Cds **) cdsA->cds;
+    Cds            *cdsk = NULL;
 
     invdf = 1.0 / (double) cnum; /* ML, biased */
 
-    AveCds(cdsA);
+    if (algo->doave)
+        AveCds(cdsA);
 
     if (FullCovMat == NULL)
         FullCovMat = cdsA->FullCovMat = MatAlloc(3 * cdsA->vlen, 3 * cdsA->vlen);
@@ -454,37 +373,7 @@ CalcFullCovMat(CdsArray *cdsA)
 }
 
 
-/* calculate covariance matrix weighted cds
-   \Sigma^-1 * \CdsMat */
-void
-CalcCovCds(Cds *cds, const double **covmat)
-{
-    int             i, k;
-    double         *covx = cds->covx,
-                   *covy = cds->covy,
-                   *covz = cds->covz;
-    const double   *x = (const double *) cds->x,
-                   *y = (const double *) cds->y,
-                   *z = (const double *) cds->z;
-    double          covmatik;
-
-    for (i = 0; i < cds->vlen; ++i)
-    {
-        covx[i] = covy[i] = covz[i] = 0.0;
-
-        for (k = 0; k < cds->vlen; ++k)
-        {
-            covmatik = covmat[i][k];
-
-            covx[i] += (covmatik * x[k]);
-            covy[i] += (covmatik * y[k]);
-            covz[i] += (covmatik * z[k]);
-        }
-    }
-}
-
-
-/* Normalize the covariance matrix to form the correlation matrix 
+/* Normalize the covariance matrix to form the correlation matrix
    by dividing each element by the square root of the product of the
    corresponding diagonal elements.
    This makes a pearson correlation matrix.
@@ -519,37 +408,6 @@ CorMat2CovMat(double **CovMat, const double *vars, const int size)
 }
 
 
-/* Normalizes a covariance matrix by dividing every cell by the 
-   average variance */
-double
-NormalizeCovMat(double **mat, const int size)
-{
-    int             i, j;
-    double          normalize;
-
-    normalize = 0.0;
-    for (i = 0; i < size; ++i)
-        normalize += mat[i][i];
-
-    normalize = size / normalize;
-
-/*     normalize = 0.0; */
-/*     for (i = 0; i < size; ++i) */
-/*         for (j = 0; j < size; ++j) */
-/*             normalize += mat[i][j]; */
-/*     normalize = (double) size / normalize; */
-
-    for (i = 0; i < size; ++i)
-        for (j = 0; j < size; ++j)
-            mat[i][j] *= normalize;
-
-    /* fprintf(stderr, "\n     Mat[%3d][%3d] = %12.5f", size/2, size/2, mat[size/2][size/2]); */
-/*     fprintf(stderr, "\n     norm = %12.5f", normalize); */
-/*     fflush(NULL); */
-    return(normalize);
-}
-
-
 void
 PrintCovMat(CdsArray *cdsA)
 {
