@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,24 +37,6 @@
 #define BUFFLEN          FILENAME_MAX
 
 
-#if defined(__APPLE__)
-    #if !defined(inline) 
-        #define inline __inline__ 
-    #endif 
-    #include <CoreServices/CoreServices.h>
-    #include <time.h>
-    #include <sys/time.h>
-    #include <sys/resource.h>
-    #include <sys/types.h>
-    #include <mach/mach_time.h>
-
-    UInt64
-    getTime(void);
-
-    double
-    seconds(void);
-#endif
-
 double
 *memsetd(double *dest, const double val, size_t len);
 
