@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,38 +38,17 @@ VariancesEDMA(double *var, double **edmamat, double **distmat, const int n);
 void
 CalcLeleVariances(CdsArray *cdsA);
 
-void
-NNxCds(double **mat, Cds *cds);
-
-void
-CdsxNN(Cds *cds, const double **mat);
-
-double
-RadGyrSqr(const Cds *cds);
-
-double
-RadGyrSqrW(const Cds *cds, const double *weights);
-
-double
-RadGyrSqrCov(Cds *cds, const double **weightmat);
-
 void
 CdsInnerProd(Cds *cds);
 
 void
 CdsInnerProd2(Cds *cds);
 
-void
-MatInnerProdSymIp(double **mat, const int N);
-
-void
-MatInnerProdSymOp(double **mato, const double **mati, const int N);
-
 void
 CalcEDMADistMat(CdsArray *cdsA);
 
 void
-CalcEDMADistMatOcc(CdsArray *cdsA);
+CalcEDMADistMatNu(CdsArray *cdsA);
 
 void
 LeleCenterMat(double **mat, const int len);
@@ -81,7 +60,7 @@ void
 CalcMLDistMat(CdsArray *cdsA);
 
 void
-CalcMLDistMatOcc(CdsArray *cdsA);
+CalcMLDistMatNu(CdsArray *cdsA);
 
 void
 EmbedAveCds(CdsArray *cdsA);
