@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,4 +35,5 @@
 #include "CovMat.h"
 #include "ProcGSLSVD.h"
 #include "DLTmath.h"
-#include "Embed.h"
+#include "qcprot.h"
+
