@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,27 +39,22 @@ Expert1(void)
 {
     printf("\n");
     printf(" Default usage is equivalent to:                                                \n");
-    printf("    theseus %s-a0 -e2 -g1 -i200 -k-1 -L0 -p1e-7 -v -P0%s your.pdb               \n", tc_GREEN, tc_NC);
+    printf("    theseus %s-a0 -e2 -g1 -i200 -p1e-7 -v -P0%s your.pdb               \n", tc_GREEN, tc_NC);
     printf("\n");
     printf(" Expert options:\n");
-    printf("    -b  Bayesian reference prior on inverse gamma scale param                   \n");
     printf("    -e  embedding algorithm for initializing the average structure              \n");
     printf("          0 = none; use randomly chosen model                                   \n");
     printf("         {%s2%s} = Maximum Likelihood                                           \n", tc_GREEN, tc_NC);
     printf("    -g  hierarchical model for variances                                        \n");
     printf("          0 = none (may not converge)                                           \n");
     printf("         {%s1%s} = inverse gamma distribution                                   \n", tc_GREEN, tc_NC);
-    printf("    -k  constant minimum variance {%s-1%s}                                      \n", tc_GREEN, tc_NC);
-    printf("         {if set to negative value, min var is determined empirically}          \n");
     printf("    -J  print very expert options                                               \n");
     printf("    -n  don't write transformed pdb file                                        \n");
     printf("    -o  reference file to superimpose on,                                       \n");
     printf("         all rotations are relative to the first model in this file             \n");
-    printf("    -O  Olve's segID file                                                       \n");
     printf("    -p  requested relative precision for convergence  {%s1e-7%s}                \n", tc_GREEN, tc_NC);
     printf("    -Z  don't orient final superposition along principal axes                   \n");
     printf("    -z  n  fixed shape parameter for inverse gamma distribution                 \n");
-    printf("    -8  preserve atom names; don't try to fix them for PDB3 standards           \n");
 }
 
 
@@ -73,25 +68,21 @@ Expert2(void)
     printf("    -2  convert Lele file to PDB format                                         \n");
     printf("    -3  n:n  scale and shape params for inverse gamma for random variances      \n");
     printf("    -4  n:n:n  radius of gyration for Gaussian generated atoms                  \n");
+    printf("    -5  TenBerge algorithm for mean                                             \n");
     printf("    -6  write Bob Edgar's SSM (structure similarity matrix)                     \n");
-    printf("    -7  very specific fix for Lele's 5x5 structured covariance matrix, test data\n");
-    printf("    -8  hierarchical translations (broken)                                      \n");
     printf("    -B  read and write binary coordinate files                                  \n");
     printf("          1 = read a PDB file, write a binary of it and quit                    \n");
     printf("          2 = read a binary, superimpose, and write a PDB                       \n");
     printf("          3 = read a PDB file, superimpose, and write a binary                  \n");
     printf("          4 = read a binary, superimpose, and write a binary                    \n");
-    printf("    -d  use ML dimensional/axes covariance weighting                            \n");
     printf("    -G  full 3D coordinate PCA (vector PCA is default)                          \n");
     printf("    -H  write 3D coordinate PCA morph files (for use with CNS/XPLOR)            \n");
-    printf("    -j  # of times to bootstrap                                                 \n");
+    printf("    -j  # of landmarks for random coords generation                             \n");
     printf("    -K  n  number of mixtures for mixture Gaussian                              \n");
-    printf("    -m  Procrustes rotation method                                              \n");
     printf("    -N  do a \"null run\" -- no superposition                                   \n");
-    printf("    -Q  do PCA across models (find families of models)                          \n");
-    printf("    -q  axes variances for random structure generation (e.g. -q1:2:3)           \n");
+    printf("    -O  Olve's segID file                                                       \n");
+    printf("    -Q  n  scale all coordinates by this factor                                 \n");
     printf("    -R0 randomly translate and rotate before superpositioning                   \n");
-    printf("    -t  weight by B-factor as a Bayesian prior                                  \n");
     printf("    -T  n  number of threads                                                    \n");
     printf("    -U  print logL for each iteration                                           \n");
     printf("    -u  calculate bias-corrected average structure                              \n");
@@ -99,7 +90,7 @@ Expert2(void)
     printf("    -X  seed the algorithm with the superposition in the file                   \n");
     printf("    -x  no iterations in inner loop (superimposing to average)                  \n");
     printf("    -y  don't calculate the average structure                                   \n");
-    printf("    -Y  print extra multivariate statistics, MV normality tests, etc.           \n");
+    printf("    -Y  print extra stats, gyration radii, Durbin-Watson autocorrelation        \n");
 }
 
 
@@ -107,7 +98,7 @@ void
 Usage(int expert)
 {
 //    int vers_major, vers_minor, vers_patch;
-    
+
 //    ilaver_(&vers_major, &vers_minor, &vers_patch);
 
     PrintTheseusPre();
@@ -122,10 +113,11 @@ Usage(int expert)
     printf("          3 = alpha and beta carbons                                            \n");
     printf("          4 = all heavy atoms (all but hydrogens)                               \n");
     printf("            or                                                                  \n");
-    printf("        a colon-delimited string explicitly specifying the atom-types PDB-style\n");
+    printf("        a colon-delimited string specifying the atom-types PDB-style            \n");
     printf("        e.g., -a' CA  : N  '                                                    \n");
     printf("        selects the alpha carbons and backone nitrogens                         \n");
     printf("    -c  use ML atomic covariance weighting (fit correlations, slower)           \n");
+    printf("    -d  calculate scale factors (for morphometrics)                             \n");
     printf("    -f  only read the first model of a multi-model PDB file                     \n");
     printf("    -i  maximum iterations {%s200%s}                                            \n", tc_GREEN, tc_NC);
     printf("    -l  superimpose with conventional least squares method                      \n");
@@ -141,13 +133,14 @@ Usage(int expert)
     printf("    -h  help/usage                                                              \n");
     printf("    -I  just calculate statistics for input file (don't superposition)          \n");
     printf("    -M  file that maps sequences in the alignment file to PDB files             \n");
+    printf("    -q  read and write Rohlf TPS morphometric landmark files                    \n");
     printf("    -r  root name for output files {%stheseus%s}                                \n", tc_GREEN, tc_NC);
     printf("    -V  version                                                                 \n");
     printf("\n Principal components analysis: \n");
     printf("    -C  use covariance matrix for PCA (correlation matrix is default)           \n");
     printf("    -P  # of principal components to calculate {%s0%s}                          \n", tc_GREEN, tc_NC);
 
-    if (expert == 1 || expert == 2)
+    if (expert)
         Expert1();
 
     if (expert == 2)
@@ -211,6 +204,6 @@ Version(void)
 {
     printf("\n  THESEUS version %s compiled on %s %s\n  by user %s with machine \"%s\" \n\n",
            VERSION, __DATE__, __TIME__, getenv("USER"), getenv("HOST"));
-    printf("  Compiled with GSL version %s\n", GSL_VERSION);
+    printf("  Compiled with GSL version %s\n\n", GSL_VERSION);
     fflush(NULL);
 }
