@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,18 +23,12 @@
     -/_|:|_|_\-
 */
 
-/* -/_|:|_|_\- */
-#if __STDC__ != 1
-    #error NOT a Standard C environment
-#endif
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <math.h>
 #include <float.h>
-//#include "Error.h"
-//#include "DLTutils.h"
 #include "DLTmath.h"
 #include "FragCds.h"
 
@@ -43,7 +37,7 @@ FragCds
 *FragCdsAlloc(int fraglen)
 {
     int            i;
-    FragCds  *frag;
+    FragCds       *frag = NULL;
 
     frag = (FragCds *) malloc(sizeof(FragCds));
 
