@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,35 +28,14 @@
 
 #include "Cds.h"
 
-void
-SuperPose2Anchor(CdsArray *scratchA, CdsArray *baseA, char *anchorf_name);
-
 void
 CalcTranslationsIp(CdsArray *scratchA, Algorithm *algo);
 
 double
 CalcRotations(CdsArray *cdsA);
 
-double
-CalcScaleFactorsML(CdsArray *cdsA);
-
-double
-CalcScaleFactorsMLConstr(CdsArray *cdsA);
-
-double
-CalcScaleFactorsMLLogNorm(CdsArray *cdsA);
-
-double
-CalcScaleFactorsML2(CdsArray *cdsA);
-
-double
-CalcScaleFactorsMLGoodall(CdsArray *cdsA);
-
-double
-CalcScaleFactors(CdsArray *cdsA);
-
 void
-ScaleCdsArray(CdsArray *cdsA);
+HierarchVars(CdsArray *cdsA);
 
 int
 CheckConvergenceInner(CdsArray *cdsA, const double precision);
@@ -64,32 +43,16 @@ CheckConvergenceInner(CdsArray *cdsA, const double precision);
 int
 CheckConvergenceOuter(CdsArray *cdsA, int round, const double precision);
 
-double
-SuperPoseArray2Orig(CdsArray *cdsA, CdsArray *targetA, double *sumdev);
-
 void
-HierarchVars(CdsArray *cdsA);
-
-int
-MultiPose_pth(CdsArray *baseA);
+InitializeStates(CdsArray *cdsA);
 
 int
 MultiPose(CdsArray *baseA);
 
-void
-RotPrincAxes(CdsArray *cdsA);
-
-void
-SuperJack(CdsArray *baseA);
+int
+MultiPose_pth(CdsArray *baseA);
 
 void
 CalcWts(CdsArray *cdsA);
 
-void
-CalcWtsFinal(CdsArray *cdsA);
-
-double
-SuperPose(Cds *cds1, Cds *cds2, double **rotmat, double *trans,
-          double *, double *, double *);
-
 #endif
