@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,11 +31,12 @@
 #include "Error.h"
 #include "lodmats.h"
 #include "pdbMalloc.h"
+#include "pdbUtils.h"
 #include "Cds.h"
 #include "PDBCds.h"
 #include "MultiPose2MSA.h"
 #include "ProcGSLSVD.h"
-#include "ProcGSLSVDOcc.h"
+#include "ProcGSLSVDNu.h"
 #include "msa.h"
 
 
@@ -48,6 +49,7 @@ atom_selxn(char *name, int mode);
 static const char atoms0[] = ":CA :C1*:C1'";
 static const char atoms1[] = ":N  :C  :O  :CA :";
 
+
 static int
 atom_selxn(char *name, int mode)
 {
@@ -127,21 +129,21 @@ VerifyAlignmentVsPDBs(PDBCdsArray *pdbA, CdsArray *baseA, MSA *msa,
                 ++len;
 
         aalen = 0;
-	    for (j = 0; j < pdbA->cds[i]->vlen; ++j)
-			if (atom_selxn(pdbA->cds[i]->name[j], atomsel) == 1 &&
-			    (pdbA->cds[i]->altLoc[j] == ' ' || pdbA->cds[i]->altLoc[j] == 'A'))
-			    ++aalen;
+        for (j = 0; j < pdbA->cds[i]->vlen; ++j)
+            if (atom_selxn(pdbA->cds[i]->name[j], atomsel) &&
+                (pdbA->cds[i]->altLoc[j] == ' ' || pdbA->cds[i]->altLoc[j] == 'A'))
+                ++aalen;
 
         baseA->cds[i]->aalen = aalen;
 
         if (len != aalen)
         {
-			fprintf(stderr, "\n\n  ERROR1122: PDB file '%s' and sequence '%s' in '%s'",
-			        pdbA->cds[i]->filename, msa->name[map[i]], msa->filename);
-			fprintf(stderr, "\n            have different lengths (%d vs %d)\n\n",
-			       aalen, len);
+            fprintf(stderr, "\n\n  ERROR1122: PDB file '%s' and sequence '%s' in '%s'",
+                    pdbA->cds[i]->filename, msa->name[map[i]], msa->filename);
+            fprintf(stderr, "\n            have different lengths (%d vs %d)\n\n",
+                   aalen, len);
             PrintTheseusTag();
-			exit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
     }
 }
@@ -159,7 +161,7 @@ Align2segID(PDBCdsArray *pdbA)
     char           *seq = NULL;
     int             resSeq = 0;
     char            alnindex[5];
-    PDBCds      *cdsi = NULL;
+    PDBCds         *cdsi = NULL;
 
     for (i = 0; i < cnum; ++i)
     {
@@ -207,7 +209,7 @@ Align2Vars(PDBCdsArray *pdbA, CdsArray *cdsA)
     MSA            *msa = pdbA->seq2pdb->msa;
     char           *seq = NULL;
     int             resSeq = 0;
-    PDBCds      *cdsi = NULL;
+    PDBCds         *cdsi = NULL;
     int            *singletons = pdbA->seq2pdb->singletons;
 
     for (i = 0; i < cnum; ++i)
@@ -226,7 +228,7 @@ Align2Vars(PDBCdsArray *pdbA, CdsArray *cdsA)
            MSA).  So we check that m is OK before accessing it. */
         while (j < msa->seqlen && k < cdsi->vlen)
         {
-            if (singletons[j] == 1)
+            if (singletons[j])
             {
                 if (seq[j] == '-') /* IS a gap */
                 {
@@ -290,7 +292,7 @@ Align2Vars(PDBCdsArray *pdbA, CdsArray *cdsA)
 static Seq2PDB
 *GetMapFile(char *mapfile_name)
 {
-    Seq2PDB        *seq2pdb;
+    Seq2PDB        *seq2pdb = NULL;
     FILE           *mapfile = NULL;
     int             i, numscanned, seqnum, maxseqnum;
     char            line[FILENAME_MAX + 256];
@@ -421,14 +423,14 @@ GetSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
                     free(msaname_root);
                 }
 
-				if (k == msa->seqnum)
-				{
-					fprintf(stderr,
-							"\n  ERROR_689: Sequence #%d (%s) in mapfile has no corresponding sequence in the alignment\n",
-							j+1, seq2pdb->pdbfile_name[j]);
-					PrintTheseusTag();
-					exit(EXIT_FAILURE);
-				}
+                if (k == msa->seqnum)
+                {
+                    fprintf(stderr,
+                            "\n  ERROR_689: Sequence #%d (%s) in mapfile has no corresponding sequence in the alignment\n",
+                            j+1, seq2pdb->pdbfile_name[j]);
+                    PrintTheseusTag();
+                    exit(EXIT_FAILURE);
+                }
 
                 free(filename_root);
                 free(mappdbname_root);
@@ -444,11 +446,11 @@ GetSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
 
         if (j == seq2pdb->seqnum)
         {
-			fprintf(stderr,
-					"\n  ERROR_690: PDB file #%d (%s) has no corresponding sequence in the alignment\n",
-					i+1, pdbA->cds[i]->filename);
-			PrintTheseusTag();
-			exit(EXIT_FAILURE);
+            fprintf(stderr,
+                    "\n  ERROR_690: PDB file #%d (%s) has no corresponding sequence in the alignment\n",
+                    i+1, pdbA->cds[i]->filename);
+            PrintTheseusTag();
+            exit(EXIT_FAILURE);
         }
     }
 }
@@ -486,11 +488,11 @@ DefaultSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
 
         if (j == msa->seqnum)
         {
-			fprintf(stderr,
-					"\n  ERROR690: PDB file #%d (%s) has no corresponding sequence in the alignment\n",
-					i+1, pdbA->cds[i]->filename);
-			PrintTheseusTag();
-			exit(EXIT_FAILURE);
+            fprintf(stderr,
+                    "\n  ERROR690: PDB file #%d (%s) has no corresponding sequence in the alignment\n",
+                    i+1, pdbA->cds[i]->filename);
+            PrintTheseusTag();
+            exit(EXIT_FAILURE);
         }
     }
 }
@@ -562,104 +564,110 @@ GetCdsFrAlignment(PDBCdsArray *pdbA, CdsArray *baseA,
     int            *lower = pdbA->lower;
     int             range_num = pdbA->range_num;
 
-	for (j = 0; j < cnum; ++j)
-	{
-	    k = map[j];
-		m = n = p = 0;
-		while(m < pdbA->cds[j]->vlen && n < vlen  && p < alignlen)
-		{
-			/* m = PDB length */
-			/* n = baseA cds length */
-			/* p = sequence alignment length */
-			/* k = sequence index */
-			/* j = pdb and baseA cds index */
+    for (j = 0; j < cnum; ++j)
+    {
+        k = map[j];
+        m = n = p = 0;
+        while(m < pdbA->cds[j]->vlen && n < vlen  && p < alignlen)
+        {
+            /* m = PDB length */
+            /* n = baseA cds length */
+            /* p = sequence alignment length */
+            /* k = sequence index */
+            /* j = pdb and baseA cds index */
 
 /*                             printf("\n1 n:%d(%d) atomname:pdbA->cds[%d]->name[%d] %s", */
 /*                                    n, alignlen, j, m, pdbA->cds[j]->name[m]); */
 /*                             fflush(NULL); */
 /* if (j == cnum - 1) */
 /* printf("\naltLoc:%c", pdbA->cds[j]->altLoc[m]); */
-			if (atom_selxn(pdbA->cds[j]->name[m], baseA->algo->atoms) == 1 &&
-			    (pdbA->cds[j]->altLoc[m] == ' ' || pdbA->cds[j]->altLoc[m] == 'A'))
-			{
+            if (atom_selxn(pdbA->cds[j]->name[m], algo->atoms) &&
+                (pdbA->cds[j]->altLoc[m] == ' ' || pdbA->cds[j]->altLoc[m] == 'A'))
+            {
 /*                                 printf("\n1 m:%d(%d) msa->seq[%d(%d)][%d(%d)] = %c", */
 /*                                        m, pdbA->cds[j]->vlen, k, cnum, n, alignlen, msa->seq[k][n]); */
 /*                                 fflush(NULL); */
-				if (range_selxn(p, lower, upper, range_num) == 1 - baseA->algo->revsel && /* in-range, or out-of-range if revsel == 1 */
-				    singletons[p] == 0) /* not a singleton */
-				{
-					if (msa->seq[k][p] != '-') /* not a gap */
-					{
-						strncpy(baseA->cds[j]->resName[n], pdbA->cds[j]->resName[m], 3);
-						baseA->cds[j]->chainID[n] = pdbA->cds[j]->chainID[m];
-						baseA->cds[j]->resSeq[n]  = pdbA->cds[j]->resSeq[m];
-						baseA->cds[j]->x[n]       = pdbA->cds[j]->x[m];
-						baseA->cds[j]->y[n]       = pdbA->cds[j]->y[m];
-						baseA->cds[j]->z[n]       = pdbA->cds[j]->z[m];
-						baseA->cds[j]->o[n]       = 1.0;
-						baseA->cds[j]->b[n]       = pdbA->cds[j]->tempFactor[m];
+                if (range_selxn(p, lower, upper, range_num) - algo->revsel && /* in-range, or out-of-range if revsel == 1 */
+                    singletons[p] == 0) /* not a singleton */
+                {
+                    if (msa->seq[k][p] != '-') /* not a gap */
+                    {
+                        strncpy(baseA->cds[j]->resName[n], pdbA->cds[j]->resName[m], 3);
+                        baseA->cds[j]->chainID[n] = pdbA->cds[j]->chainID[m];
+                        baseA->cds[j]->resSeq[n]  = pdbA->cds[j]->resSeq[m];
+                        baseA->cds[j]->x[n]       = pdbA->cds[j]->x[m];
+                        baseA->cds[j]->y[n]       = pdbA->cds[j]->y[m];
+                        baseA->cds[j]->z[n]       = pdbA->cds[j]->z[m];
+                        baseA->cds[j]->o[n]       = pdbA->cds[j]->occupancy[m];
+                        baseA->cds[j]->b[n]       = pdbA->cds[j]->tempFactor[m];
+                        baseA->cds[j]->nu[n]       = 1;
+                        baseA->cds[j]->mu[n]       = 0;
 
-						++m;
-						++n;
-					}
-					else /* is a gap */
-					{
-						strncpy(baseA->cds[j]->resName[n], "GAP", 3);
-						baseA->cds[j]->chainID[n] = pdbA->cds[j]->chainID[m];
-						baseA->cds[j]->resSeq[n]  = 0;
-						baseA->cds[j]->x[n]       = 0.0;
-						baseA->cds[j]->y[n]       = 0.0;
-						baseA->cds[j]->z[n]       = 0.0;
-						baseA->cds[j]->o[n]       = 0.0;
-						baseA->cds[j]->b[n]       = 99.99;
+                        ++m;
+                        ++n;
+                    }
+                    else /* is a gap */
+                    {
+                        strncpy(baseA->cds[j]->resName[n], "GAP", 3);
+                        baseA->cds[j]->chainID[n] = pdbA->cds[j]->chainID[m];
+                        baseA->cds[j]->resSeq[n]  = 0;
+                        baseA->cds[j]->x[n]       = 0.0;
+                        baseA->cds[j]->y[n]       = 0.0;
+                        baseA->cds[j]->z[n]       = 0.0;
+                        baseA->cds[j]->o[n]       = 0.0;
+                        baseA->cds[j]->b[n]       = 99.99;
+                        baseA->cds[j]->nu[n]       = 0;
+                        baseA->cds[j]->mu[n]       = 1;
 
-						++n;
-					}
-				}
-				else /* out of range */
-				{
-					if (msa->seq[k][p] != '-') /* not a gap */
-					{
-						++m;
-					}
+                        ++n;
+                    }
+                }
+                else /* out of range */
+                {
+                    if (msa->seq[k][p] != '-') /* not a gap */
+                    {
+                        ++m;
+                    }
 
-				}
+                }
 
-				++p;
-/* 				            if (j == cnum-1) */
+                ++p;
+/*                          if (j == cnum-1) */
 /*                                 printf("\n2 m:%d(%d) msa->seq[%d(%d)][%d(%d)] = %c", */
 /*                                        m, pdbA->cds[j]->vlen, k, cnum, n, alignlen, msa->seq[k][n]); */
 /*                                 fflush(NULL); */
-			}
-			else /* not the proper atom slxn */
-			{
-				++m;
-			}
-/* 			            if (j == cnum-1) */
+            }
+            else /* not the proper atom slxn */
+            {
+                ++m;
+            }
+/*                      if (j == cnum-1) */
 /*                             printf("\n2 n:%d(%d) atomname:pdbA->cds[%d]->name[%d] %s", */
 /*                                    n, alignlen, j, m, pdbA->cds[j]->name[m]); */
 /*                             fflush(NULL); */
-		}
-		/*******************************************************************************************/
-		/* if the end of the PDB is before the end of the alignment */
-		if (n < vlen && m != 0 && n != 0)
-		{
-/* 		    printf("\nHere: m:%4d n:%4d p:%4d j:%4d -- %4d %4d %4d %4d", */
-/* 		            m, n, p, j, pdbA->cds[j]->vlen, vlen, alignlen, cnum); */
+        }
+        /*******************************************************************************************/
+        /* if the end of the PDB is before the end of the alignment */
+        if (n < vlen && m != 0 && n != 0)
+        {
+/*          printf("\nHere: m:%4d n:%4d p:%4d j:%4d -- %4d %4d %4d %4d", */
+/*                  m, n, p, j, pdbA->cds[j]->vlen, vlen, alignlen, cnum); */
 
-			for (q = n; q < vlen; ++q)
-			{
-				strncpy(baseA->cds[j]->resName[q], "GAP", 3);
-				baseA->cds[j]->chainID[q] = pdbA->cds[j]->chainID[m-1];
-				baseA->cds[j]->resSeq[q]  = 0;
-				baseA->cds[j]->x[q]       = 0.0;
-				baseA->cds[j]->y[q]       = 0.0;
-				baseA->cds[j]->z[q]       = 0.0;
-				baseA->cds[j]->o[q]       = 0.0;
-				baseA->cds[j]->b[q]       = 66.66;
-			}
-		}
-	}
+            for (q = n; q < vlen; ++q)
+            {
+                strncpy(baseA->cds[j]->resName[q], "GAP", 3);
+                baseA->cds[j]->chainID[q] = pdbA->cds[j]->chainID[m-1];
+                baseA->cds[j]->resSeq[q]  = 0;
+                baseA->cds[j]->x[q]       = 0.0;
+                baseA->cds[j]->y[q]       = 0.0;
+                baseA->cds[j]->z[q]       = 0.0;
+                baseA->cds[j]->o[q]       = 0.0;
+                baseA->cds[j]->b[q]       = 66.66;
+                baseA->cds[j]->nu[n]       = 0;
+                baseA->cds[j]->mu[n]       = 1;
+            }
+        }
+    }
 }
 
 
@@ -780,31 +788,31 @@ ParseSelxns(PDBCdsArray *pdbA, char *selection, const int alignlen, int *singlet
 
     if (revsel == 0)
     {
-		vlen = 0;
-		for (j = 0; j < pdbA->range_num; ++j)
-			vlen += (pdbA->upper[j] - pdbA->lower[j] + 1);
+        vlen = 0;
+        for (j = 0; j < pdbA->range_num; ++j)
+            vlen += (pdbA->upper[j] - pdbA->lower[j] + 1);
 
         /* don't count singletons that are in selected ranges */
         for (j = 0; j < pdbA->range_num; ++j)
             for (i = 0; i < alignlen; ++i)
-                if (i >= pdbA->lower[j] && i <= pdbA->upper[j] && singletons[i] == 1)
+                if (i >= pdbA->lower[j] && i <= pdbA->upper[j] && singletons[i])
                     vlen--;
     }
     else
     {
-		vlen = alignlen;
-		for (j = 0; j < pdbA->range_num; ++j)
-			vlen -= (pdbA->upper[j] - pdbA->lower[j] + 1);
+        vlen = alignlen;
+        for (j = 0; j < pdbA->range_num; ++j)
+            vlen -= (pdbA->upper[j] - pdbA->lower[j] + 1);
 
         singleton_cnt = 0;
         for (i = 0; i < alignlen; ++i)
-            if (singletons[i] == 1)
+            if (singletons[i])
                 ++singleton_cnt;
 
         /* don't count singletons that are in (un)selected ranges */
         for (j = 0; j < pdbA->range_num; ++j)
             for (i = 0; i < alignlen; ++i)
-                if (i >= pdbA->lower[j] && i <= pdbA->upper[j] && singletons[i] == 1)
+                if (i >= pdbA->lower[j] && i <= pdbA->upper[j] && singletons[i])
                     singleton_cnt--;
 
         vlen -= singleton_cnt;
@@ -831,9 +839,8 @@ Align2MSA(PDBCdsArray *pdbA, CdsArray *baseA, char *msafile_name, char *mapfile_
 {
     int             i, alnlen, vlen;
     const int       cnum = pdbA->cnum;
-    MSA            *msa;
+    MSA            *msa = NULL;
     //int            *singletons = NULL;
-    Algorithm      *algo = baseA->algo;
 
     if (mapfile_name == NULL)
     {
@@ -869,7 +876,7 @@ Align2MSA(PDBCdsArray *pdbA, CdsArray *baseA, char *msafile_name, char *mapfile_
         DefaultSeq2PDBMap(pdbA, pdbA->seq2pdb, msa);
 
     GetSingletons(pdbA->seq2pdb->singletons, msa);
-    if (algo->missing == 1)
+    if (algo->missing)
         GetUbiqs(pdbA->seq2pdb->singletons, msa);
 //    for (i=0;i<alnlen;++i)
 //        printf("singleton[%3d]:%d\n", i, singletons[i]);
@@ -916,28 +923,28 @@ Align2MSA(PDBCdsArray *pdbA, CdsArray *baseA, char *msafile_name, char *mapfile_
 
 
 double
-CalcRotationsOcc(CdsArray *cdsA)
+CalcRotationsNu(CdsArray *cdsA)
 {
-    Cds        **cds = cdsA->cds;
-    Cds         *avecds = cdsA->avecds;
+    Cds           **cds = cdsA->cds;
+    Cds            *avecds = cdsA->avecds;
     const double   *wts = (const double *) cdsA->w;
     double          deviation = 0.0, deviation_sum = 0.0;
     int             i;
 
     for (i = 0; i < cdsA->cnum; ++i)
     {
-        if(cdsA->algo->covweight != 0)
+        if(algo->covweight)
         {
-                deviation = ProcGSLSVDCovOcc(cds[i], avecds, cds[i]->matrix,
+                deviation = ProcGSLSVDCovNu(cds[i], avecds, cds[i]->matrix,
                                                 (const double **) cdsA->WtMat,
                                                 cdsA->tmpmat3a,
                                                 cdsA->tmpmat3b,
                                                 cdsA->tmpmat3c,
                                                 cdsA->tmpvec3a);
         }
-        else if(cdsA->algo->varweight != 0 || cdsA->algo->leastsquares != 0)
+        else if(algo->varweight || algo->leastsquares)
         {
-                deviation = ProcGSLSVDOcc(cds[i], avecds,
+                deviation = ProcGSLSVDNu(cds[i], avecds,
                                              cds[i]->matrix,
                                              wts,
                                              cdsA->tmpmat3a,
@@ -949,12 +956,12 @@ CalcRotationsOcc(CdsArray *cdsA)
         cds[i]->wRMSD_from_mean = sqrt(deviation / cdsA->vlen);
         deviation_sum += deviation;
 
-        if (cdsA->algo->verbose == 1)
+        if (algo->verbose)
         {
             /* rmsd from mean would usually need a 2 in denom,\
                but this is already deviation from mean,
                since structure #2 is the average structure */
-            printf("CalcRotationsOcc:%5d %8.3f %13.3f \n",
+            printf("CalcRotationsNu:%5d %8.3f %13.3f \n",
                    i+1,
                    cds[i]->wRMSD_from_mean,
                    deviation);
@@ -965,6 +972,57 @@ CalcRotationsOcc(CdsArray *cdsA)
 }
 
 
+// DLT OP
+double
+CalcRotationsNu2(CdsArray *cdsA)
+{
+    Cds           **cds = cdsA->cds;
+    const Cds      *avecds = cdsA->avecds;
+    const double   *wts = (const double *) cdsA->w;
+    const double  **wtmat = (const double **) cdsA->WtMat;
+    Cds            *tcds = NULL;
+    double          deviation, deviation_sum;
+    double          norm1, norm2, innprod;
+    const int       vlen = cdsA->vlen;
+    int             i;
+
+
+    if (algo->covweight)
+    {
+        tcds = cdsA->tcds;
+        MatMultCdsMultMatDiag(tcds, wtmat, avecds);
+    }
+    else if (algo->varweight)
+    {
+        tcds = cdsA->tcds;
+        MatDiagMultCdsMultMatDiag(tcds, wts, avecds);
+    }
+    else if (algo->leastsquares)
+    {
+        tcds = cdsA->avecds;
+    }
+
+    deviation = deviation_sum = 0.0;
+    for (i = 0; i < cdsA->cnum; ++i)
+    {
+        deviation = ProcGSLSVDvanNu2((const double **) cds[i]->sc,
+                                     (const double **) tcds->wc,
+                                     (const int *) cds[i]->nu,
+                                     vlen, cds[i]->matrix,
+                                     cdsA->tmpmat3a,
+                                     cdsA->tmpmat3b,
+                                     cdsA->tmpmat3c,
+                                     cdsA->tmpvec3a,
+                                     &norm1, &norm2, &innprod);
+
+        cds[i]->wRMSD_from_mean = sqrt(deviation / (3 * cdsA->vlen));
+        deviation_sum += deviation;
+    }
+
+    return(deviation_sum);
+}
+
+
 /* char aa1[] = "ARNDCQEGHILKMFPSTWYV"; */
 /* char aa3[] = "ALAARGASNASPCYSGLNGLUGLYHISILELEULYSMETPHEPROSERTHRTRPTYRVAL"; */
 
@@ -973,7 +1031,7 @@ pdb2fst(PDBCdsArray *pdbA)
 {
     int             i, j, count, aaindex;
     char           *pindex = NULL;
-    FILE           *fp;
+    FILE           *fp = NULL;
     char            outfile[FILENAME_MAX];
 
     for (i = 0; i < pdbA->cnum; ++i)
@@ -998,16 +1056,16 @@ pdb2fst(PDBCdsArray *pdbA)
                  strncmp(pdbA->cds[i]->name[j], "C1'", 3) == 0) &&
                 (pdbA->cds[i]->altLoc[j] == ' ' || pdbA->cds[i]->altLoc[j] == 'A'))
             {
-				if (count % 72 == 0)
-					fputc('\n', fp);
+                if (count % 72 == 0)
+                    fputc('\n', fp);
 
                 pindex = strstr(aan3, pdbA->cds[i]->resName[j]);
                 if (pindex == NULL)
                     fputc('X', fp);
                 else
                 {
-					aaindex = (int) (pindex - &aan3[0])/3;
-					fputc(aan1[aaindex], fp);
+                    aaindex = (int) (pindex - &aan3[0])/3;
+                    fputc(aan1[aaindex], fp);
                 }
 
                 ++count;
@@ -1022,3 +1080,4 @@ pdb2fst(PDBCdsArray *pdbA)
         fclose(fp);
     }
 }
+
