@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,10 @@ void
 Align2MSA(PDBCdsArray *pdbA, CdsArray *baseA, char *msafile_name, char *mapfile_name);
 
 double
-CalcRotationsOcc(CdsArray *cdsA);
+CalcRotationsNu(CdsArray *cdsA);
+
+double
+CalcRotationsNu2(CdsArray *cdsA);
 
 void
 pdb2fst(PDBCdsArray *pdbA);
