@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "Threads.h"
 #include "MultiPose_local.h"
 #include "pdbStats.h"
+#include "pdbUtils.h"
 #include "distfit.h"
 #include "ProcGSLSVD.h"
 #include "MultiPoseMix.h"
@@ -73,7 +74,7 @@ FrobTermAtom(CdsArray *cdsA, const int atom)
    structural superposition.
 
      NOTA BENE: This function assumes that the variances, covariance matrices,
-     hierarchical model parameters, average coordinates, rotations, and 
+     hierarchical model parameters, average coordinates, rotations, and
      translations have all been pre-calculated. Even when not calculating the
      optimal ML rotations and translation transformations, the other parameters
      in general must be estimated iteratively, as described below.
@@ -99,19 +100,19 @@ CalcLogLAtom(CdsArray *cdsA, const int atom)
     const double    ndk2 = 0.5 * ndk;
     const double   *var = (const double *) cdsA->var;
     double          lndetrow , frobterm, logL;
-    Algorithm      *algo = cdsA->algo;
+
 
     lndetrow = frobterm = 0.0;
 
-    if (algo->leastsquares == 1)
+    if (algo->leastsquares)
     {
         frobterm = FrobTermAtom(cdsA, atom);
     }
-    else if (algo->varweight == 1)
+    else if (algo->varweight)
     {
         lndetrow = log(var[atom]);
 
-        if (algo->hierarch != 0)
+        if (algo->hierarch)
             frobterm = FrobTermAtom(cdsA, atom);
         else
             frobterm = -ndk2;
@@ -186,7 +187,7 @@ NewCalcMixDens(CdsArray **mixA, const int mixn, double **probs)
 
                 dist = SqrCdsDist(mixA[j]->cds[i], m, mixA[j]->avecds, m);
                 pij = probs[j][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[j]->var[m]);
-                sump += pij / summix; 
+                sump += pij / summix;
             }
 
             probs[j][m] = sump / cnum;
@@ -221,14 +222,14 @@ OldCalcMixDens(CdsArray **mixA, const int mixn, double **probs)
 
     for (k = 0; k < mixn; ++k)
     {
-		for (i = 0; i < vlen; ++i)
-		{
-			dist = 0.0;
-			for (j = 0; j < cnum; ++j)
-				dist += SqrCdsDist(mixA[k]->cds[j], i, mixA[k]->avecds, i);
-	
-			probs[k][i] *= normal_pdf(sqrt(dist), 0.0, 3.0 * cnum * mixA[k]->var[i]);
-		}
+        for (i = 0; i < vlen; ++i)
+        {
+            dist = 0.0;
+            for (j = 0; j < cnum; ++j)
+                dist += SqrCdsDist(mixA[k]->cds[j], i, mixA[k]->avecds, i);
+
+            probs[k][i] *= normal_pdf(sqrt(dist), 0.0, 3.0 * cnum * mixA[k]->var[i]);
+        }
     }
 
     for (m = 0; m < vlen; ++m)
@@ -328,7 +329,7 @@ void
 InitializeMix(CdsArray *cdsA, double **probs)
 {
     int             i, j;
-    const int       vlen = cdsA->vlen, mixn = cdsA->algo->mixture;
+    const int       vlen = cdsA->vlen, mixn = algo->mixture;
     double          ave, sum, aveprob;
 
     const gsl_rng_type     *T = NULL;
@@ -384,28 +385,28 @@ CalcSubsetProbs(CdsArray **mixA, const int subset, double **probs)
     const int       vlen = mixA[0]->vlen, cnum = mixA[0]->cnum;
     double          sump, summix, dist, pij, aveprob, sum;
 
-	for (m = 0; m < vlen; ++m)
-	{
-		for (j = 0; j < subset - 1; ++j)
-		{
-			sump = 0.0;
-			for (i = 0; i < cnum; ++i)
-			{
-				summix = 0.0;
-				for (k = 0; k < subset - 1; ++k)
-				{
-					dist = SqrCdsDist(mixA[k]->cds[i], m, mixA[k]->avecds, m);
-					summix += probs[k][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[k]->var[m]);
-				}
+    for (m = 0; m < vlen; ++m)
+    {
+        for (j = 0; j < subset - 1; ++j)
+        {
+            sump = 0.0;
+            for (i = 0; i < cnum; ++i)
+            {
+                summix = 0.0;
+                for (k = 0; k < subset - 1; ++k)
+                {
+                    dist = SqrCdsDist(mixA[k]->cds[i], m, mixA[k]->avecds, m);
+                    summix += probs[k][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[k]->var[m]);
+                }
 
-				dist = SqrCdsDist(mixA[j]->cds[i], m, mixA[j]->avecds, m);
-				pij = probs[j][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[j]->var[m]);
-				sump += pij / summix; 
-			}
+                dist = SqrCdsDist(mixA[j]->cds[i], m, mixA[j]->avecds, m);
+                pij = probs[j][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[j]->var[m]);
+                sump += pij / summix;
+            }
 
-			probs[j][m] = sump / cnum;
-		}
-	}
+            probs[j][m] = sump / cnum;
+        }
+    }
 
     aveprob = 0.0;
     for (i = 0; i < vlen; ++i)
@@ -413,18 +414,18 @@ CalcSubsetProbs(CdsArray **mixA, const int subset, double **probs)
             aveprob += log(probs[j][i]);
     aveprob = exp(aveprob/vlen);
 
-	for (i = 0; i < vlen; ++i)
-	    probs[subset - 1][i] = aveprob;
+    for (i = 0; i < vlen; ++i)
+        probs[subset - 1][i] = aveprob;
 
-	for (i = 0; i < vlen; ++i)
-	{
-		sum = 0.0;
-		for (j = 0; j < subset; ++j)
-			sum += probs[j][i];
+    for (i = 0; i < vlen; ++i)
+    {
+        sum = 0.0;
+        for (j = 0; j < subset; ++j)
+            sum += probs[j][i];
 
-		for (j = 0; j < subset; ++j)
-			probs[j][i] /= sum;
-	}
+        for (j = 0; j < subset; ++j)
+            probs[j][i] /= sum;
+    }
 }
 
 
@@ -439,46 +440,46 @@ InitializeSubsets(CdsArray **mixA, const int mixn, double **probs, double **vars
 
     /* VecPrint(probs[0], vlen); */
 
-	count = 0;
-	while(1)
-	{
-		++count;
+    count = 0;
+    while(1)
+    {
+        ++count;
 
-		memcpy(oldprobs, probs[0], vlen * sizeof(double));
+        memcpy(oldprobs, probs[0], vlen * sizeof(double));
 
-		for (i = 0; i < 2; ++i)
-			MultiPoseMix(mixA[i], probs[i], vars[i]);
+        for (i = 0; i < 2; ++i)
+            MultiPoseMix(mixA[i], probs[i], vars[i]);
 
-		NewCalcMixDens(mixA, 2, probs);
+        NewCalcMixDens(mixA, 2, probs);
 
-		if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-2) == 1 && count > 5)
-			break;
-	}
+        if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-2) && count > 5)
+            break;
+    }
 
     /* VecPrint(probs[0], vlen); */
 
     for (n = 3; n < mixn; ++n)
     {
-		for (j = 0; j < n; ++j)
-			AveCds(mixA[j]);
-	
+        for (j = 0; j < n; ++j)
+            AveCds(mixA[j]);
+
         CalcSubsetProbs(mixA, n, probs);
 
-		count = 0;
-		while(1)
-		{
-			++count;
-	
-			memcpy(oldprobs, probs[0], vlen * sizeof(double));
-	
-			for (i = 0; i < n; ++i)
-				MultiPoseMix(mixA[i], probs[i], vars[i]);
-	
-			NewCalcMixDens(mixA, n, probs);
-	
-			if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-3) == 1 && count > 5)
-				break;
-		}
+        count = 0;
+        while(1)
+        {
+            ++count;
+
+            memcpy(oldprobs, probs[0], vlen * sizeof(double));
+
+            for (i = 0; i < n; ++i)
+                MultiPoseMix(mixA[i], probs[i], vars[i]);
+
+            NewCalcMixDens(mixA, n, probs);
+
+            if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-3) && count > 5)
+                break;
+        }
 
         /* VecPrint(probs[0], vlen); */
     }
@@ -501,12 +502,12 @@ InitializeSubsets_pth(CdsArray **mixA, const int mixn, double **probs,
 
     /* VecPrint(probs[0], vlen); */
 
-	count = 0;
-	while(1)
-	{
-		++count;
+    count = 0;
+    while(1)
+    {
+        ++count;
 
-		memcpy(oldprobs, probs[0], vlen * sizeof(double));
+        memcpy(oldprobs, probs[0], vlen * sizeof(double));
 
         rc = 0;
         for (i = 0; i < 2; ++i)
@@ -515,88 +516,88 @@ InitializeSubsets_pth(CdsArray **mixA, const int mixn, double **probs,
             mixdata[i]->probs = probs[i];
             mixdata[i]->vars = vars[i];
 
-			rc = pthread_create(&callThd[i], attr, MultiPoseMix_pth, (void *) mixdata[i]);
+            rc = pthread_create(&callThd[i], attr, MultiPoseMix_pth, (void *) mixdata[i]);
 
-			if (rc)
-			{
-				printf("ERROR811: return code from pthread_create() %d is %d\n", i, rc);
-				fflush(NULL);
-				exit(EXIT_FAILURE);
-			}
+            if (rc)
+            {
+                printf("ERROR811: return code from pthread_create() %d is %d\n", i, rc);
+                fflush(NULL);
+                exit(EXIT_FAILURE);
+            }
         }
 
         rc = 0;
-		for (i = 0; i < 2; ++i)
-		{
-			rc = pthread_join(callThd[i], (void **) NULL);
-	
-			if (rc)
-			{
-				printf("ERROR812: return code from pthread_join() %d is %d\n", i, rc);
-				fflush(NULL);
-				exit(EXIT_FAILURE);
-			}
-		}
+        for (i = 0; i < 2; ++i)
+        {
+            rc = pthread_join(callThd[i], (void **) NULL);
 
-		NewCalcMixDens(mixA, 2, probs);
+            if (rc)
+            {
+                printf("ERROR812: return code from pthread_join() %d is %d\n", i, rc);
+                fflush(NULL);
+                exit(EXIT_FAILURE);
+            }
+        }
 
-		if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-2) == 1 && count > 5)
-			break;
-	}
+        NewCalcMixDens(mixA, 2, probs);
+
+        if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-2) && count > 5)
+            break;
+    }
 
     /* VecPrint(probs[0], vlen); */
 
     for (n = 3; n < mixn; ++n)
     {
-		for (j = 0; j < n; ++j)
-			AveCds(mixA[j]);
-	
+        for (j = 0; j < n; ++j)
+            AveCds(mixA[j]);
+
         CalcSubsetProbs(mixA, n, probs);
 
-		count = 0;
-		while(1)
-		{
-			++count;
-	
-			memcpy(oldprobs, probs[0], vlen * sizeof(double));
-	
-			rc = 0;
-			for (i = 0; i < n; ++i)
-			{
-				mixdata[i]->cdsA = mixA[i];
-				mixdata[i]->probs = probs[i];
-				mixdata[i]->vars = vars[i];
-				
-				/* MultiPoseMix_pth((void *) mixdata[i]); */
-	
-				rc = pthread_create(&callThd[i], attr, MultiPoseMix_pth, (void *) mixdata[i]);
-		
-				if (rc)
-				{
-					printf("ERROR813: return code from pthread_create() %d is %d\n", i, rc);
-					fflush(NULL);
-					exit(EXIT_FAILURE);
-				}
-			}
+        count = 0;
+        while(1)
+        {
+            ++count;
 
-			rc = 0;
-			for (i = 0; i < n; ++i)
-			{
-				rc = pthread_join(callThd[i], (void **) NULL);
-		
-				if (rc)
-				{
-					printf("ERROR814: return code from pthread_join() %d is %d\n", i, rc);
-					fflush(NULL);
-					exit(EXIT_FAILURE);
-				}
-			}
+            memcpy(oldprobs, probs[0], vlen * sizeof(double));
 
-			NewCalcMixDens(mixA, n, probs);
-	
-			if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-3) == 1 && count > 5)
-				break;
-		}
+            rc = 0;
+            for (i = 0; i < n; ++i)
+            {
+                mixdata[i]->cdsA = mixA[i];
+                mixdata[i]->probs = probs[i];
+                mixdata[i]->vars = vars[i];
+
+                /* MultiPoseMix_pth((void *) mixdata[i]); */
+
+                rc = pthread_create(&callThd[i], attr, MultiPoseMix_pth, (void *) mixdata[i]);
+
+                if (rc)
+                {
+                    printf("ERROR813: return code from pthread_create() %d is %d\n", i, rc);
+                    fflush(NULL);
+                    exit(EXIT_FAILURE);
+                }
+            }
+
+            rc = 0;
+            for (i = 0; i < n; ++i)
+            {
+                rc = pthread_join(callThd[i], (void **) NULL);
+
+                if (rc)
+                {
+                    printf("ERROR814: return code from pthread_join() %d is %d\n", i, rc);
+                    fflush(NULL);
+                    exit(EXIT_FAILURE);
+                }
+            }
+
+            NewCalcMixDens(mixA, n, probs);
+
+            if (CheckConvergenceMix(probs[0], oldprobs, vlen, 1e-3) && count > 5)
+                break;
+        }
 
         /* VecPrint(probs[0], vlen); */
     }
@@ -714,17 +715,17 @@ CalcLRTs(CdsArray **mixA, const int mixn, const int cnum, double **probs, const
 
         for (j = 0; j < mixn; ++j)
         {
-			dist = 0.0;
-			for (k = 0; k < cnum; ++k)
-				dist += SqrCdsDist(mixA[j]->cds[k], i, mixA[j]->avecds, i);
+            dist = 0.0;
+            for (k = 0; k < cnum; ++k)
+                dist += SqrCdsDist(mixA[j]->cds[k], i, mixA[j]->avecds, i);
 
             if (probs[j][i] == 0.0)
                 printf(" %10.3f", 0.0);
             else
             {
                 logL[j] = log(probs[j][i]) + normal_lnpdf(sqrt(dist), 0.0, 3.0 * cnum * mixA[j]->var[i]);
-			    printf(" %10.3f", logL[j]);
-			}
+                printf(" %10.3f", logL[j]);
+            }
 
             mxlogL[j] += logL[j];
         }
@@ -741,11 +742,11 @@ CalcLRTs(CdsArray **mixA, const int mixn, const int cnum, double **probs, const
                 smallest = logL[j];
         }
 
-		logLR = largest - smallest;
-		printf(" %10.3f", logLR);
+        logLR = largest - smallest;
+        printf(" %10.3f", logLR);
 
-		if (logLR >= 3.0)
-			printf(" *");
+        if (logLR >= 3.0)
+            printf(" *");
     }
 
     printf("         \n");
@@ -770,8 +771,8 @@ CalcAICcorrxn(CdsArray *cdsA)
 {
     double         n, p;
 
-    cdsA->stats->nparams = p = CalcParamNum(cdsA);
-    cdsA->stats->ndata = n = 3.0 * cdsA->cnum * cdsA->vlen;
+    stats->nparams = p = CalcParamNum(cdsA);
+    stats->ndata = n = 3.0 * cdsA->cnum * cdsA->vlen;
 
     return(- p * n / (n - p - 1));
 }
@@ -786,10 +787,10 @@ CalcMixAICLogL(CdsArray **mixA, const int mixn, const double **probs,
 
     for (i = 0; i < mixn; ++i)
     {
-		if (mixA[i]->algo->leastsquares == 1)
-			CalcNormResidualsLS(mixA[i]);
-		else
-			CalcNormResiduals(mixA[i]);
+        if (algo->leastsquares)
+            CalcNormResidualsLS(mixA[i]);
+        else
+            CalcNormResiduals(mixA[i]);
     }
 
     *logL = 0.0;
@@ -802,9 +803,6 @@ CalcMixAICLogL(CdsArray **mixA, const int mixn, const double **probs,
         *logL += log(Lik);
     }
 
-    for (i = 0; i < mixn; ++i)
-        *logL += CalcHierarchLogL(mixA[i]);
-
     *AIC = *logL;
     for (i = 0; i < mixn; ++i)
         *AIC += CalcAICcorrxn(mixA[i]);
@@ -817,14 +815,14 @@ int
 Mixture(CdsArray *cdsA, PDBCdsArray *pdbA)
 {
     int             count, i;
-    const int       vlen = cdsA->vlen, cnum = cdsA->cnum, mixn = cdsA->algo->mixture;
+    const int       vlen = cdsA->vlen, cnum = cdsA->cnum, mixn = algo->mixture;
     double        **probs = calloc(mixn, sizeof(double *));
     double         *aveprobs = calloc(mixn, sizeof(double));
     int            *slope = calloc(mixn, sizeof(int));
     double         *oldprobs = calloc(vlen, sizeof(double));
     CdsArray   **mixA = NULL;
-    Algorithm      *algo = cdsA->algo;
-    /* Statistics     *stats = cdsA->stats; */
+
+    /* S */
     PDBCdsArray *pdb2A = NULL;
     double        **newprobs = MatAlloc(vlen, cnum);
     double        **vars = MatAlloc(mixn, vlen);
@@ -842,7 +840,7 @@ Mixture(CdsArray *cdsA, PDBCdsArray *pdbA)
         CdsArrayAlloc(mixA[i], cnum, vlen);
         CdsArraySetup(mixA[i]);
         CdsArrayCopy(mixA[i], cdsA);
-        mixA[i]->algo->write_file = 0;
+        algo->write_file = 0;
     }
 
     printf("    Initializing mixture iterations ... \n");
@@ -879,7 +877,7 @@ Mixture(CdsArray *cdsA, PDBCdsArray *pdbA)
 /*     VecPrint(probs[0], vlen); */
 /*     VecPrint(probs[1], vlen); */
 
-        if (CheckConvergenceMix(probs[0], oldprobs, vlen, algo->precision) == 1 && count > 5)
+        if (CheckConvergenceMix(probs[0], oldprobs, vlen, algo->precision) && count > 5)
             break;
     }
 
@@ -910,7 +908,7 @@ Mixture(CdsArray *cdsA, PDBCdsArray *pdbA)
 /*      for (j = 0; j < cnum; ++j) */
 /*          TransformPDBCdsIp(pdb2A->cds[j]); */
 /*  */
-/*      if (algo->alignment == 1) */
+/*      if (algo->alignment) */
 /*          Align2segID(pdb2A); */
 /*  */
 /*      printf("\n    Writing transformed coordinates PDB file ... "); */
@@ -974,20 +972,20 @@ int
 Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
 {
     int             count, i, j, lineskip;
-    const int       vlen = cdsA->vlen, cnum = cdsA->cnum, mixn = cdsA->algo->mixture;
+    const int       vlen = cdsA->vlen, cnum = cdsA->cnum, mixn = algo->mixture;
     double        **probs = calloc(mixn, sizeof(double *));
     double         *aveprobs = calloc(mixn, sizeof(double));
     int            *slope = calloc(mixn, sizeof(int));
     double         *oldprobs = calloc(vlen, sizeof(double));
     double        **vars = MatAlloc(mixn, vlen);
-    CdsArray   **mixA = NULL;
-    Algorithm      *algo = cdsA->algo;
+    CdsArray      **mixA = NULL;
+
     double        **newprobs = MatAlloc(vlen, cnum);
     double          logL, AIC, Lik;
 
     int             rc;
     MixData       **mixdata = NULL;
-    pthread_t      *callThd;
+    pthread_t      *callThd = NULL;
     pthread_attr_t  attr;
 
     callThd = malloc(mixn * sizeof(pthread_t));
@@ -1011,7 +1009,7 @@ Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
         CdsArrayAlloc(mixA[i], cnum, vlen);
         CdsArraySetup(mixA[i]);
         CdsArrayCopy(mixA[i], cdsA);
-        mixA[i]->algo->write_file = 0;
+        algo->write_file = 0;
     }
 
     printf("    Initializing mixture iterations ... \n");
@@ -1042,51 +1040,51 @@ Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
             mixdata[i]->cdsA = mixA[i];
             mixdata[i]->probs = probs[i];
             mixdata[i]->vars = vars[i];
-            
+
             /* MultiPoseMix_pth((void *) mixdata[i]); */
 
-			rc = pthread_create(&callThd[i], &attr, MultiPoseMix_pth, (void *) mixdata[i]);
-	
-			if (rc)
-			{
-				printf("ERROR815: return code from pthread_create() %d is %d\n", i, rc);
-				fflush(NULL);
-				exit(EXIT_FAILURE);
-			}
+            rc = pthread_create(&callThd[i], &attr, MultiPoseMix_pth, (void *) mixdata[i]);
+
+            if (rc)
+            {
+                printf("ERROR815: return code from pthread_create() %d is %d\n", i, rc);
+                fflush(NULL);
+                exit(EXIT_FAILURE);
+            }
         }
 
         rc = 0;
-		for (i = 0; i < mixn; ++i)
-		{
-			rc = pthread_join(callThd[i], (void **) NULL);
-	
-			if (rc)
-			{
-				printf("ERROR816: return code from pthread_join() %d is %d\n", i, rc);
-				fflush(NULL);
-				exit(EXIT_FAILURE);
-			}
-		}
+        for (i = 0; i < mixn; ++i)
+        {
+            rc = pthread_join(callThd[i], (void **) NULL);
 
-		for (i = 0; i < mixn; ++i)
-		{
-			printf("    Mixture %d: %4d rounds\n", i, mixdata[i]->rounds);
-			fflush(NULL);
+            if (rc)
+            {
+                printf("ERROR816: return code from pthread_join() %d is %d\n", i, rc);
+                fflush(NULL);
+                exit(EXIT_FAILURE);
+            }
+        }
+
+        for (i = 0; i < mixn; ++i)
+        {
+            printf("    Mixture %d: %4d rounds\n", i, mixdata[i]->rounds);
+            fflush(NULL);
         }
 
         NewCalcMixDens(mixA, mixn, probs);
         AveProb(aveprobs, mixn, probs, vlen);
 
-		printf("\n    mxp:");
-		for (j = 0; j < mixn; ++j)
-			printf(" % 6.4f", aveprobs[j]);
-		printf("\n");
+        printf("\n    mxp:");
+        for (j = 0; j < mixn; ++j)
+            printf(" % 6.4f", aveprobs[j]);
+        printf("\n");
 
-        if (CheckConvergenceMix(probs[0], oldprobs, vlen, algo->precision) == 1 && count > 5)
+        if (CheckConvergenceMix(probs[0], oldprobs, vlen, algo->precision) && count > 5)
             break;
 
         lineskip = 3 + mixn;
-		printf("\033[<%d>A", lineskip);
+        printf("\033[<%d>A", lineskip);
     }
 
     pthread_attr_destroy(&attr);
@@ -1095,10 +1093,10 @@ Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
 
     for (i = 0; i < mixn; ++i)
     {
-		if (algo->leastsquares == 1)
-			CalcNormResidualsLS(mixA[i]);
-		else
-			CalcNormResiduals(mixA[i]);
+        if (algo->leastsquares)
+            CalcNormResidualsLS(mixA[i]);
+        else
+            CalcNormResiduals(mixA[i]);
     }
 
     logL = 0.0;
@@ -1111,8 +1109,8 @@ Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
         logL += log(Lik);
     }
 
-    for (i = 0; i < mixn; ++i)
-        logL += CalcHierarchLogL(mixA[i]);
+//     for (i = 0; i < mixn; ++i)
+//         logL += CalcHierarchLogL(mixA[i]);
 
     AIC = logL;
     for (i = 0; i < mixn; ++i)
@@ -1146,38 +1144,19 @@ Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
 
 /* For superimposing to an alignment, we don't need to weight by occupancy
    since we are using pseudo-coordinates here from the E-M expectation step */
+   // DLT OP FIX comment
 static void
 CalcTranslations(CdsArray *scratchA, Algorithm *algo)
 {
     Cds        **cds = scratchA->cds;
     int             i;
 
-	for (i = 0; i < scratchA->cnum; ++i)
-	{
-		if (algo->alignment == 1 && algo->rounds < 3)
-			CenMassWtIpOcc(cds[i], scratchA->w);
-		else
-			CenMassWtIp(cds[i], scratchA->w);
-	}
-}
-
-
-static void
-MatDiagMultCdsMultMatDiag(Cds *outcds, const double *wtK, const Cds *cds)
-{
-    int             i;
-    double          wtKi;
-    const double   *x = (const double *) cds->x,
-                   *y = (const double *) cds->y,
-                   *z = (const double *) cds->z;
-
-    for (i = 0; i < cds->vlen; ++i)
+    for (i = 0; i < scratchA->cnum; ++i)
     {
-        wtKi = wtK[i];
-
-        outcds->x[i] = wtKi * x[i];
-        outcds->y[i] = wtKi * y[i];
-        outcds->z[i] = wtKi * z[i];
+        if (algo->alignment && algo->rounds < 3)
+            CenMassWtIpNu(cds[i], scratchA->w);
+        else
+            CenMassWtIp(cds[i], scratchA->w);
     }
 }
 
@@ -1192,25 +1171,25 @@ CalcRotations(CdsArray *cdsA)
     double          deviation = 0.0, deviation_sum = 0.0;
     int             i;
 
-	MatDiagMultCdsMultMatDiag(tcds, wts, avecds);
+    MatDiagMultCdsMultMatDiag(tcds, wts, avecds);
 
-	for (i = 0; i < cdsA->cnum; ++i)
-	{
-		/* note that the avecds are already multiplied by the weight matrices */
-		deviation = ProcGSLSVDvan(cds[i],
-									 tcds,
-									 cds[i]->matrix,
-									 cdsA->tmpmat3a,
-									 cdsA->tmpmat3b,
-									 cdsA->tmpmat3c,
-									 cdsA->tmpvec3a);
+    for (i = 0; i < cdsA->cnum; ++i)
+    {
+        /* note that the avecds are already multiplied by the weight matrices */
+        deviation = ProcGSLSVDvan(cds[i],
+                                     tcds,
+                                     cds[i]->matrix,
+                                     cdsA->tmpmat3a,
+                                     cdsA->tmpmat3b,
+                                     cdsA->tmpmat3c,
+                                     cdsA->tmpvec3a);
 
 /*      RotateCdsIp(cds[i], (const double **) cds[i]->matrix); */
 
-		/* find global rmsd and average cds (both held in structure) */
-		cds[i]->wRMSD_from_mean = sqrt(deviation / (3 * cdsA->vlen));
-		deviation_sum += deviation;
-	}
+        /* find global rmsd and average cds (both held in structure) */
+        cds[i]->wRMSD_from_mean = sqrt(deviation / (3 * cdsA->vlen));
+        deviation_sum += deviation;
+    }
 
     return(deviation_sum);
 }
@@ -1219,10 +1198,7 @@ CalcRotations(CdsArray *cdsA)
 static void
 HierarchVars(CdsArray *cdsA)
 {
-    int             i;
-    double          mean, mu, lambda, b, c, zeta, sigma;
-
-    switch(cdsA->algo->hierarch)
+    switch(algo->hierarch)
     {
         case 0:
             break;
@@ -1231,94 +1207,17 @@ HierarchVars(CdsArray *cdsA)
             /* This accounts for the fact that the smallest eigenvalue of the covariance
                matrix is always zero, i.e. the covariance matrix is necessarily of rank
                vlen - 1 */
-            if (cdsA->algo->rounds > 4)
+            if (algo->rounds > 4)
                 InvGammaFitEvals(cdsA, 1);
             else
                 InvGammaFitEvals(cdsA, 0);
 
-            if (cdsA->algo->verbose != 0)
-                printf("    HierarchVars() chi2:%f\n", cdsA->stats->hierarch_chi2);
-            break;
-
-        case 2:
-            InvGammaFitVars(cdsA, 1);
-            if (cdsA->algo->verbose != 0)
-                printf("    HierarchVars() chi2:%f\n", cdsA->stats->hierarch_chi2);
-            break;
-
-        case 3:
-            InvGamma1FitEvals(cdsA, 1);
-            break;
-
-        case 4:
-            InvGammaFitVars_minc(cdsA, 1.0, 1);
-            break;
-
-        case 5:
-            InvGammaMMFitVars(cdsA, &b, &c);
-            break;
-
-        case 6:
-            InvGammaStacyFitVars(cdsA, &b, &c);
-            break;
-
-        case 7:
-            for (i = 0; i < cdsA->vlen; ++i)
-                cdsA->var[i] = cdsA->CovMat[i][i];
-            cdsA->algo->covweight = 0;
-            cdsA->algo->varweight = 1;
-            InvGammaFitVars(cdsA, 1);
-            cdsA->algo->covweight = 1;
-            cdsA->algo->varweight = 0;
-            CovMat2CorMat(cdsA->CovMat, cdsA->vlen);
-            CorMat2CovMat(cdsA->CovMat, (const double *) cdsA->var, cdsA->vlen);
-            break;
-
-        case 8: /* ML fit of variances to a reciprocal inverse gaussian dist */
-            RecipInvGaussFitVars(cdsA, &mu, &lambda);
-            RecipInvGaussAdjustVars(cdsA, mu, lambda);
-            break;
-
-        case 9: /* ML fit of variances to a lognorml distribution */
-            LognormalFitVars(cdsA, &zeta, &sigma);
-            LognormalAdjustVars(cdsA, zeta, sigma);             
-            break;
-
-        case 10:
-            InvgaussFitVars(cdsA, &mean, &lambda);
-            InvgaussAdjustVars(cdsA, zeta, sigma);
-            break;
-
-        case 12: /* inv gamma fit to eigenvalues of covariance mat, but only weighting by variances */
-            cdsA->algo->covweight = 1;
-            cdsA->algo->varweight = 0;
-            if (cdsA->algo->alignment == 1)
-                CalcCovMatOcc(cdsA);
-            else
-                CalcCovMat(cdsA);
-            InvGammaFitEvals(cdsA, 1);
-            cdsA->algo->covweight = 0;
-            cdsA->algo->varweight = 1;
-            for (i = 0; i < cdsA->vlen; ++i)
-                cdsA->var[i] = cdsA->CovMat[i][i];
-            break;
-
-        case 13: /* inv gamma fit to eigenvalues of covariance mat, but only weighting by variances */
-            cdsA->algo->covweight = 1;
-            cdsA->algo->varweight = 0;
-            if (cdsA->algo->alignment == 1)
-                CalcCovMatOcc(cdsA);
-            else
-                CalcCovMat(cdsA);
-            InvGammaFitVars(cdsA, 0); /* no iterations */
-            cdsA->algo->covweight = 0;
-            cdsA->algo->varweight = 1;
-            for (i = 0; i < cdsA->vlen; ++i)
-                cdsA->var[i] = cdsA->CovMat[i][i];
+            if (algo->verbose)
+                printf("    HierarchVars() chi2:%f\n", stats->hierarch_chi2);
             break;
 
         default:
-            printf("\n  ERROR:  Bad -g option \"%d\" \n", cdsA->algo->hierarch);
+            printf("\n  ERROR:  Bad -g option \"%d\" \n", algo->hierarch);
             Usage(0);
             exit(EXIT_FAILURE);
             break;
@@ -1345,26 +1244,26 @@ CheckConvergenceInner(CdsArray *cdsA, const double precision)
 static int
 CheckConvergenceOuter(CdsArray *cdsA, int round, const double precision)
 {
-    Algorithm      *algo = cdsA->algo;
+
     int             i;
 
     if (round >= algo->iterations)
         return(1);
 
-    if (algo->abort == 1)
+    if (algo->abort)
         return(1);
 
-/*     else if (algo->alignment == 1 && round < 10) */
+/*     else if (algo->alignment && round < 10) */
 /*         return(0); */
     else if (round > 6)
     {
         /* if (Mat3FrobEq((const double **) mat1, (const double **) mat2, algo->precision) == 0) */
-        cdsA->stats->precision = 0.0;
+        stats->precision = 0.0;
         for (i = 0; i < cdsA->cnum; ++i)
-            cdsA->stats->precision += FrobDiffNormIdentMat((const double **) cdsA->cds[i]->matrix, 3);
-        cdsA->stats->precision /= cdsA->cnum;
+            stats->precision += FrobDiffNormIdentMat((const double **) cdsA->cds[i]->matrix, 3);
+        stats->precision /= cdsA->cnum;
 
-        if (cdsA->stats->precision > precision)
+        if (stats->precision > precision)
             return(0);
         else
             return(1);
@@ -1380,7 +1279,6 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
 {
     int             i, round, innerround;
     int             slxn; /* index of random coord to select as first */
-    double          deviation_sum = 0.0;
     const int       cnum = baseA->cnum;
     const int       vlen = baseA->vlen;
     double         *evals = malloc(3 * sizeof(double));
@@ -1388,7 +1286,6 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
     Statistics     *stats = NULL;
     Cds        **cds = NULL;
     Cds         *avecds = NULL;
-    Cds         *tcds = NULL;
     CdsArray    *scratchA = NULL;
 
     gsl_rng               *r2 = NULL;
@@ -1407,11 +1304,8 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
     CdsArrayCopy(scratchA, baseA);
 
     /* setup local aliases based on scratchA */
-    algo = scratchA->algo;
-    stats = scratchA->stats;
     cds = scratchA->cds;
     avecds = scratchA->avecds;
-    tcds = scratchA->tcds;
 
     memcpy(scratchA->w, probs, vlen * sizeof(double));
     memcpy(baseA->w, probs, vlen * sizeof(double));
@@ -1422,7 +1316,7 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
     stats->hierarch_p1 = 0.0;
     stats->hierarch_p2 = 0.0;
 
-    if (algo->embedave != 0)
+    if (algo->embedave)
     {
         printf("    Calculating distance matrix for embedding average ... \n");
         fflush(NULL);
@@ -1430,8 +1324,8 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
         CdsCopyAll(avecds, cds[0]);
         DistMatsAlloc(scratchA);
 
-        if (algo->alignment == 1)
-            CalcMLDistMatOcc(scratchA);
+        if (algo->alignment)
+            CalcMLDistMatNu(scratchA);
         else
             CalcMLDistMat(scratchA);
 
@@ -1453,7 +1347,7 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
         CdsCopyAll(avecds, baseA->cds[slxn]);
     }
 
-    if (algo->notrans == 0)
+    if (algo->dotrans)
     {
         CenMassWtIp(avecds, scratchA->w);
         ApplyCenterIp(avecds);
@@ -1463,8 +1357,8 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
        (1) First calculates the translations
        (2) Does inner loop -- calc rotations and average till convergence
        (3) Holding the superposition constant, calculates the covariance
-           matrices and corresponding weight matrices, looping till 
-           convergence when using a dimensional/axial covariance matrix 
+           matrices and corresponding weight matrices, looping till
+           convergence when using a dimensional/axial covariance matrix
     */
     round = 0;
     while(1)
@@ -1476,7 +1370,7 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
 /*         fflush(NULL); */
 
         ++round;
-        baseA->algo->rounds = algo->rounds = round;
+        algo->rounds = round;
 
         /* Find weighted center and translate all cds */
         CalcTranslations(scratchA, algo);
@@ -1488,7 +1382,7 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
             memcpy(cds[i]->translation, cds[i]->center, 3 * sizeof(double));
 
         /* when superimposing to an alignemnt, initially iterate into unwted LS for a few rounds */
-        if (algo->alignment == 1 && round < 5)
+        if (algo->alignment && round < 5)
             memsetd(scratchA->w, 1.0, vlen);
 
         /* Inner loop:
@@ -1509,13 +1403,13 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
                 MatCpySym(cds[i]->last_matrix, (const double **) cds[i]->matrix, 3);
 
             /* find the optimal rotation matrices */
-            if (algo->alignment == 1 /* && (round == 1 || cnum == 2) */)
-                deviation_sum = CalcRotationsOcc(scratchA);
+            if (algo->alignment /* && (round == 1 || cnum == 2) */)
+                CalcRotationsNu(scratchA);
             else
-                deviation_sum = CalcRotations(scratchA);
+                CalcRotations(scratchA);
 
             if (innerround == 1 &&
-                CheckConvergenceOuter(scratchA, round, algo->precision) == 1)
+                CheckConvergenceOuter(scratchA, round, algo->precision))
                    goto outsidetheloops;
 
             /* rotate the scratch cds with new rotation matrix */
@@ -1523,17 +1417,17 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
                 RotateCdsIp(cds[i], (const double **) cds[i]->matrix);
 
             /* find global rmsd and average cds (both held in structure) */
-			if (algo->alignment == 1)
-			{
-				AveCdsOcc(scratchA);
-				EM_MissingCds(scratchA);
-			}
-			else
-			{
-				AveCds(scratchA);
-			}
+            if (algo->alignment)
+            {
+                AveCdsNu(scratchA);
+                EM_MissingCds(scratchA);
+            }
+            else
+            {
+                AveCds(scratchA);
+            }
 
-            stats->wRMSD_from_mean = sqrt(deviation_sum / (3 * vlen * cnum));
+            //stats->wRMSD_from_mean = sqrt(deviation_sum / (3 * vlen * cnum));
 
             if (innerround > 160)
             {
@@ -1546,7 +1440,7 @@ MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
 
         /* Weighting by dimensional, axial Xi covariance matrix, here diagonal. */
         /* Holding the superposition constant, calculates the covariance
-           matrices and corresponding weight matrices, looping till 
+           matrices and corresponding weight matrices, looping till
            convergence. */
         CalcCovariances(scratchA);
 
@@ -1578,15 +1472,15 @@ static void
 CalcWtsMix(CdsArray *cdsA, const double *probs)
 {
     int             i;
-    Algorithm      *algo = cdsA->algo;
+
     double         *variance = cdsA->var;
     double         *weight = cdsA->w;
     const int       vlen = cdsA->vlen;
 
-    if (algo->noave == 0)
+    if (algo->doave)
         AveCds(cdsA);
 
-    if (algo->leastsquares != 0)
+    if (algo->leastsquares)
     {
         for (i = 0; i < vlen; ++i)
             weight[i] = probs[i];
@@ -1594,12 +1488,8 @@ CalcWtsMix(CdsArray *cdsA, const double *probs)
         return;
     }
 
-    if (algo->varweight != 0)
+    if (algo->varweight)
     {
-        for (i = 0; i < vlen; ++i)
-            if (variance[i] < probs[i] * algo->constant)
-                variance[i] = probs[i] * algo->constant;
-
         HierarchVars(cdsA);
 
         for (i = 0; i < vlen; ++i)
@@ -1612,6 +1502,4 @@ CalcWtsMix(CdsArray *cdsA, const double *probs)
                 weight[i] =  probs[i] / variance[i];
         }
     }
-
-    /* cdsA->stats->wtnorm = NormalizeWeights(weight, vlen); */
 }
