@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <float.h>
+#include <pthread.h>
 #include "CovMat.h"
 #include "DLTutils.h"
 #include "Error.h"
@@ -37,15 +38,20 @@
 #include "pdbIO.h"
 #include "pdbUtils.h"
 #include "ProcGSLSVD.h"
-#include "ProcGSLSVDOcc.h"
+#include "ProcGSLSVDNu.h"
 #include "Embed.h"
 #include "FragDist.h"
 #include "CovMat.h"
 #include "RandCds.h"
 #include "msa.h"
 #include "MultiPose2MSA.h"
-
+#include "Threads.h"
+#include "ProcGSLSVD.h"
+#include "ProcGSLSVDNu.h"
+#include "qcprot.h"
+#include "GibbsMet.h"
+#include "internmat.h"
 #include "DLTmath.h"
-#include <gsl/gsl_rng.h>
 #include "distfit.h"
+#include <gsl/gsl_rng.h>
 
