@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,15 +32,9 @@ CalcPCA(CdsArray *cdsA);
 void
 Calc3NPCA(CdsArray *cdsA);
 
-void
-CalcStructPCA(CdsArray *cdsA);
-
 void
 WritePCAFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
 
-void
-WriteModelPCAFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
-
 void
 WritePCAMorphFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
 
