@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,14 +26,18 @@
 #ifndef PDBCOORDS_SEEN
 #define PDBCOORDS_SEEN
 
-#include "DLTmath.h"
 #include "msa.h"
 #include "Cds.h"
 
 
+typedef struct Seq2PDB Seq2PDB;
+typedef struct PDBCds PDBCds;
+typedef struct PDBCdsArray PDBCdsArray;
+
+
 /* A structure for mapping sequence names in an alignment to their corresponding
    pdbfiles */
-typedef struct Seq_2_PDB
+struct Seq2PDB
 {
     int             seqnum;
     char          **pdbfile_name;
@@ -45,17 +49,20 @@ typedef struct Seq_2_PDB
     int            *map;
     MSA            *msa;
     int            *singletons;
-} Seq2PDB;
+};
 
 
 /* PDBCds is mostly for reading/writing PDB files */
-typedef struct PDB_Cds
+struct PDBCds
 {
     char            filename[FILENAME_MAX];
     int             model;
+
+    int             vlen; /* number of coordinates */
+
     double        **matrix;
     double         *translation;
-    int             vlen; /* number of coordinates */
+    double          scale;
 
     /* PDB ATOM/HETATM fields */
     char          **record; /* ATOM or HETATM */
@@ -77,6 +84,8 @@ typedef struct PDB_Cds
     char          **element;
     char          **charge;
 
+    int            *nu;
+
     /* not to be accessed - for space only */
     char           *record_space;
     char           *name_space;
@@ -84,20 +93,20 @@ typedef struct PDB_Cds
     char           *segID_space;
     char           *element_space;
     char           *charge_space;
-} PDBCds;
+};
 
 
-typedef struct PDB_Cds_Array
+struct PDBCdsArray
 {
-    PDBCds     **cds;     /* pointer to an array of cnum pointers to Cds */
-    PDBCds      *avecds;  /* average Cds of all in CdsArray */
-    struct Cds_Array    *cdsA;       /* associated CdsArray - do not free */
-    struct Cds_Array    *scratchA;   /* do not free */
-    int             vlen;       /* number of coordinates */
-    int             cnum;       /* number of Cds in array */
-    int            *upper, *lower;
-    int             range_num;
-    Seq2PDB        *seq2pdb;
-} PDBCdsArray;
+    PDBCds            **cds;        /* pointer to an array of cnum pointers to Cds */
+    PDBCds             *avecds;     /* average Cds of all in CdsArray */
+    struct CdsArray    *cdsA;       /* associated CdsArray - do not free */
+    struct CdsArray    *scratchA;   /* do not free */
+    int                 vlen;       /* number of coordinates */
+    int                 cnum;       /* number of Cds in array */
+    int                *upper, *lower;
+    int                 range_num;
+    Seq2PDB            *seq2pdb;
+};
 
 #endif
