@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,16 +37,14 @@
 
 
 static double
-CalcE0Cov(const Cds *cds1, const Cds *cds2,
-          const double *axesw);
+CalcE0Cov(const Cds *cds1, const Cds *cds2);
 
 static void
 CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
       const double *weights);
 
 static void
-CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
-         const double **WtMat, const double *axesw);
+CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat, const double **WtMat);
 
 static int
 CalcGSLSVD(double **Rmat, double **Umat, double *sigma, double **VTmat);
@@ -56,15 +54,15 @@ CalcRotMat(double **rotmat, double **Umat, double **VTmat);
 
 
 static double
-CalcMahFrobInnProd(const Cds *cds, const double *weights, const double *axesw)
-{   
+CalcMahFrobInnProd(const Cds *cds, const double *weights)
+{
     int             i;
     double          sum;
     const double   *x = (const double *) cds->x,
                    *y = (const double *) cds->y,
                    *z = (const double *) cds->z;
     double          xi, yi, zi;
-    const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
+
 
     sum = 0.0;
     i = cds->vlen;
@@ -74,8 +72,7 @@ CalcMahFrobInnProd(const Cds *cds, const double *weights, const double *axesw)
         yi = *y++;
         zi = *z++;
 
-        sum += *weights++ *
-               (axeswx * (xi * xi) + axeswy * (yi * yi) + axeswz * (zi * zi));
+        sum += *weights++ * ((xi * xi) + (yi * yi) + (zi * zi));
     }
 
     return(sum);
@@ -84,7 +81,7 @@ CalcMahFrobInnProd(const Cds *cds, const double *weights, const double *axesw)
 
 static double
 CalcInnProdNorm(const Cds *cds)
-{   
+{
     int             i;
     double          sum;
     const double   *x = (const double *) cds->x,
@@ -108,8 +105,33 @@ CalcInnProdNorm(const Cds *cds)
 
 
 static double
-CalcMahFrobInnProdRot(const Cds *cds, const double **rmat, const double *weights, const double *axesw)
-{   
+CalcInnProdNorm2(const double **cds, const int len)
+{
+    int             i;
+    double          sum;
+    const double   *x = (const double *) cds[0],
+                   *y = (const double *) cds[1],
+                   *z = (const double *) cds[2];
+    double          xi, yi, zi;
+
+    sum = 0.0;
+    i = len;
+    while(i-- > 0)
+    {
+        xi = *x++;
+        yi = *y++;
+        zi = *z++;
+
+        sum += xi * xi + yi * yi + zi * zi;
+    }
+
+    return(sum);
+}
+
+
+static double
+CalcMahFrobInnProdRot(const Cds *cds, const double **rmat, const double *weights)
+{
     int             i;
     double          sum;
     const double   *x = (const double *) cds->x,
@@ -119,7 +141,7 @@ CalcMahFrobInnProdRot(const Cds *cds, const double **rmat, const double *weights
     const double    rmat00 = rmat[0][0], rmat01 = rmat[0][1], rmat02 = rmat[0][2],
                     rmat10 = rmat[1][0], rmat11 = rmat[1][1], rmat12 = rmat[1][2],
                     rmat20 = rmat[2][0], rmat21 = rmat[2][1], rmat22 = rmat[2][2];
-    const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
+
 
     sum = 0.0;
     i = cds->vlen;
@@ -133,8 +155,7 @@ CalcMahFrobInnProdRot(const Cds *cds, const double **rmat, const double *weights
         yir = xi * rmat01 + yi * rmat11 + zi * rmat21;
         zir = xi * rmat02 + yi * rmat12 + zi * rmat22;
 
-        sum += *weights++ *
-               (axeswx * (xir * xir) + axeswy * (yir * yir) + axeswz * (zir * zir));
+        sum += *weights++ * ((xir * xir) + (yir * yir) + (zir * zir));
     }
 
     return(sum);
@@ -142,9 +163,8 @@ CalcMahFrobInnProdRot(const Cds *cds, const double **rmat, const double *weights
 
 
 static double
-CalcE0Cov(const Cds *cds1, const Cds *cds2,
-          const double *axesw)
-{   
+CalcE0Cov(const Cds *cds1, const Cds *cds2)
+{
     int             i;
     double          sum;
     const double   *x2 = (const double *) cds2->x,
@@ -161,7 +181,7 @@ CalcE0Cov(const Cds *cds1, const Cds *cds2,
                    *cz1 = (const double *) cds1->covz;
     double          x1i, y1i, z1i, x2i, y2i, z2i,
                     cx1i, cy1i, cz1i, cx2i, cy2i, cz2i;
-    const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
+
 
     sum = 0.0;
     i = cds1->vlen;
@@ -181,9 +201,9 @@ CalcE0Cov(const Cds *cds1, const Cds *cds2,
         cy2i = *cy2++;
         cz2i = *cz2++;
 
-        sum += (axeswx * (cx1i * x1i + cx2i * x2i) +
-                axeswy * (cy1i * y1i + cy2i * y2i) +
-                axeswz * (cz1i * z1i + cz2i * z2i));
+        sum += (cx1i * x1i + cx2i * x2i) +
+               (cy1i * y1i + cy2i * y2i) +
+               (cz1i * z1i + cz2i * z2i);
     }
 
     return(sum);
@@ -225,11 +245,11 @@ CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -262,9 +282,9 @@ CalcRvan(const Cds *cds1, const Cds *cds2, double **Rmat)
                     Rmat10, Rmat11, Rmat12,
                     Rmat20, Rmat21, Rmat22;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
 
-    Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
+    Rmat00 = Rmat01 = Rmat02 =
+    Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
 
     i = cds1->vlen;
@@ -281,11 +301,11 @@ CalcRvan(const Cds *cds1, const Cds *cds2, double **Rmat)
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -304,8 +324,62 @@ CalcRvan(const Cds *cds1, const Cds *cds2, double **Rmat)
 
 
 static void
-CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
-         const double **WtMat, const double *axesw)
+CalcRvan2(const double **cds1, const double **cds2, const int len, double **Rmat)
+{
+    int             i;
+    const double   *x1 = cds1[0],
+                   *y1 = cds1[1],
+                   *z1 = cds1[2];
+    const double   *x2 = cds2[0],
+                   *y2 = cds2[1],
+                   *z2 = cds2[2];
+    double          x2i, y2i, z2i, x1i, y1i, z1i;
+    double          Rmat00, Rmat01, Rmat02,
+                    Rmat10, Rmat11, Rmat12,
+                    Rmat20, Rmat21, Rmat22;
+
+    Rmat00 = Rmat01 = Rmat02 =
+    Rmat10 = Rmat11 = Rmat12 =
+    Rmat20 = Rmat21 = Rmat22 = 0.0;
+
+    i = len;
+    while(i-- > 0)
+    {
+        x1i = *x1++;
+        y1i = *y1++;
+        z1i = *z1++;
+
+        x2i = *x2++;
+        y2i = *y2++;
+        z2i = *z2++;
+
+        Rmat00 += x2i * x1i;
+        Rmat01 += x2i * y1i;
+        Rmat02 += x2i * z1i;
+
+        Rmat10 += y2i * x1i;
+        Rmat11 += y2i * y1i;
+        Rmat12 += y2i * z1i;
+
+        Rmat20 += z2i * x1i;
+        Rmat21 += z2i * y1i;
+        Rmat22 += z2i * z1i;
+    }
+
+    Rmat[0][0] = Rmat00;
+    Rmat[0][1] = Rmat01;
+    Rmat[0][2] = Rmat02;
+    Rmat[1][0] = Rmat10;
+    Rmat[1][1] = Rmat11;
+    Rmat[1][2] = Rmat12;
+    Rmat[2][0] = Rmat20;
+    Rmat[2][1] = Rmat21;
+    Rmat[2][2] = Rmat22;
+}
+
+
+static void
+CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat, const double **WtMat)
 {
     int             i;
     const double   *x2 = (const double *) cds2->covx,
@@ -314,9 +388,6 @@ CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
     const double   *x1 = (const double *) cds1->x,
                    *y1 = (const double *) cds1->y,
                    *z1 = (const double *) cds1->z;
-    const double    axeswx = sqrt(axesw[0]),
-                    axeswy = sqrt(axesw[1]),
-                    axeswz = sqrt(axesw[2]);
     double          x2i, y2i, z2i, x1i, y1i, z1i;
     double          Rmat00, Rmat01, Rmat02,
                     Rmat10, Rmat11, Rmat12,
@@ -325,27 +396,25 @@ CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
-
     i = cds1->vlen;
     while(i-- > 0)
     {
-        x2i = axeswx * *x2++;
-        y2i = axeswy * *y2++;
-        z2i = axeswz * *z2++;
+        x2i = *x2++;
+        y2i = *y2++;
+        z2i = *z2++;
 
-        x1i = axeswx * *x1++;
-        y1i = axeswy * *y1++;
-        z1i = axeswz * *z1++;
+        x1i = *x1++;
+        y1i = *y1++;
+        z1i = *z1++;
 
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -387,9 +456,11 @@ CalcGSLSVD(double **Rmat, double **Umat, double *sigma, double **VTmat)
 
     //return(dgesvd_opt_dest(Rmat, 3, 3, Umat, sigma, VTmat));
 
-    svdGSLDest(Rmat, 3, sigma, VTmat);
+    // GSL says Jacobi SVD is more accurate the Golub
+    svdGSLJacobiDest(Rmat, 3, sigma, VTmat);
     Mat3TransposeIp(VTmat);
     Mat3Cpy(Umat, (const double **) Rmat);
+
     return(1);
 
 /*     printf("\n\n **********************************************************************:"); */
@@ -455,7 +526,7 @@ CalcGSLSVD(double **Rmat, double **Umat, double *sigma, double **VTmat)
 /* Takes U and V^t on input, calculates R = VU^t */
 static int
 CalcRotMat(double **rotmat, double **Umat, double **Vtmat)
-{   
+{
     int         i, j, k;
     double      det;
 
@@ -496,7 +567,7 @@ CalcRotMat(double **rotmat, double **Umat, double **Vtmat)
    rmsd = sqrt(E/atom_num)  */
 double
 ProcGSLSVDvan(const Cds *cds1, const Cds *cds2, double **rotmat,
-                 double **Rmat, double **Umat, double **VTmat, double *sigma)
+              double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev, term1, term2;
 
@@ -531,6 +602,46 @@ ProcGSLSVDvan(const Cds *cds1, const Cds *cds2, double **rotmat,
 }
 
 
+/* returns sum of squared residuals, E
+   rmsd = sqrt(E/atom_num)  */
+double
+ProcGSLSVDvan2(const double **cds1, const double **cds2, const int len, double **rotmat,
+               double **Rmat, double **Umat, double **VTmat, double *sigma,
+               double *norm1, double *norm2, double *innprod)
+{
+    double          det;
+
+    *norm1 = CalcInnProdNorm2(cds1, len);
+    *norm2 = CalcInnProdNorm2(cds2, len);
+    CalcRvan2(cds1, cds2, len, Rmat);
+    CalcGSLSVD(Rmat, Umat, sigma, VTmat);
+    det = CalcRotMat(rotmat, Umat, VTmat);
+
+//     VerifyRotMat(rotmat, 1e-5);
+/*     printf("\n*************** sumdev = %8.2f ", sumdev); */
+/*     printf("\nrotmat:"); */
+/*     write_C_mat((const double **)rotmat, 3, 8, 0); */
+
+    if (det < 0)
+        *innprod = sigma[0] + sigma[1] - sigma[2];
+    else
+        *innprod = sigma[0] + sigma[1] + sigma[2];
+
+/*     printf("\nRmat:"); */
+/*     write_C_mat((const double **)Rmat, 3, 8, 0); */
+/*     printf("\nUmat:"); */
+/*     write_C_mat((const double **)Umat, 3, 8, 0); */
+/*     printf("\nVTmat:"); */
+/*     write_C_mat((const double **)VTmat, 3, 8, 0); */
+/*     int i; */
+/*     for (i = 0; i < 3; ++i) */
+/*         printf("\nsigma[%d] = %8.2f ", i, sigma[i]); */
+
+    return(*norm1 + *norm2 - 2.0 * *innprod);
+}
+
+
+
 static void
 CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
 {
@@ -546,7 +657,6 @@ CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
                     Rmat10, Rmat11, Rmat12,
                     Rmat20, Rmat21, Rmat22;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
 
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
@@ -565,11 +675,11 @@ CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -589,7 +699,7 @@ CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
 
 static double
 CalcInnProdNormFrag(const FragCds *cds)
-{   
+{
     int             i;
     double          sum;
     const double   *x = (const double *) cds->x,
@@ -616,7 +726,7 @@ CalcInnProdNormFrag(const FragCds *cds)
    rmsd = sqrt(E/atom_num)  */
 double
 ProcGSLSVDFrag(const FragCds *frag1, const FragCds *frag2, double **rotmat,
-                  double **Rmat, double **Umat, double **VTmat, double *sigma)
+               double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev, term1, term2;
 
@@ -639,16 +749,16 @@ ProcGSLSVDFrag(const FragCds *frag1, const FragCds *frag2, double **rotmat,
 
 double
 ProcGSLSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
-              const double *weights, const double *axesw,
-              double **Rmat, double **Umat, double **VTmat, double *sigma)
+           const double *weights,
+           double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev, term1, term2;
 
-    term1 = CalcMahFrobInnProd(cds2, weights, axesw);
+    term1 = CalcMahFrobInnProd(cds2, weights);
     CalcR(cds1, cds2, Rmat, weights);
     CalcGSLSVD(Rmat, Umat, sigma, VTmat);
     det = CalcRotMat(rotmat, Umat, VTmat);
-    term2 = CalcMahFrobInnProdRot(cds1, (const double **) rotmat, weights, axesw);
+    term2 = CalcMahFrobInnProdRot(cds1, (const double **) rotmat, weights);
     sumdev = term1 + term2;
 
 /*     VerifyRotMat(rotmat, 1e-5); */
@@ -679,7 +789,7 @@ ProcGSLSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
    rmsd = sqrt(E/atom_num)  */
 double
 ProcGSLSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
-                 const double **WtMat, const double *axesw, double **Rmat,
+                 const double **WtMat, double **Rmat,
                  double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev = 0.0;
@@ -687,8 +797,8 @@ ProcGSLSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
     CalcCovCds(cds1, WtMat);
     CalcCovCds(cds2, WtMat);
 
-    sumdev = CalcE0Cov(cds1, cds2, axesw);
-    CalcRCov(cds1, cds2, Rmat, WtMat, axesw);
+    sumdev = CalcE0Cov(cds1, cds2);
+    CalcRCov(cds1, cds2, Rmat, WtMat);
     CalcGSLSVD(Rmat, Umat, sigma, VTmat);
     det = CalcRotMat(rotmat, Umat, VTmat);
 
