@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,19 +32,22 @@ double
 ProcGSLSVDvan(const Cds *cds1, const Cds *cds2, double **rotmat,
               double **Rmat, double **Umat, double **VTmat, double *sigma);
 
+double
+ProcGSLSVDvan2(const double **cds1, const double **cds2, const int len, double **rotmat,
+               double **Rmat, double **Umat, double **VTmat, double *sigma,
+               double *norm1, double *norm2, double *innprod);
+
 double
 ProcGSLSVDFrag(const FragCds *frag1, const FragCds *frag2, double **rotmat,
                   double **Rmat, double **Umat, double **VTmat, double *sigma);
 
 double
-ProcGSLSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
-              const double *weights, const double *axesw,
-              double **Rmat, double **Umat, double **VTmat, double *sigma);
+ProcGSLSVD(const Cds *cds1, const Cds *cds2, double **rotmat, const double *weights,
+           double **Rmat, double **Umat, double **VTmat, double *sigma);
 
 double
-ProcGSLSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
-                 const double **covmat, const double *axesw,
-                 double **Rmat, double **Umat, double **VTmat,
-                 double *sigma);
+ProcGSLSVDCov(Cds *cds1, Cds *cds2, double **rotmat, const double **covmat,
+              double **Rmat, double **Umat, double **VTmat,
+              double *sigma);
 
 #endif
