@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,20 +35,16 @@
 #include "ProcJacobiSVD.h"
 
 static double
-CalcE0(const Cds *cds1, const Cds *cds2,
-          const double *weights, const double *axesw);
+CalcE0(const Cds *cds1, const Cds *cds2, const double *weights);
 
 static double
-CalcE0Cov(const Cds *cds1, const Cds *cds2,
-             const double *axesw);
+CalcE0Cov(const Cds *cds1, const Cds *cds2);
 
 static void
-CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
-         const double *weights, const double *axesw);
+CalcR(const Cds *cds1, const Cds *cds2, double **Rmat, const double *weights);
 
 static void
-CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
-            const double **covmat, const double *axesw);
+CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat, const double **covmat);
 
 static int
 CalcJacobiSVD(double **a, double **U, double *z, double **V, double tol);
@@ -57,9 +53,8 @@ static int
 CalcRotMat(double **rotmat, double **Umat, double **VTmat);
 
 static double
-CalcE0(const Cds *cds1, const Cds *cds2,
-         const double *weights, const double *axesw)
-{   
+CalcE0(const Cds *cds1, const Cds *cds2, const double *weights)
+{
     int             i;
     double          sum;
     const double   *x1 = (const double *) cds1->x,
@@ -69,7 +64,6 @@ CalcE0(const Cds *cds1, const Cds *cds2,
                    *y2 = (const double *) cds2->y,
                    *z2 = (const double *) cds2->z;
     double          x1i, y1i, z1i, x2i, y2i, z2i;
-    const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
 /* #include "pdbIO.h" */
 /* PrintCds((Cds *)cds1); */
 /* PrintCds((Cds *)cds2); */
@@ -85,9 +79,9 @@ CalcE0(const Cds *cds1, const Cds *cds2,
         y2i = *y2++;
         z2i = *z2++;
         sum +=  *weights++ *
-               (axeswx * (x1i * x1i + x2i * x2i) +
-                axeswy * (y1i * y1i + y2i * y2i) +
-                axeswz * (z1i * z1i + z2i * z2i));
+               ((x1i * x1i + x2i * x2i) +
+                (y1i * y1i + y2i * y2i) +
+                (z1i * z1i + z2i * z2i));
 /* printf("\nsum = %d %f %f", i, weight, sum); */
     }
 /* exit(0); */
@@ -96,9 +90,8 @@ CalcE0(const Cds *cds1, const Cds *cds2,
 
 
 static double
-CalcE0Cov(const Cds *cds1, const Cds *cds2,
-             const double *axesw)
-{   
+CalcE0Cov(const Cds *cds1, const Cds *cds2)
+{
     int             i;
     double          sum;
     const double   *x2 = (const double *) cds2->x,
@@ -115,7 +108,7 @@ CalcE0Cov(const Cds *cds1, const Cds *cds2,
                    *cz1 = (const double *) cds1->covz;
     double          x1i, y1i, z1i, x2i, y2i, z2i,
                     cx1i, cy1i, cz1i, cx2i, cy2i, cz2i;
-    const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
+
 
     sum = 0.0;
     i = cds1->vlen;
@@ -135,9 +128,9 @@ CalcE0Cov(const Cds *cds1, const Cds *cds2,
         cy2i = *cy2++;
         cz2i = *cz2++;
 
-        sum += (axeswx * (cx1i * x1i + cx2i * x2i) +
-                axeswy * (cy1i * y1i + cy2i * y2i) +
-                axeswz * (cz1i * z1i + cz2i * z2i));
+        sum += ((cx1i * x1i + cx2i * x2i) +
+                (cy1i * y1i + cy2i * y2i) +
+                (cz1i * z1i + cz2i * z2i));
     }
 
     return(sum);
@@ -147,8 +140,7 @@ CalcE0Cov(const Cds *cds1, const Cds *cds2,
 /* This function assumes that the coordinates have been centered previously
    Use CenMass() and ApplyCenter() */
 static void
-CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
-         const double *weights, const double *axesw)
+CalcR(const Cds *cds1, const Cds *cds2, double **Rmat, const double *weights)
 {
     int             i;
     double          weight;
@@ -158,9 +150,6 @@ CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
     const double   *x1 = (const double *) cds1->x,
                    *y1 = (const double *) cds1->y,
                    *z1 = (const double *) cds1->z;
-    const double    axeswx = sqrt(axesw[0]),
-                    axeswy = sqrt(axesw[1]),
-                    axeswz = sqrt(axesw[2]);
     double          x2i, y2i, z2i, x1i, y1i, z1i;
     double          Rmat00, Rmat01, Rmat02,
                     Rmat10, Rmat11, Rmat12,
@@ -169,29 +158,27 @@ CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
-
     i = cds1->vlen;
     while(i-- > 0)
     {
         weight = *weights++;
 
-        x2i = axeswx * *x2++;
-        y2i = axeswy * *y2++;
-        z2i = axeswz * *z2++;
+        x2i = *x2++;
+        y2i = *y2++;
+        z2i = *z2++;
 
-        x1i = axeswx * *x1++;
-        y1i = axeswy * *y1++;
-        z1i = axeswz * *z1++;
+        x1i = *x1++;
+        y1i = *y1++;
+        z1i = *z1++;
 
         Rmat00 += weight * x2i * x1i;
         Rmat01 += weight * x2i * y1i;
         Rmat02 += weight * x2i * z1i;
-        
+
         Rmat10 += weight * y2i * x1i;
         Rmat11 += weight * y2i * y1i;
         Rmat12 += weight * y2i * z1i;
-        
+
         Rmat20 += weight * z2i * x1i;
         Rmat21 += weight * z2i * y1i;
         Rmat22 += weight * z2i * z1i;
@@ -224,7 +211,6 @@ CalcRvan(const Cds *cds1, const Cds *cds2, double **Rmat)
                     Rmat10, Rmat11, Rmat12,
                     Rmat20, Rmat21, Rmat22;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
 
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
@@ -243,11 +229,11 @@ CalcRvan(const Cds *cds1, const Cds *cds2, double **Rmat)
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -280,7 +266,6 @@ CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
                     Rmat10, Rmat11, Rmat12,
                     Rmat20, Rmat21, Rmat22;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
 
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
@@ -299,11 +284,11 @@ CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -322,8 +307,7 @@ CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
 
 
 static void
-CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
-            const double **covmat, const double *axesw)
+CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat, const double **covmat)
 {
     int             i;
     const double   *x2 = (const double *) cds2->covx,
@@ -332,9 +316,6 @@ CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
     const double   *x1 = (const double *) cds1->x,
                    *y1 = (const double *) cds1->y,
                    *z1 = (const double *) cds1->z;
-    const double    axeswx = sqrt(axesw[0]),
-                    axeswy = sqrt(axesw[1]),
-                    axeswz = sqrt(axesw[2]);
     double          x2i, y2i, z2i, x1i, y1i, z1i;
     double          Rmat00, Rmat01, Rmat02,
                     Rmat10, Rmat11, Rmat12,
@@ -343,27 +324,25 @@ CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
 
-   /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
-
     i = cds1->vlen;
     while(i-- > 0)
     {
-        x2i = axeswx * *x2++;
-        y2i = axeswy * *y2++;
-        z2i = axeswz * *z2++;
+        x2i = *x2++;
+        y2i = *y2++;
+        z2i = *z2++;
 
-        x1i = axeswx * *x1++;
-        y1i = axeswy * *y1++;
-        z1i = axeswz * *z1++;
+        x1i = *x1++;
+        y1i = *y1++;
+        z1i = *z1++;
 
         Rmat00 += x2i * x1i;
         Rmat01 += x2i * y1i;
         Rmat02 += x2i * z1i;
-        
+
         Rmat10 += y2i * x1i;
         Rmat11 += y2i * y1i;
         Rmat12 += y2i * z1i;
-        
+
         Rmat20 += z2i * x1i;
         Rmat21 += z2i * y1i;
         Rmat22 += z2i * z1i;
@@ -385,7 +364,7 @@ CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
    Calculates the SVD of a, a = UzV^t .
 
    This is pulled almost verbatim from
-   John Nash, _Compact Numerical Methods for Computers_, 1979, Wiley, NY 
+   John Nash, _Compact Numerical Methods for Computers_, 1979, Wiley, NY
    Chapter 3, algorithm 1, pp 30-31.
 
    It is based on the method of Chartres:
@@ -397,11 +376,11 @@ CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
    Decomposition and algebraic eigenproblem."  Comput. J. 18:74-76.
 
    I have added a convergence criterion based on the sum of cross-products
-   after a sweep -- it should be 0 if the matrix is orthogonal. 
+   after a sweep -- it should be 0 if the matrix is orthogonal.
    I also made some adjustments for C-style indexing.
    Unlike Nash's implementation, this function returns the
    transpose of V, same behavior as LAPACK DGESVD.
-   Singular values are ordered largest to smallest and stored in z. 
+   Singular values are ordered largest to smallest and stored in z.
    The matrix A is preserved (unlike in Nash 1979 where it is overwritten
    with U) */
 static int
@@ -586,11 +565,11 @@ CalcJacobiSVDpp(double **A, double **U, double *z, double **Vt, double tol)
             p = 0.0;
             for (i = 0; i < 3; ++i)
                 p += Vt[ss][i] * Vt[ss][i];
-    
+
             q = 0.0;
             for (i = 0; i < 3; ++i)
                 q += Vt[ss+1][i] * Vt[ss+1][i];
-    
+
             if (p < q)
             {
                 for (i = 0; i < 3; ++i)
@@ -619,12 +598,12 @@ CalcJacobiSVDpp(double **A, double **U, double *z, double **Vt, double tol)
                         q += g * g;
                         r += h * h;
                     }
-    
+
                     pp = p*p;
                     qr = q*r;
                     orth = pp / qr;
                     /* orthsum += orth; */
-    
+
                     if (r > eps && qr > eps && orth > eps)
                     {
                         if (q < r)
@@ -640,7 +619,7 @@ CalcJacobiSVDpp(double **A, double **U, double *z, double **Vt, double tol)
                             c = sqrt(0.5 * (v + q) / v);
                             s = p / (v * c);
                         }
-    
+
                         /* step 9 - apply rotation to a */
                         for (i = 0; i < 3; ++i)
                         {
@@ -649,7 +628,7 @@ CalcJacobiSVDpp(double **A, double **U, double *z, double **Vt, double tol)
                             Vt[j][i] =  (r * c) + (h * s);
                             Vt[k][i] = -(r * s) + (h * c);
                         }
-    
+
                         /* step 10 - apply rotation to V */
                         for (i = 0; i < 3; ++i)
                         {
@@ -680,7 +659,7 @@ CalcJacobiSVDpp(double **A, double **U, double *z, double **Vt, double tol)
                         q += g * g;
                         r += h * h;
                     }
-    
+
                     orthsum += (p*p) / (q*r);
                 }
             }
@@ -717,7 +696,7 @@ CalcJacobiSVDpp(double **A, double **U, double *z, double **Vt, double tol)
 /* Takes U and V^t on input, calculates R = VU^t */
 static int
 CalcRotMat(double **rotmat, double **Umat, double **Vtmat)
-{   
+{
     int         i, j, k;
     double      det;
 
@@ -758,14 +737,14 @@ CalcRotMat(double **rotmat, double **Umat, double **Vtmat)
    rmsd = sqrt(E/atom_num)  */
 double
 ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
-                 const double *weights, const double *axesw,
+                 const double *weights,
                  double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev;
 
-    sumdev = CalcE0(cds1, cds2, weights, axesw);
+    sumdev = CalcE0(cds1, cds2, weights);
     /* printf("\n # sumdev = %8.2f ", sumdev); */
-    CalcR(cds1, cds2, Rmat, weights, axesw);
+    CalcR(cds1, cds2, Rmat, weights);
     CalcJacobiSVD(Rmat, Umat, sigma, VTmat, 1e-8);
     det = CalcRotMat(rotmat, Umat, VTmat);
 
@@ -794,14 +773,14 @@ ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
 
 // static double
 // CalcInnProdNorm(const Cds *cds)
-// {   
+// {
 //     int             i;
 //     double          sum;
 //     const double   *x = (const double *) cds->x,
 //                    *y = (const double *) cds->y,
 //                    *z = (const double *) cds->z;
 //     double          xi, yi, zi;
-// 
+//
 //     sum = 0.0;
 //     i = cds->vlen;
 //     while(i-- > 0)
@@ -809,17 +788,17 @@ ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
 //         xi = *x++;
 //         yi = *y++;
 //         zi = *z++;
-// 
+//
 //         sum += xi * xi + yi * yi + zi * zi;
 //     }
-// 
+//
 //     return(sum);
 // }
-// 
-// 
+//
+//
 // static double
 // CalcInnProdNormRot(const Cds *cds, const double **rmat)
-// {   
+// {
 //     int             i;
 //     double          sum;
 //     const double   *x = (const double *) cds->x,
@@ -829,7 +808,7 @@ ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
 //     const double    rmat00 = rmat[0][0], rmat01 = rmat[0][1], rmat02 = rmat[0][2],
 //                     rmat10 = rmat[1][0], rmat11 = rmat[1][1], rmat12 = rmat[1][2],
 //                     rmat20 = rmat[2][0], rmat21 = rmat[2][1], rmat22 = rmat[2][2];
-// 
+//
 //     sum = 0.0;
 //     i = cds->vlen;
 //     while(i-- > 0)
@@ -837,14 +816,14 @@ ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
 //         xi = *x++;
 //         yi = *y++;
 //         zi = *z++;
-// 
+//
 //         xir = xi * rmat00 + yi * rmat10 + zi * rmat20;
 //         yir = xi * rmat01 + yi * rmat11 + zi * rmat21;
 //         zir = xi * rmat02 + yi * rmat12 + zi * rmat22;
-// 
+//
 //         sum += xir * xir + yir * yir + zir * zir;
 //     }
-// 
+//
 //     return(sum);
 // }
 
@@ -912,7 +891,7 @@ ProcJacobiSVDFrag(const FragCds *cds1, const FragCds *cds2, double **rotmat,
    rmsd = sqrt(E/atom_num)  */
 double
 ProcJacobiSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
-                    const double **covmat, const double *axesw, double **Rmat,
+                    const double **covmat, double **Rmat,
                     double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev = 0.0;
@@ -920,8 +899,8 @@ ProcJacobiSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
     CalcCovCds(cds1, covmat);
     CalcCovCds(cds2, covmat);
 
-    sumdev = CalcE0Cov(cds1, cds2, axesw);
-    CalcRCov(cds1, cds2, Rmat, covmat, axesw);
+    sumdev = CalcE0Cov(cds1, cds2);
+    CalcRCov(cds1, cds2, Rmat, covmat);
     CalcJacobiSVD(Rmat, Umat, sigma, VTmat, DBL_EPSILON);
     det = CalcRotMat(rotmat, Umat, VTmat);
 
