@@ -5,7 +5,7 @@
 
 double
 ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
-              const double *weights, const double *axesw,
+              const double *weights,
               double **Rmat, double **Umat, double **VTmat, double *sigma);
 
 double
@@ -14,7 +14,7 @@ ProcJacobiSVDvan(const Cds *cds1, const Cds *cds2, double **rotmat,
 
 double
 ProcJacobiSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
-                 const double **covmat, const double *axesw,
+                 const double **covmat,
                  double **Rmat, double **Umat, double **VTmat,
                  double *sigma);
 
