@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ QuatToRotmat(double **R,      /* 3x3 rotation matrix */
     q1sqr = q[1] * q[1];
     q2sqr = q[2] * q[2];
     q3sqr = q[3] * q[3];
-    
+
     q12 = q[1] * q[2];
     q03 = q[0] * q[3];
     q13 = q[1] * q[3];
@@ -101,7 +101,7 @@ QCProot(double *coeff, double guess, const double delta)
         oldg = guess;
         /* guess -= (eval_horn_quart(coeff, guess) / eval_horn_quart_deriv(coeff, guess)); */
         guess -= eval_horn_NR_corrxn(coeff, guess);
-    
+
         if (fabs(guess - oldg) < fabs(delta*guess))
             return(guess);
     }
@@ -152,7 +152,7 @@ horn_root(double *coeff, double guess, int n, double delta)
 {
     int             i;
     double          x, xold;
-    
+
     i = 0;
     x = guess;
 
@@ -160,10 +160,10 @@ horn_root(double *coeff, double guess, int n, double delta)
     {
        xold = x;
        x -= (eval_horn_quart(coeff, x) / eval_horn_quart_deriv(coeff, x));
-    
+
        if (fabs(x - xold) < delta)
           return(x);
-    
+
        ++i;
     }
 
@@ -195,8 +195,8 @@ ComputeQuartHornFrag(const FragCds *frag1, const FragCds *frag2, double *coeff)
         x2 = fx2[i];
         y2 = fy2[i];
         z2 = fz2[i];
-   
-    
+
+
         Sxx += (x1 * x2);
         Sxy += (x1 * y2);
         Sxz += (x1 * z2);
@@ -207,7 +207,7 @@ ComputeQuartHornFrag(const FragCds *frag1, const FragCds *frag2, double *coeff)
 
         Szx += (z1 * x2);
         Szy += (z1 * y2);
-        Szz += (z1 * z2);  
+        Szz += (z1 * z2);
     }
 
     Sxx2 = Sxx * Sxx;
@@ -237,11 +237,10 @@ ComputeQuartHornFrag(const FragCds *frag1, const FragCds *frag2, double *coeff)
 }
 
 
-
 /* A lot of register variables, but this sort of thing scales very well with
    new and improved processors */
 double
-CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len, double *coeff, const double innerprod, double *quat)
+CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len, double *coeff, const double outerprod, double *quat)
 {
     double          Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz;
     double          Szz2, Syy2, Sxx2, Sxy2, Syz2, Sxz2, Syx2, Szy2, Szx2,
@@ -264,7 +263,7 @@ CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len,
         x2 = fx2[i];
         y2 = fy2[i];
         z2 = fz2[i];
-   
+
         Sxx += (x1 * x2);
         Sxy += (x1 * y2);
         Sxz += (x1 * z2);
@@ -275,7 +274,7 @@ CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len,
 
         Szx += (z1 * x2);
         Szy += (z1 * y2);
-        Szz += (z1 * z2);  
+        Szz += (z1 * z2);
     }
 
     Sxx2 = Sxx * Sxx;
@@ -315,27 +314,25 @@ CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len,
              + (+(SxypSyx)*(SyzpSzy)+(SxzpSzx)*(SxxmSyy+Szz)) * (-(SxymSyx)*(SyzmSzy)+(SxzpSzx)*(SxxpSyy+Szz))
              + (+(SxypSyx)*(SyzmSzy)+(SxzmSzx)*(SxxmSyy-Szz)) * (-(SxymSyx)*(SyzpSzy)+(SxzmSzx)*(SxxpSyy-Szz));
 
-    lambdamax = QCProot(coeff, 0.5 * innerprod, precision);
+    lambdamax = QCProot(coeff, 0.5 * outerprod, precision);
 
     /* Now calculate the optimal rotation from one row of the cofactor matrix */
-    double a11, a12, a13, a14, a21, a22, a23, a24;
+    double a13, a14, a21, a22, a23, a24;
     double a31, a32, a33, a34, a41, a42, a43, a44;
 
-    a11 = SxxpSyy + Szz - lambdamax; 
-    a12 = SyzmSzy; 
-    a13 = -SxzmSzx; 
+    a13 = -SxzmSzx;
     a14 = SxymSyx;
-    a21 = SyzmSzy; 
-    a22 = SxxmSyy - Szz - lambdamax; 
-    a23 = SxypSyx; 
+    a21 = SyzmSzy;
+    a22 = SxxmSyy - Szz - lambdamax;
+    a23 = SxypSyx;
     a24 = SxzpSzx;
-    a31 = a13; 
-    a32 = a23; 
+    a31 = a13;
+    a32 = a23;
     a33 = Syy - Sxx - Szz - lambdamax;
     a34 = SyzpSzy;
-    a41 = a14; 
-    a42 = a24; 
-    a43 = a34; 
+    a41 = a14;
+    a42 = a24;
+    a43 = a34;
     a44 = Szz - SxxpSyy - lambdamax;
 
     double a3344_4334 = a33 * a44 - a43 * a34;
@@ -349,7 +346,7 @@ CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len,
     double q3 =  a21*a3244_4234 - a22*a3144_4134 + a24*a3142_4132;
     double q4 = -a21*a3243_4233 + a22*a3143_4133 - a23*a3142_4132;
     double dq = sqrt(q1*q1 + q2*q2 + q3*q3 + q4*q4);
-    
+
     quat[0] = q1/dq;
     quat[1] = q2/dq;
     quat[2] = q3/dq;
@@ -362,10 +359,10 @@ CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len,
 /* A lot of register variables, but this sort of thing scales very well with
    new and improved processors */
 /* This version has the conditional to test whether the row of the cofactor matrix is too small.
-   It goes through all four rows if necessary to find one that is large enough to avoid floating 
+   It goes through all four rows if necessary to find one that is large enough to avoid floating
    point error. */
 static double
-CalcQuarticCoeffsPu(const FragCds *frag1, const FragCds *frag2, const int len, double *coeff, const double innerprod, double *quat)
+CalcQuarticCoeffsPu(const FragCds *frag1, const FragCds *frag2, const int len, double *coeff, const double outerprod, double *quat)
 {
     double          Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz;
     double          Szz2, Syy2, Sxx2, Sxy2, Syz2, Sxz2, Syx2, Szy2, Szx2,
@@ -389,7 +386,7 @@ CalcQuarticCoeffsPu(const FragCds *frag1, const FragCds *frag2, const int len, d
         x2 = fx2[i];
         y2 = fy2[i];
         z2 = fz2[i];
-   
+
         Sxx += (x1 * x2);
         Sxy += (x1 * y2);
         Sxz += (x1 * z2);
@@ -400,7 +397,7 @@ CalcQuarticCoeffsPu(const FragCds *frag1, const FragCds *frag2, const int len, d
 
         Szx += (z1 * x2);
         Szy += (z1 * y2);
-        Szz += (z1 * z2);  
+        Szz += (z1 * z2);
     }
 
     Sxx2 = Sxx * Sxx;
@@ -440,27 +437,27 @@ CalcQuarticCoeffsPu(const FragCds *frag1, const FragCds *frag2, const int len, d
              + (+(SxypSyx)*(SyzpSzy)+(SxzpSzx)*(SxxmSyy+Szz)) * (-(SxymSyx)*(SyzmSzy)+(SxzpSzx)*(SxxpSyy+Szz))
              + (+(SxypSyx)*(SyzmSzy)+(SxzmSzx)*(SxxmSyy-Szz)) * (-(SxymSyx)*(SyzpSzy)+(SxzmSzx)*(SxxpSyy-Szz));
 
-    lambdamax = QCProot(coeff, 0.5 * innerprod, precision);
+    lambdamax = QCProot(coeff, 0.5 * outerprod, precision);
 
     /* Now calculate the optimal rotation from one row of the cofactor matrix */
     double a11, a12, a13, a14, a21, a22, a23, a24;
     double a31, a32, a33, a34, a41, a42, a43, a44;
 
-    a11 = SxxpSyy + Szz - lambdamax; 
-    a12 = SyzmSzy; 
-    a13 = -SxzmSzx; 
+    a11 = SxxpSyy + Szz - lambdamax;
+    a12 = SyzmSzy;
+    a13 = -SxzmSzx;
     a14 = SxymSyx;
-    a21 = SyzmSzy; 
-    a22 = SxxmSyy - Szz - lambdamax; 
-    a23 = SxypSyx; 
+    a21 = SyzmSzy;
+    a22 = SxxmSyy - Szz - lambdamax;
+    a23 = SxypSyx;
     a24 = SxzpSzx;
-    a31 = a13; 
-    a32 = a23; 
+    a31 = a13;
+    a32 = a23;
     a33 = Syy - Sxx - Szz - lambdamax;
     a34 = SyzpSzy;
-    a41 = a14; 
-    a42 = a24; 
-    a43 = a34; 
+    a41 = a14;
+    a42 = a24;
+    a43 = a34;
     a44 = Szz - SxxpSyy - lambdamax;
 
     double a3344_4334 = a33 * a44 - a43 * a34;
@@ -543,42 +540,42 @@ RotMatToQuaternion(const double **rot, double *quat)
     double              trace, s, w, x, y, z;
 
     /* convert to quaternion */
-    trace = rot[0][0] + rot[1][1] + rot[2][2] + 1.0; 
+    trace = rot[0][0] + rot[1][1] + rot[2][2] + 1.0;
 
     if( trace > FLT_EPSILON )
     {
-		s = 0.5 / sqrt(trace);
-		w = 0.25 / s;
-		x = ( rot[2][1] - rot[1][2] ) * s;
-		y = ( rot[0][2] - rot[2][0] ) * s;
-		z = ( rot[1][0] - rot[0][1] ) * s;
+        s = 0.5 / sqrt(trace);
+        w = 0.25 / s;
+        x = ( rot[2][1] - rot[1][2] ) * s;
+        y = ( rot[0][2] - rot[2][0] ) * s;
+        z = ( rot[1][0] - rot[0][1] ) * s;
     }
     else
     {
-		if (rot[0][0] > rot[1][1] && rot[0][0] > rot[2][2])
-		{
-			s = 2.0 * sqrt( 1.0 + rot[0][0] - rot[1][1] - rot[2][2]);
-			x = 0.25 * s;
-			y = (rot[0][1] + rot[1][0] ) / s;
-			z = (rot[0][2] + rot[2][0] ) / s;
-			w = (rot[1][2] - rot[2][1] ) / s;
-	    }
-	    else if (rot[1][1] > rot[2][2])
-	    {
-			s = 2.0 * sqrt(1.0 + rot[1][1] - rot[0][0] - rot[2][2]);
-			x = (rot[0][1] + rot[1][0] ) / s;
-			y = 0.25 * s;
-			z = (rot[1][2] + rot[2][1] ) / s;
-			w = (rot[0][2] - rot[2][0] ) / s;
-		}
-		else
-		{
-			s = 2.0 * sqrt(1.0 + rot[2][2] - rot[0][0] - rot[1][1]);
-			x = (rot[0][2] + rot[2][0] ) / s;
-			y = (rot[1][2] + rot[2][1] ) / s;
-			z = 0.25 * s;
-			w = (rot[0][1] - rot[1][0] ) / s;
-		}
+        if (rot[0][0] > rot[1][1] && rot[0][0] > rot[2][2])
+        {
+            s = 2.0 * sqrt( 1.0 + rot[0][0] - rot[1][1] - rot[2][2]);
+            x = 0.25 * s;
+            y = (rot[0][1] + rot[1][0] ) / s;
+            z = (rot[0][2] + rot[2][0] ) / s;
+            w = (rot[1][2] - rot[2][1] ) / s;
+        }
+        else if (rot[1][1] > rot[2][2])
+        {
+            s = 2.0 * sqrt(1.0 + rot[1][1] - rot[0][0] - rot[2][2]);
+            x = (rot[0][1] + rot[1][0] ) / s;
+            y = 0.25 * s;
+            z = (rot[1][2] + rot[2][1] ) / s;
+            w = (rot[0][2] - rot[2][0] ) / s;
+        }
+        else
+        {
+            s = 2.0 * sqrt(1.0 + rot[2][2] - rot[0][0] - rot[1][1]);
+            x = (rot[0][2] + rot[2][0] ) / s;
+            y = (rot[1][2] + rot[2][1] ) / s;
+            z = 0.25 * s;
+            w = (rot[0][1] - rot[1][0] ) / s;
+        }
     }
 
     quat[0] = -w;
@@ -608,7 +605,7 @@ QuarticHornFrag(const FragCds *frag1, const FragCds *frag2, double *coeff)
     printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
     QuatToRotmat(rotmat, quat);
     Mat3Print(rotmat);
-    
+
     double        **Rmat = MatAlloc(3, 3);
     double        **Umat = MatAlloc(3, 3);
     double        **VTmat = MatAlloc(3, 3);
@@ -652,22 +649,21 @@ FragDistPu(CdsArray *cdsA, int fraglen, int center_ca, int pu)
     double         *coeff = NULL;
     double          var;
     FILE           *distfile = NULL, *distfile2 = NULL;
-    double          biggest;
     double         *array = NULL;
 
-	double        **Rmat = MatAlloc(3, 3);
-	double        **Umat = MatAlloc(3, 3);
-	double        **VTmat = MatAlloc(3, 3);
-	double        *sigma = malloc(3 * sizeof(double));
-	double        **rotmat2 = MatAlloc(3, 3);
+    double        **Rmat = MatAlloc(3, 3);
+    double        **Umat = MatAlloc(3, 3);
+    double        **VTmat = MatAlloc(3, 3);
+    double        *sigma = malloc(3 * sizeof(double));
+    double        **rotmat2 = MatAlloc(3, 3);
 
-	double         *quat = malloc(4 * sizeof(double));
-	double        **rotmat = MatAlloc(3, 3);
+    double         *quat = malloc(4 * sizeof(double));
+    double        **rotmat = MatAlloc(3, 3);
 
-	double          frag1_radgyr;
-	double          frag2_radgyr;
-	double          rmsd2, lambdamax;
-//	int             n = 1000;
+    double          frag1_radgyr;
+    double          frag2_radgyr;
+    double          rmsd2, lambdamax;
+//  int             n = 1000;
     clock_t          start_time, end_time;
 //    unsigned long   seed = (unsigned long) time(NULL);
 
@@ -686,7 +682,6 @@ FragDistPu(CdsArray *cdsA, int fraglen, int center_ca, int pu)
 
     start_time = clock();
 
-    biggest = 0.0;
     count = 0;
     for (coord1 = 0; coord1 < cdsA->cnum; ++coord1)
     {
@@ -701,13 +696,13 @@ FragDistPu(CdsArray *cdsA, int fraglen, int center_ca, int pu)
                     frag1->x[k] = cdsA->cds[coord1]->x[tmp];
                     frag1->y[k] = cdsA->cds[coord1]->y[tmp];
                     frag1->z[k] = cdsA->cds[coord1]->z[tmp];
-    
+
                     frag2->x[k] = cdsA->cds[coord2]->x[tmp];
                     frag2->y[k] = cdsA->cds[coord2]->y[tmp];
                     frag2->z[k] = cdsA->cds[coord2]->z[tmp];
                 }
 
-                if (center_ca == 1)
+                if (center_ca)
                 {
                     CenterFragCA(frag1);
                     CenterFragCA(frag2);
@@ -720,37 +715,37 @@ FragDistPu(CdsArray *cdsA, int fraglen, int center_ca, int pu)
 
                 //var = QuarticHornFrag((const FragCds *) frag1, (const FragCds *) frag2, coeff);
 
-                if (pu == 1)
+                if (pu)
                 {
-					frag1_radgyr = RadGyrSqrFrag(frag1);
-					frag2_radgyr = RadGyrSqrFrag(frag2);
-					lambdamax = CalcQuarticCoeffsPu(frag1, frag2, frag1->fraglen, coeff, frag1_radgyr + frag2_radgyr, quat);
-					rmsd2 = (frag1_radgyr + frag2_radgyr) - (2.0 * lambdamax);
-					//var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
-					var = ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
-					printf("\nQCP rmsd = %e %e\n", sqrt(rmsd2/fraglen), sqrt(var/fraglen));
-					QuatToRotmat(rotmat, quat);
- 				}
- 				else
- 				{
-	//				printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
-	// 				Mat3Print(rotmat);
-	
-					var = ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
-					//var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
-					//var = ProcJacobiSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
-					//RotMatToQuaternion((const double **) rotmat2, quat);
-	
-	//				printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
-	//				Mat3Print(rotmat2);
+                    frag1_radgyr = RadGyrSqrFrag(frag1);
+                    frag2_radgyr = RadGyrSqrFrag(frag2);
+                    lambdamax = CalcQuarticCoeffsPu(frag1, frag2, frag1->fraglen, coeff, frag1_radgyr + frag2_radgyr, quat);
+                    rmsd2 = (frag1_radgyr + frag2_radgyr) - (2.0 * lambdamax);
+                    //var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+                    var = ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+                    printf("\nQCP rmsd = %e %e\n", sqrt(rmsd2/fraglen), sqrt(var/fraglen));
+                    QuatToRotmat(rotmat, quat);
+                }
+                else
+                {
+    //              printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
+    //              Mat3Print(rotmat);
+
+                    var = ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+                    //var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+                    //var = ProcJacobiSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+                    //RotMatToQuaternion((const double **) rotmat2, quat);
+
+    //              printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
+    //              Mat3Print(rotmat2);
                 }
 
-// 				if (Mat3Eq((const double **) rotmat, (const double **) rotmat2, 1e-8) == 0)
-// 				{
-// 					printf("\n Not equal\n");
-// 					Mat3Print(rotmat);
-// 					Mat3Print(rotmat2);
-// 			    }
+//              if (Mat3Eq((const double **) rotmat, (const double **) rotmat2, 1e-8) == 0)
+//              {
+//                  printf("\n Not equal\n");
+//                  Mat3Print(rotmat);
+//                  Mat3Print(rotmat2);
+//              }
 
 //                fprintf(distfile, "%-16.8e \n", var);
 //                fprintf(distfile2, "%-16.8e \n", sqrt(var));
@@ -764,19 +759,19 @@ FragDistPu(CdsArray *cdsA, int fraglen, int center_ca, int pu)
         }
     }
 
-	end_time = clock();
-	double milliseconds = (double) (end_time - start_time) / ((double) CLOCKS_PER_SEC * 0.001);
-	
-	printf( "\n milliseconds: %-16.8e --  iters = %d \n", milliseconds, count);
+    end_time = clock();
+    double milliseconds = (double) (end_time - start_time) / ((double) CLOCKS_PER_SEC * 0.001);
 
-	MatDestroy(&rotmat);
-	MatDestroy(&rotmat2);
-	MatDestroy(&Umat);
-	MatDestroy(&Rmat);
-	MatDestroy(&VTmat);
+    printf( "\n milliseconds: %-16.8e --  iters = %d \n", milliseconds, count);
 
-	free(sigma);
-	free(quat);
+    MatDestroy(&rotmat);
+    MatDestroy(&rotmat2);
+    MatDestroy(&Umat);
+    MatDestroy(&Rmat);
+    MatDestroy(&VTmat);
+
+    free(sigma);
+    free(quat);
 
     FragCdsFree(&frag1);
     FragCdsFree(&frag2);
