@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -57,10 +57,10 @@ RandFillMat(double **mat, int rows, int cols, int randmeth,
 // {
 //     while(x < 0.0)
 //         x += 2.0*MY_PI;
-// 
+//
 //     while(x > 2.0*MY_PI)
 //         x -= 2.0*MY_PI;
-// 
+//
 //     return(x);
 // }
 
@@ -148,72 +148,6 @@ rand_rotation(const double *x, double **M)
 }
 
 
-/*not work, not uniform*/
-void
-myrand_rotation(const double *x, double **M)
-{
-    const double alph = x[0] * 2.0 * MY_PI;
-    const double beta = x[1] * 2.0 * MY_PI;
-    const double gamm = x[2] * 2.0 * MY_PI;
-
-    const double calph = cos(alph);
-    const double cbeta = cos(beta);
-    const double cgamm = cos(gamm);
-    const double salph = sin(alph);
-    const double sbeta = sin(beta);
-    const double sgamm = sin(gamm);
-
-    M[0][0] =  calph*cbeta*cgamm - salph*sgamm;
-    M[0][1] = -calph*cbeta*sgamm - salph*cgamm;
-    M[0][2] =  calph*sbeta;
-
-    M[1][0] =  salph*cbeta*cgamm + calph*sgamm;
-    M[1][1] = -salph*cbeta*sgamm + calph*cgamm;
-    M[1][2] =  salph*sbeta;
-
-    M[2][0] = -sbeta*cgamm;
-    M[2][1] =  sbeta*sgamm;
-    M[2][2] =  cbeta;
-
-/*     VerifyRotMat(M, 1e-12); */
-}
-
-
-/* does not work, not uniform */
-void
-myrand_rotation_polar(const double *x, double **M)
-{
-    const double ome = x[0] * 2.0*MY_PI;
-    const double phi = x[1] * 1.0*MY_PI;
-    const double kap = x[2] * 1.0*MY_PI;
-
-    const double come = cos(ome);
-    const double cphi = cos(phi);
-    const double ckap = cos(kap);
-    const double some = sin(ome);
-    const double sphi = sin(phi);
-    const double skap = sin(kap);
-
-    const double l = some*cphi;
-    const double m = some*sphi;
-    const double n = come;
-
-    M[0][0] = l*l + (m*m + n*n)*ckap;
-    M[0][1] = l*m*(1-ckap) - n*skap;
-    M[0][2] = n*l*(1-ckap) + m*skap;
-
-    M[1][0] = l*m*(1-ckap) + n*skap;
-    M[1][1] = m*m + (n*n + l*l)*ckap;
-    M[1][2] = m*n*(1-ckap) - l*skap;
-
-    M[2][0] = n*l*(1-ckap) - m*skap;;
-    M[2][1] = m*n*(1-ckap) + l*skap;
-    M[2][2] = n*n + (l*l + m*m) * ckap;
-
-/*     VerifyRotMat(M, 1e-12); */
-}
-
-
 void
 rand_translation(double *x, double var, const gsl_rng *r2)
 {
@@ -231,8 +165,6 @@ RandRotCdsArray(CdsArray *cdsA, const gsl_rng *r2)
     double       **rotmat = MatAlloc(3, 3);
     int            i;
 
-/* #include "vonmises_dist.h" */
-/* #include "uniform_dist.h" */
     for (i = 0; i < cdsA->cnum; ++i)
     {
         randx[0] = gsl_rng_uniform(r2);
@@ -318,8 +250,8 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
     double        *p = calloc(protlen, sizeof(double));
     double       **randv = MatAlloc(protlen, 3), **randn = MatAlloc(protlen, 3);
     double        *diag = malloc(protlen * sizeof(double));
-    Cds       **cds = cdsA->cds;
-    Cds        *mcds = cdsA->cds[0];
+    Cds          **cds = cdsA->cds;
+    Cds           *mcds = cdsA->cds[0];
     double         scale = 1.0;
 
 //     for (i = 0; i < protlen; ++i)
@@ -337,7 +269,7 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
 
      for (i = 0; i < protlen; ++i)
          diag[i] = covmat[i][i];
-         //diag[i] = invgamma_dev(cdsA->algo->param[0], cdsA->algo->param[1]);
+         //diag[i] = invgamma_dev(algo->param[0], algo->param[1]);
 
     CovMat2CorMat(covmat, protlen);
 
@@ -345,9 +277,9 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
 /*         printf("%-3d %f\n", i+1, covmat[i][i]); */
 
 //      for (i = 0; i < protlen; ++i)
-//          diag[i] = invgamma_dev(cdsA->algo->param[0], cdsA->algo->param[1]);
+//          diag[i] = invgamma_dev(algo->param[0], algo->param[1]);
 
-    PrintCovMatGnuPlot((const double **) covmat, protlen, mystrcat(cdsA->algo->rootname, "_cor.mat"));
+    PrintCovMatGnuPlot((const double **) covmat, protlen, mystrcat(algo->rootname, "_cor.mat"));
 
     for (i = 0; i < protlen; ++i)
         printf("%-3d %f\n", i+1, diag[i]);
@@ -355,11 +287,11 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
     CenMass(mcds);
     ApplyCenterIp(mcds);
 
-    if (mcds->innerprod == NULL)
-        mcds->innerprod = MatAlloc(protlen, protlen);
+    if (mcds->outerprod == NULL)
+        mcds->outerprod = MatAlloc(protlen, protlen);
 
     CdsInnerProd(mcds);
-    PrintCovMatGnuPlot((const double **) mcds->innerprod, protlen, mystrcat(cdsA->algo->rootname, "_mean.mat"));
+    PrintCovMatGnuPlot((const double **) mcds->outerprod, protlen, mystrcat(algo->rootname, "_mean.mat"));
 
     /* LAPACK dpotrf calculates the Cholesky decomposition, here upper triangular */
     //dpotrf_opt_dest(covmat, protlen);
@@ -368,12 +300,12 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
 
     for (i = cdsA->cnum - 1; i >=0; --i)
     {
-        RandFillMat(randn, protlen, 3, cdsA->algo->random, 0, 0, 0, r2);
+        RandFillMat(randn, protlen, 3, algo->random, 0, 0, 0, r2);
 
         memset(&randv[0][0], 0, protlen * 3 * sizeof(double));
         for (m = 0; m < 3; ++m)
             for (j = 0; j < protlen; ++j)
-                for (k = 0; k < protlen; ++k) /* because covmat is upper diagonal, lower is all zeros */        
+                for (k = 0; k < protlen; ++k) /* because covmat is upper diagonal, lower is all zeros */
                     randv[j][m] += covmat[k][j] * randn[k][m];
 
 /*         for (j = 0; j < protlen; ++j) */
@@ -381,7 +313,7 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
 
         for (j = 0; j < protlen; ++j)
         {
-            scale = RandScale(diag[j], cdsA->algo->random, 0, 0);
+            scale = RandScale(diag[j], algo->random, 0, 0);
             /* printf("\n%d %f", j, scale); */
 
             cds[i]->x[j] = mcds->x[j] + randv[j][0] * scale;
@@ -414,32 +346,11 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
     double        *invdiag = malloc(protlen * sizeof(double));
     double         a, b, c, d, sum/* , smallest */;
     double         B, /* C,  */D;
-    Cds       **cds = cdsA->cds;
-    Cds        *mcds = cdsA->cds[0];
-    double         axes[3];
-    double         axes_sqrt[3];
+    Cds          **cds = cdsA->cds;
+    Cds           *mcds = cdsA->cds[0];
 /*     FILE          *fp; */
     double         x1 = 0.0, x2 = 0.0, scale = 1.0;
 
-    sum = 0.0;
-    for (i = 0; i < 3; ++i)
-        sum += cdsA->algo->raxes[i];
-    sum /= 3.0;
-
-    for (i = 0; i < 3; ++i)
-        cdsA->algo->raxes[i] /= sum;
-
-    printf(" axes vars: %f %f %f\n",
-           cdsA->algo->raxes[0],
-           cdsA->algo->raxes[1],
-           cdsA->algo->raxes[2]);
-
-    for (i = 0; i < 3; ++i)
-        axes_sqrt[i] = sqrt(cdsA->algo->raxes[i]);
-
-    for (i = 0; i < 3; ++i)
-        axes[i] = cdsA->algo->raxes[i];
-
     /* B = 0.7480208079921; */
     B = 0.2;
     a = 15.0;
@@ -453,7 +364,7 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
 /*     D = 0.03135645239684; */
     b = B, /* C = c,  */d = D;
 
-/*     CalcCovMat(cdsA); */  
+/*     CalcCovMat(cdsA); */
 
     memcpy(covmat[0], internmat[0], protlen * protlen * sizeof(double));
 
@@ -506,7 +417,7 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
 //     for (i = 0; i < protlen; ++i)
 //     {
 //         /* diag[i] = covmat[i][i] = invgamma_dev(3.468e-03, 3.779e-01); */
-//         diag[i] = invgamma_dev(cdsA->algo->param[0], cdsA->algo->param[1]);
+//         diag[i] = invgamma_dev(algo->param[0], algo->param[1]);
 //     }
 
 //     CorMat2CovMat(covmat, diag, protlen);
@@ -524,7 +435,7 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
     for (i = 0; i < protlen; ++i)
         diag[i] = covmat[i][i];
 
-    PrintCovMatGnuPlot((const double **) covmat, protlen, mystrcat(cdsA->algo->rootname, "_cov.mat"));
+    PrintCovMatGnuPlot((const double **) covmat, protlen, mystrcat(algo->rootname, "_cov.mat"));
 
     for (i = 0; i < protlen; ++i)
         printf("%-3d %f\n", i+1, diag[i]);
@@ -544,17 +455,17 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
     CenMass(mcds);
     ApplyCenterIp(mcds);
 
-    if (mcds->innerprod == NULL)
-        mcds->innerprod = MatAlloc(protlen, protlen);
+    if (mcds->outerprod == NULL)
+        mcds->outerprod = MatAlloc(protlen, protlen);
 
     CdsInnerProd(mcds);
-    PrintCovMatGnuPlot((const double **) mcds->innerprod, protlen, mystrcat(cdsA->algo->rootname, "_mean.mat"));
+    PrintCovMatGnuPlot((const double **) mcds->outerprod, protlen, mystrcat(algo->rootname, "_mean.mat"));
 
     sum = 0.0;
     for (i = 0; i < protlen; ++i)
-        sum += (1.0 / (diag[i]*axes[0]) + 1.0 / (diag[i]*axes[1]) + 1.0 / (diag[i]*axes[2]));
+        sum += 1.0 / diag[i];
 
-    printf("\n\n->  sum: %f   sigma^2: %f  sigma: %f\n", sum/3, 3*protlen/sum, sqrt(3*protlen/sum));
+    printf("\n\n->  sum: %f   sigma^2: %f  sigma: %f\n", sum, protlen/sum, sqrt(protlen/sum));
 
 /*     MatInvLAPACK(covmat, covmat, protlen); */
 /*  */
@@ -583,32 +494,21 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
 
 /*     PrintCovMatGnuPlot((const double **) covmat, protlen, "corr.mat"); */
 /*  */
-/*     FILE *fp2 = fopen("intdist.mat", "w"); */
-/*     for (i = 0; i < protlen; ++i) */
-/*     { */
-/*         fprintf(fp2, "\n"); */
-/*         for (j = 0; j < protlen; ++j) */
-/*             fprintf(fp2, "% 12.8f\t", */
-/*             exp(-0.1*CdsDist(cds[0], i, cds[0], j))); */
-/*     } */
-/*     fprintf(fp2, "\n"); */
-/*     fclose(fp2); */
 
     /* LAPACK dpotrf calculates the Cholesky decomposition, here upper triangular */
     //dpotrf_opt_dest(covmat, protlen);
     CholeskyGSLDest(covmat, protlen);
 /*     write_C_mat((const double **) covmat, protlen, 6, 10); */
-    printf(" true axes sqrt: %f %f %f\n", axes_sqrt[0], axes_sqrt[1], axes_sqrt[2]);
 
 /*     fp = fopen("rand.txt", "w"); */
     for (i = cdsA->cnum - 1; i >=0; --i)
     {
-        RandFillMat(randn, protlen, 3, cdsA->algo->random, b, c, d, r2);
+        RandFillMat(randn, protlen, 3, algo->random, b, c, d, r2);
 
         memset(&randv[0][0], 0, protlen * 3 * sizeof(double));
         for (m = 0; m < 3; ++m)
             for (j = 0; j < protlen; ++j)
-                for (k = 0; k < protlen; ++k) /* because covmat is upper diagonal, lower is all zeros */        
+                for (k = 0; k < protlen; ++k) /* because covmat is upper diagonal, lower is all zeros */
                     randv[j][m] += covmat[k][j] * randn[k][m];
 
 /*         for (j = 0; j < protlen; ++j) */
@@ -616,15 +516,15 @@ RandCds_2sdf_old(CdsArray *cdsA, gsl_rng *r2)
 
         for (j = 0; j < protlen; ++j)
         {
-            scale = RandScale(diag[j], cdsA->algo->random, a, b);
+            scale = RandScale(diag[j], algo->random, a, b);
             /* printf("\n%d %f", j, scale); */
 
             cds[i]->x[j] = mcds->x[j] +
-                              randv[j][0] * scale * axes_sqrt[0];
+                              randv[j][0] * scale;
             cds[i]->y[j] = mcds->y[j] +
-                              randv[j][1] * scale * axes_sqrt[1];
+                              randv[j][1] * scale;
             cds[i]->z[j] = mcds->z[j] +
-                              randv[j][2] * scale * axes_sqrt[2];
+                              randv[j][2] * scale;
 /*             if (j == 0) */
 /*                 printf("\n%-3d % 8.3f % 8.3f % 8.3f", */
 /*                        i, cds[i]->x[j], cds[i]->y[j], cds[i]->z[j]); */
@@ -665,9 +565,9 @@ RandCds_2sdf(CdsArray *cdsA, gsl_rng *r2)
 
     CenMass(mcds);
     ApplyCenterIp(mcds);
-    CalcCdsPrincAxes(mcds, mcds->matrix);
-    Mat3TransposeIp(mcds->matrix);
-    RotateCdsIp(mcds, (const double **) mcds->matrix);
+//     CalcCdsPrincAxes(mcds, mcds->matrix);
+//     Mat3TransposeIp(mcds->matrix);
+//     RotateCdsIp(mcds, (const double **) mcds->matrix);
 
     for (i = cdsA->cnum - 1; i >=0; --i)
     {
@@ -932,7 +832,7 @@ PDBCdsArray
         cds->x[i] = normal_dev3(0.0, radii[0]*radii[0], r2); /* 11 30-37 8    Real(8.3)    x          Orthogonal coordinates for X */
         cds->y[i] = normal_dev3(0.0, radii[1]*radii[1], r2); /* 12 30-37 8    Real(8.3)    y          Orthogonal coordinates for Y */
         cds->z[i] = normal_dev3(0.0, radii[2]*radii[2], r2); /* 13 30-37 8    Real(8.3)    z          Orthogonal coordinates for Z */
-        cds->occupancy[i] = 1.0;               /* 14 54-59 6    Real(6.2)    occupancy  Occupancy. */
+        cds->occupancy[i] = 1.0;               /* 14 54-59 6    Real(6.2)    occupancy  Nuupancy. */
         cds->tempFactor[i] = 10.0;             /* 15 60-65 6    Real(6.2)    tempFactor Temperature factor. */
     }
 
