@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,157 +42,161 @@
 #include <gsl/gsl_randist.h>
 #include <gsl/gsl_sort.h>
 #include <gsl/gsl_statistics_double.h>
+#include <gsl/gsl_sf_psi.h>
 
 #include "distfit_local.h"
 
 #define VERSION "0.90"
 #define DISTNUM 24
 
+static double
+**ReadValsMulti(const char *listfile_name, int *col, int *len);
+
 /* array of function names */
 char
-dist_name[DISTNUM][32] = 
+dist_name[DISTNUM][32] =
 {
-	"Normal",      "Laplace",   "EVD",        "Logistic",
-	"Cauchy",      "Uniform",   "Weibull", 
-	"Gamma",       "ChisqrGen",  "Lognormal",
-	"Invgamma",    "Invgauss",  "Recinvgauss", "Pareto",
-	"Exponential", "Invchisqr", "Chisqr",      "Chi",
-	"Rayleigh", "Rice*",
-	"Maxwell",     "Beta",      "BetaSym", "BetaPrime"     //"Binomial"
+    "Normal",      "Laplace",   "EVD",        "Logistic",
+    "Cauchy",      "Uniform",   "Weibull",
+    "Gamma",       "ChisqrGen",  "Lognormal",
+    "Invgamma",    "Invgauss",  "Recinvgauss", "Pareto",
+    "Exponential", "Invchisqr", "Chisqr",      "Chi",
+    "Rayleigh", "Rice*",
+    "Maxwell",     "Beta",      "BetaSym", "BetaPrime"     //"Binomial"
 };
 
 /* array of function pointers */
 DistFit
-distfit_func[DISTNUM] = 
+distfit_func[DISTNUM] =
 {
-	&normal_fit,    &laplace_fit,   &EVD_fit,         &logistic_fit,
-	&cauchy_fit,    &uniform_fit,   &weibull_fit, 
-	&gamma_fit,     &chisqrgen_fit, &lognormal_fit,
-	&invgamma_fit,  &invgauss_fit,  &recinvgauss_fit, &pareto_fit,
-	&exp_fit,       &invchisqr_fit, &chisqr_fit,      &chi_fit,
-	&rayleigh_fit,  &rice_fit,
-	&maxwell_fit,   &beta_fit,      &betasym_fit,  &betaprime_fit   //&binomial_fit
+    &normal_fit,    &laplace_fit,   &EVD_fit,         &logistic_fit,
+    &cauchy_fit,    &uniform_fit,   &weibull_fit,
+    &gamma_fit,     &chisqrgen_fit, &lognormal_fit,
+    &invgamma_fit,  &invgauss_fit,  &recinvgauss_fit, &pareto_fit,
+    &exp_fit,       &invchisqr_fit, &chisqr_fit,      &chi_fit,
+    &rayleigh_fit,  &rice_fit,
+    &maxwell_fit,   &beta_fit,      &betasym_fit,  &betaprime_fit   //&binomial_fit
 };
 
 /* array of function pointers */
 DistDev
-distdev_func[DISTNUM] = 
+distdev_func[DISTNUM] =
 {
-	&normal_dev,    &laplace_dev,   &EVD_dev,         &logistic_dev,
-	&cauchy_dev,    &uniform_dev,   &weibull_dev,
-	&gamma_dev,     &chisqrgen_dev, &lognormal_dev,
-	&invgamma_dev,  &invgauss_dev,  &recinvgauss_dev, &pareto_dev,
-	&exp_dev,       &invchisqr_dev, &chisqr_dev,      &chi_dev,
-	&rayleigh_dev,  &rice_dev,
-	&maxwell_dev,   &beta_dev,      &betasym_dev,     &betaprime_dev //&binomial_dev
+    &normal_dev,    &laplace_dev,   &EVD_dev,         &logistic_dev,
+    &cauchy_dev,    &uniform_dev,   &weibull_dev,
+    &gamma_dev,     &chisqrgen_dev, &lognormal_dev,
+    &invgamma_dev,  &invgauss_dev,  &recinvgauss_dev, &pareto_dev,
+    &exp_dev,       &invchisqr_dev, &chisqr_dev,      &chi_dev,
+    &rayleigh_dev,  &rice_dev,
+    &maxwell_dev,   &beta_dev,      &betasym_dev,     &betaprime_dev //&binomial_dev
 };
 
 DistPDF
-distpdf_func[DISTNUM] = 
+distpdf_func[DISTNUM] =
 {
-	&normal_pdf,    &laplace_pdf,   &EVD_pdf,         &logistic_pdf,
-	&cauchy_pdf,    &uniform_pdf,   &weibull_pdf,
-	&gamma_pdf,     &chisqrgen_pdf, &lognormal_pdf,
-	&invgamma_pdf,  &invgauss_pdf,  &recinvgauss_pdf, &pareto_pdf,
-	&exp_pdf,       &invchisqr_pdf, &chisqr_pdf,      &chi_pdf,
-	&rayleigh_pdf,  &rice_pdf,
-	&maxwell_pdf,   &beta_pdf,      &betasym_pdf,     &betaprime_pdf //&binomial_pdf
+    &normal_pdf,    &laplace_pdf,   &EVD_pdf,         &logistic_pdf,
+    &cauchy_pdf,    &uniform_pdf,   &weibull_pdf,
+    &gamma_pdf,     &chisqrgen_pdf, &lognormal_pdf,
+    &invgamma_pdf,  &invgauss_pdf,  &recinvgauss_pdf, &pareto_pdf,
+    &exp_pdf,       &invchisqr_pdf, &chisqr_pdf,      &chi_pdf,
+    &rayleigh_pdf,  &rice_pdf,
+    &maxwell_pdf,   &beta_pdf,      &betasym_pdf,     &betaprime_pdf //&binomial_pdf
 };
 
 DistCDF
-distcdf_func[DISTNUM] = 
+distcdf_func[DISTNUM] =
 {
-	&normal_cdf,    &laplace_cdf,   &EVD_cdf,         &logistic_cdf,
-	&cauchy_cdf,    &uniform_cdf,   &weibull_cdf,
-	&gamma_cdf,     &chisqrgen_cdf, &lognormal_cdf,
-	&invgamma_cdf,  &invgauss_cdf,  &recinvgauss_cdf, &pareto_cdf,
-	&exp_cdf,       &invchisqr_cdf, &chisqr_cdf,      &chi_cdf,
-	&rayleigh_cdf,  &rice_cdf,
-	&maxwell_cdf,   &beta_cdf,      &betasym_cdf,     &betaprime_cdf //&binomial_cdf
+    &normal_cdf,    &laplace_cdf,   &EVD_cdf,         &logistic_cdf,
+    &cauchy_cdf,    &uniform_cdf,   &weibull_cdf,
+    &gamma_cdf,     &chisqrgen_cdf, &lognormal_cdf,
+    &invgamma_cdf,  &invgauss_cdf,  &recinvgauss_cdf, &pareto_cdf,
+    &exp_cdf,       &invchisqr_cdf, &chisqr_cdf,      &chi_cdf,
+    &rayleigh_cdf,  &rice_cdf,
+    &maxwell_cdf,   &beta_cdf,      &betasym_cdf,     &betaprime_cdf //&binomial_cdf
 };
 
 DistSDF
-distsdf_func[DISTNUM] = 
+distsdf_func[DISTNUM] =
 {
-	&normal_sdf,    &laplace_sdf,   &EVD_sdf,         &logistic_sdf,
-	&cauchy_sdf,    &uniform_sdf,   &weibull_sdf,
-	&gamma_sdf,     &chisqrgen_sdf, &lognormal_sdf,
-	&invgamma_sdf,  &invgauss_sdf,  &recinvgauss_sdf, &pareto_sdf,
-	&exp_sdf,       &invchisqr_sdf, &chisqr_sdf,      &chi_sdf,
-	&rayleigh_sdf,  &rice_sdf,
-	&maxwell_sdf,   &beta_sdf,      &betasym_sdf,     &betaprime_sdf //&binomial_sdf
+    &normal_sdf,    &laplace_sdf,   &EVD_sdf,         &logistic_sdf,
+    &cauchy_sdf,    &uniform_sdf,   &weibull_sdf,
+    &gamma_sdf,     &chisqrgen_sdf, &lognormal_sdf,
+    &invgamma_sdf,  &invgauss_sdf,  &recinvgauss_sdf, &pareto_sdf,
+    &exp_sdf,       &invchisqr_sdf, &chisqr_sdf,      &chi_sdf,
+    &rayleigh_sdf,  &rice_sdf,
+    &maxwell_sdf,   &beta_sdf,      &betasym_sdf,     &betaprime_sdf //&binomial_sdf
 };
 
 DistInt
-distint_func[DISTNUM] = 
+distint_func[DISTNUM] =
 {
-	&normal_int,    &laplace_int,   &EVD_int,         &logistic_int,
-	&cauchy_int,    &uniform_int,   &weibull_int,
-	&gamma_int,     &chisqrgen_int, &lognormal_int,
-	&invgamma_int,  &invgauss_int,  &recinvgauss_int, &pareto_int,
-	&exp_int,       &invchisqr_int, &chisqr_int,      &chi_int,
-	&rayleigh_int,  &rice_int,
-	&maxwell_int,   &beta_int,      &betasym_int,     &betaprime_int //&binomial_int
+    &normal_int,    &laplace_int,   &EVD_int,         &logistic_int,
+    &cauchy_int,    &uniform_int,   &weibull_int,
+    &gamma_int,     &chisqrgen_int, &lognormal_int,
+    &invgamma_int,  &invgauss_int,  &recinvgauss_int, &pareto_int,
+    &exp_int,       &invchisqr_int, &chisqr_int,      &chi_int,
+    &rayleigh_int,  &rice_int,
+    &maxwell_int,   &beta_int,      &betasym_int,     &betaprime_int //&binomial_int
 };
 
 int
-dist_pnum[DISTNUM] = 
+dist_pnum[DISTNUM] =
 {
-	2, 2, 2, 2,
-	2, 2, 2,
-	2, 2, 2,
-	2, 2, 2, 2,
-	1, 1, 1, 1,
-	1, 2,
-	1, 2, 1, 2 //2
+    2, 2, 2, 2,
+    2, 2, 2,
+    2, 2, 2,
+    2, 2, 2, 2,
+    1, 1, 1, 1,
+    1, 2,
+    1, 2, 1, 2 //2
 };
 
 
 int
-dist_nonneg[DISTNUM] = 
+dist_nonneg[DISTNUM] =
 {
-	0, 0, 0, 0,
-	0, 0, 1,
-	1, 1, 0,
-	0, 0, 0, 0,
-	1, 0, 1, 1,
-	1, 1,
-	1, 0, 0, 1 //1
+    0, 0, 0, 0,
+    0, 0, 1,
+    1, 1, 0,
+    0, 0, 0, 0,
+    1, 0, 1, 1,
+    1, 1,
+    1, 0, 0, 1 //1
 };
 
 
 int
-dist_posdef[DISTNUM] = 
+dist_posdef[DISTNUM] =
 {
-	0, 0, 0, 0,
-	0, 0, 0,
-	0, 0, 1,
-	1, 1, 1, 1,
-	0, 1, 0, 0,
-	0, 0,
-	0, 0, 0, 0 //0
+    0, 0, 0, 0,
+    0, 0, 0,
+    0, 0, 1,
+    1, 1, 1, 1,
+    0, 1, 0, 0,
+    0, 0,
+    0, 0, 0, 0 //0
 };
 
 int
-dist_beta[DISTNUM] = 
+dist_beta[DISTNUM] =
 {
-	0, 0, 0, 0,
-	0, 0, 0,
-	0, 0, 0,
-	0, 0, 0, 0,
-	0, 0, 0, 0,
-	0, 0,
-	0, 1, 1, 0 //0
+    0, 0, 0, 0,
+    0, 0, 0,
+    0, 0, 0,
+    0, 0, 0, 0,
+    0, 0, 0, 0,
+    0, 0,
+    0, 1, 1, 0 //0
 };
 
 DFParams        DfParams;
 DFParams       *dfparams = &DfParams;
 DistStats     **diststats = NULL;
-int distsort[DISTNUM];
-double *pdfparams = NULL;
-double *cdfparams = NULL;
-double *sdfparams = NULL;
-double *intparams = NULL;
+int             distsort[DISTNUM];
+double         *pdfparams = NULL;
+double         *cdfparams = NULL;
+double         *sdfparams = NULL;
+double         *intparams = NULL;
 
 
 /*
@@ -276,7 +280,7 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
         var = 0.0;
         for (j = 0; j < len; ++j)
             var += dif[i][j] * dif[i][j];
-        
+
         std[i] = sqrt(var * invlen);
     }
 
@@ -310,11 +314,11 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
 
 //     printf ("\n\nEdgeworth correlation matrix:");
 //     MatPrintLowerDiag(cor, dim);
-// 
+//
 //     for (i = 0; i < dim; ++i)
 //         for (j = 0; j < dim; ++j)
 //             cov[i][j] = cor[i][j] / (std[i] * std[j]);
-// 
+//
 //     printf ("\n\nEdgeworth covariance matrix:");
 //     MatPrintLowerDiag(cov, dim);
 
@@ -399,7 +403,7 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
         }
     }
 
-    /* There are d \kappa_{i,i,i} terms, 2 {d \choose 2} \kappa_{i,i,j} terms, 
+    /* There are d \kappa_{i,i,i} terms, 2 {d \choose 2} \kappa_{i,i,j} terms,
        and {d \choose 3} \kappa_{i,j,k} terms.
        gsl_sf_choose (unsigned int n, unsigned int m) */
 
@@ -419,7 +423,7 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
     printf("\nln(det):           %14.3f", lndet);
 
     entropy = 0.5 * dim * log(2.0 * M_PI * M_E) + 0.5 * lndet;
-    
+
     printf("\nwhite entropy:     %14.3f", entropy);
     printf("\nbias:              %14.3f", bias);
     printf("\nln(scale):         %14.3f", lnscale);
@@ -427,7 +431,7 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
     printf("\nNaive N-entropy:   %14.3f", entropy + lnscale);
 
     //entropy = entropy - bias + lnscale;
-    
+
     printf("\nEdgeworth entropy: %14.3f", entropy - term1/12.0 + lnscale);
     printf("\nEdgeworth entropy (4th order corrections): %14.3f", entropy - bias + lnscale);
     printf("\n\n");
@@ -446,11 +450,11 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
 //             kappa_iii += t3; /* skewness */
 //             kappa_iiii += t3 * dif[i][j]; /* kurtosis */
 //         }
-// 
+//
 //         kappa_iii *= invlen;
 //         kappa_iiii *= invlen;
 //         kappa_iiii -= 3.0;
-// 
+//
 //         t3 = kappa_iii * kappa_iii;
 //         t4 = kappa_iiii * kappa_iiii;
 //         term1 += t3;
@@ -458,28 +462,28 @@ CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
 //         term5 += t4 * kappa_iiii; // k_4^3;
 //         term6 += t3 * kappa_iiii; // k_3^2 k_4
 //     }
-// 
+//
 //     bias = (term1 + 3.0 * term2 + term3 / 6.0) / 12.0 + term4/48.0 - term5/16.0 - 5.0*term6/8.0;
-// 
+//
 //     printf("\nEdgeworth term1: %g", term1/ 12.0);
 //     printf("\nEdgeworth term2: %g", 3.0*term2/ 12.0);
 //     printf("\nEdgeworth term3: %g", term3/(6.0*12.0));
 //     printf("\nEdgeworth term4: %g", +term4/48.0);
 //     printf("\nEdgeworth term5: %g", -term5/16.0);
 //     printf("\nEdgeworth term6: %g\n", - 5.0*term6/8.0);
-// 
+//
 //     printf("\nln(det):           %14.3f", lndet);
-// 
+//
 //     entropy = 0.5 * dim * log(2.0 * M_PI * M_E) + 0.5 * lndet;
-//     
+//
 //     printf("\nwhite entropy:     %14.3f", entropy);
 //     printf("\nbias:              %14.3f", bias);
 //     printf("\nln(scale):         %14.3f", lnscale);
-// 
+//
 //     printf("\nNaive N-entropy:   %14.3f", entropy + lnscale);
-// 
+//
 //     //entropy = entropy - bias + lnscale;
-//     
+//
 //     printf("\nEdgeworth entropy: %14.3f", entropy - term1/12.0 + lnscale);
 //     printf("\nEdgeworth entropy: %14.3f", entropy - bias + lnscale);
 //     printf("\n\n");
@@ -560,13 +564,13 @@ CalcDistStats(const double *array, const int len)
     pstats[7] = gsl_stats_quantile_from_sorted_data(x, 1, len, 0.05);
     pstats[8] = gsl_stats_quantile_from_sorted_data(x, 1, len, 0.95);
     pstats[9] = FindMode(x, len);
-    
+
     printf("\nmode approximation: %g\n", pstats[9]);
 
     printf("\n       ave (+/-       SD)    skew    kurt     median ( 95%% credible interval ) ( 90%% credible interval )");
     printf("\n--------------------------------------------------------------------------------------------------------");
 
-    printf("\n% 10.2f (+/- %8.2f) % 7.2f % 7.2f % 10.2f (% 10.2f - % 10.2f) (% 10.2f - % 10.2f)\n\n", 
+    printf("\n% 10.2f (+/- %8.2f) % 7.2f % 7.2f % 10.2f (% 10.2f - % 10.2f) (% 10.2f - % 10.2f)\n\n",
            pstats[0], pstats[1], pstats[2], pstats[3], pstats[4], pstats[5], pstats[6], pstats[7], pstats[8]);
 
     free(x);
@@ -579,10 +583,14 @@ ParseCmdLine(int *argc, char **argv[])
     int             option;
 
     /* get the options */
-    while ((option = getopt (*argc, *argv, "b:c:C:d:D:hI:m:n:op:P:s:S:t:vz")) != -1)
+    while ((option = getopt (*argc, *argv, "1b:c:C:d:D:g:G:hI:m:n:op:P:s:S:t:T:vz")) != -1)
     {
         switch (option)
         {
+            case '1':
+                dfparams->neg = 1;
+                break;
+
             case 'b':
                 dfparams->bootstrap = (int) strtol(optarg, NULL, 10);
                 break;
@@ -676,6 +684,14 @@ ParseCmdLine(int *argc, char **argv[])
                 dfparams->distdev = (int) strtol(optarg, NULL, 10);
                 break;
 
+            case 'g':
+                dfparams->digamma = (double) strtod(optarg, NULL);
+                break;
+
+            case 'G':
+                dfparams->invdigamma = (double) strtod(optarg, NULL);
+                break;
+
             case 'h':
                 dfparams->histo = 1;
                 break;
@@ -719,6 +735,10 @@ ParseCmdLine(int *argc, char **argv[])
 
                 break;
 
+            case 'T':
+                dfparams->trigamma = (double) strtod(optarg, NULL);
+                break;
+
             case 'v':
                 Version();
                 exit(EXIT_SUCCESS);
@@ -772,6 +792,10 @@ main(int argc, char *argv[])
     dfparams->mix = 0;
     dfparams->fixzeros = 0;
     dfparams->fixones = 0;
+    dfparams->digamma = 0.0;
+    dfparams->trigamma = 0.0;
+    dfparams->invdigamma = 0.0;
+    dfparams->neg = 0;
 
     //printf("\n###### %e\n", normal_sdf(5.0, 0.0, 1.0));
 
@@ -784,7 +808,55 @@ main(int argc, char *argv[])
     narguments = ParseCmdLine(&argc, &argv);
 
     if (dfparams->seed == -1)
-        dfparams->seed = (unsigned long) time(NULL);
+        dfparams->seed = (unsigned long) time(NULL) + getpid();
+
+    if (dfparams->digamma > 0.0)
+    {
+        printf("\n Digamma(%g):  %g \n\n", dfparams->digamma, gsl_sf_psi(dfparams->digamma));
+
+        exit(EXIT_SUCCESS);
+    }
+
+    if (dfparams->invdigamma > 0.0)
+    {
+        double y;
+        double x = dfparams->invdigamma;
+        double lambda;
+
+        if (dfparams->neg)
+            x = -x;
+
+        // Inverse digamma (psi) function.  The digamma function is the
+        // derivative of the log gamma function.  This calculates the value
+        // Y > 0 for a value X such that digamma(Y) = X.
+        //
+        // This algorithm is from Paul Fackler:
+        // http://www4.ncsu.edu/~pfackler/
+
+        lambda = 1.0;
+        y = exp(x);
+        while (lambda > DBL_EPSILON)
+        {
+            y += lambda*copysign(1.0, x - gsl_sf_psi(y));
+            lambda *= 0.5;
+        }
+
+        printf("\n Inverse Digamma(%g):  %g \n\n", dfparams->invdigamma, y);
+
+        exit(EXIT_SUCCESS);
+    }
+
+    if (dfparams->trigamma > 0.0)
+    {
+        double x = dfparams->trigamma;
+
+        x = gsl_sf_psi_1(x);
+        //x = 1.0/sqrt(x);
+
+        printf("\n Trigamma(%g):  %g \n\n", dfparams->trigamma, x);
+
+        exit(EXIT_SUCCESS);
+    }
 
     if (pdfparams != NULL)
     {
@@ -849,7 +921,13 @@ main(int argc, char *argv[])
         if (dfparams->histo == 0)
         {
             /* get data values from file */
-            array = getvals(argv[0], &length, dfparams->col);
+            //array = getvals(argv[0], &length, dfparams->col);
+            double **matrix = NULL;
+            int colnum;
+            matrix = ReadValsMulti(argv[0], &colnum, &length);
+            array = malloc(length * sizeof(double));
+            for (i = 0; i < length; ++i)
+                array[i] = matrix[dfparams->col][i];
             dfparams->length = length;
 
             if (length < 4)
@@ -875,6 +953,8 @@ main(int argc, char *argv[])
 
             for (i = 0; i < length; ++i)
                 warray[i] = array[i];
+
+            MatDestroy(&matrix);
         }
         else
         {
@@ -895,10 +975,10 @@ main(int argc, char *argv[])
             while(1)
             {
                 ch = getc(listfile);
-        
+
                 if (ch == EOF || ch == '\n')
                     ++length;
-        
+
                 if (ch == EOF)
                     break;
             }
@@ -989,11 +1069,11 @@ main(int argc, char *argv[])
     }
 
     /* do the bootstrap if so desired */
-    if (dfparams->distnum == 1 && dfparams->bootstrap > 1)
+    if (dfparams->distnum && dfparams->bootstrap > 1)
     {
         BootFit(diststats, dfparams->distindex, array, length, dfparams);
     }
-    else if(dfparams->distnum == 1)
+    else if(dfparams->distnum)
     {
         SingleDistFit(distfit_func, dfparams->distindex, dist_name[dfparams->distindex], diststats[0], array, length, dfparams);
     }
@@ -1008,7 +1088,7 @@ main(int argc, char *argv[])
 
             TestData(array, length);
 
-            if (dfparams->histo == 1)
+            if (dfparams->histo)
             {
                 MultiHistFit(array, freq, length);
             }
@@ -1031,7 +1111,7 @@ main(int argc, char *argv[])
 
     free(array);
     free(warray);
-    if (dfparams->histo == 1)
+    if (dfparams->histo)
         free(freq);
     for(i = 0; i < dfparams->distnum; ++i)
         free(diststats[i]);
@@ -1046,52 +1126,52 @@ TestData(const double *data, const int length)
 {
     int             i;
 
-	dfparams->isbeta = 1;
-	dfparams->isneg = 0;
-	dfparams->iszero = 0;
-	for (i = 0; i < length; ++i)
-	{
-		if (data[i] > 1.0)
-		{
-			dfparams->isbeta = 0;
-			break;
-		}
-	}
+    dfparams->isbeta = 1;
+    dfparams->isneg = 0;
+    dfparams->iszero = 0;
+    for (i = 0; i < length; ++i)
+    {
+        if (data[i] > 1.0)
+        {
+            dfparams->isbeta = 0;
+            break;
+        }
+    }
 
-	for (i = 0; i < length; ++i)
-	{
-		if (data[i] == 0.0)
-		{
-			dfparams->isbeta = 0;
-			dfparams->iszero = 1;
-			break;
-		}
-	}
+    for (i = 0; i < length; ++i)
+    {
+        if (data[i] == 0.0)
+        {
+            dfparams->isbeta = 0;
+            dfparams->iszero = 1;
+            break;
+        }
+    }
 
-	for (i = 0; i < length; ++i)
-	{
-	    if (data[i] < 0.0)
-		{
-			dfparams->isbeta = 0;
-			dfparams->isneg = 1;
-			break;
-		}
-	}
+    for (i = 0; i < length; ++i)
+    {
+        if (data[i] < 0.0)
+        {
+            dfparams->isbeta = 0;
+            dfparams->isneg = 1;
+            break;
+        }
+    }
 }
 
 
 int
 TestDistVsData(const int ndist)
 {
-    if (dist_beta[ndist] == 1 && dfparams->isbeta == 0)
+    if (dist_beta[ndist] && dfparams->isbeta == 0)
         return(0);
-    else if (dist_posdef[ndist] == 1 && dfparams->isneg == 1)
+    else if (dist_posdef[ndist] && dfparams->isneg)
         return(0);
-    else if (dist_nonneg[ndist] == 1 && dfparams->isneg == 1)
+    else if (dist_nonneg[ndist] && dfparams->isneg)
         return(0);
-    else if (dist_posdef[ndist] == 1 && dfparams->iszero == 1)
+    else if (dist_posdef[ndist] && dfparams->iszero)
         return(0);
-    else if (dist_nonneg[ndist] == 1 && dfparams->iszero == 1) /* should return 1, but there are problems fitting data with zeros */
+    else if (dist_nonneg[ndist] && dfparams->iszero) /* should return 1, but there are problems fitting data with zeros */
         return(0);
     else
         return(1);
@@ -1105,7 +1185,7 @@ PrintRandDist(char *fname, double (*dist_dev)(double param1, double param2, cons
     int                    i;
     double                 *array = NULL;
     char                   argstring[64];
-    FILE                   *tmpfile;
+    FILE                   *tmpfile = NULL;
     const gsl_rng_type     *T = NULL;
     gsl_rng                *r2 = NULL;
 
@@ -1329,51 +1409,51 @@ SingleDistFit(DistFit *distfit_func, int distindex, char *dist_name,
 {
     double         param1, param2, chisq, logLper, logL, AIC, BIC;
 
-	param1 = param2 = chisq = logLper = logL = AIC = BIC = 0.0;
-	strcpy(diststats->dist_name, dist_name);
+    param1 = param2 = chisq = logLper = logL = AIC = BIC = 0.0;
+    strcpy(diststats->dist_name, dist_name);
 
-	if (TestDistVsData(distindex) == 0)
-		return;
+    if (TestDistVsData(distindex) == 0)
+        return;
 
-	chisq = distfit_func[distindex](array, length, &param1, &param2, &logL);
-	logLper = logL / (double) length;
+    chisq = distfit_func[distindex](array, length, &param1, &param2, &logL);
+    logLper = logL / (double) length;
 
-	if (chisq == -1.0)
-		diststats->AIC = -DBL_MAX;
+    if (chisq == -1.0)
+        diststats->AIC = -DBL_MAX;
 
-	if (dist_pnum[distindex] == 2)
-	{
-		AIC = logL - ((2.0 * length) / (length - 3.0));
-		BIC = logL - 2.0 * log(length);
-	}
-	else if (dist_pnum[distindex] == 1)
-	{
-		AIC = logL - (length / (length - 2.0));
-		BIC = logL - log(length);
-	}
+    if (dist_pnum[distindex] == 2)
+    {
+        AIC = logL - ((2.0 * length) / (length - 3.0));
+        BIC = logL - 2.0 * log(length);
+    }
+    else if (dist_pnum[distindex] == 1)
+    {
+        AIC = logL - (length / (length - 2.0));
+        BIC = logL - log(length);
+    }
 
-	if (fabs(chisq) > 1e6)
-		chisq = DBL_MAX;
+    if (fabs(chisq) > 1e6)
+        chisq = DBL_MAX;
 
-	if (logLper < -1e7)
-		logLper = -DBL_MAX;
+    if (logLper < -1e7)
+        logLper = -DBL_MAX;
 
-	if (logL < -1e11)
-		logL = -DBL_MAX;
+    if (logL < -1e11)
+        logL = -DBL_MAX;
 
-	if (AIC < -1e11)
-		AIC = -DBL_MAX;
+    if (AIC < -1e11)
+        AIC = -DBL_MAX;
 
-	if (BIC < -1e11)
-		BIC = -DBL_MAX;
+    if (BIC < -1e11)
+        BIC = -DBL_MAX;
 
-	diststats->param1 = param1;
-	diststats->param2 = param2;
-	diststats->chisq = chisq;
-	diststats->logL = logL;
-	diststats->logLper = logLper;
-	diststats->AIC = AIC;
-	diststats->BIC = BIC;
+    diststats->param1 = param1;
+    diststats->param2 = param2;
+    diststats->chisq = chisq;
+    diststats->logL = logL;
+    diststats->logLper = logLper;
+    diststats->AIC = AIC;
+    diststats->BIC = BIC;
 }
 
 
@@ -1472,25 +1552,25 @@ CalcAkaike(DistStats **diststats, int distnum)
         if (TestDistVsData(i) == 0)
             continue;
 
-/* 
+/*
         if(diststats[i]->AIC == -DBL_MAX ||
            diststats[i]->chisq < 0.0)
             continue;
  */
 
         diststats[i]->akaikewt = exp(diststats[i]->AIC - largest);
-        
+
         //printf("\nweight[%d]:%e %e %e", i, diststats[i]->akaikewt, largest, diststats[i]->AIC);
-        
+
         if (!isfinite(diststats[i]->akaikewt))
             diststats[i]->akaikewt = 0.0;
-        
+
         wtsum += diststats[i]->akaikewt;
     }
 
     for(i = 0; i < distnum; ++i)
     {
- 
+
         if (TestDistVsData(i) == 0)
             continue;
 /*
@@ -1583,8 +1663,8 @@ PrintDistSD(DistStats **diststats)
 void
 InsortDiststats_old(DistStats **diststats, int distnum)
 {
-    int            i, j;
-    DistStats       *temp;
+    int             i, j;
+    DistStats      *temp = NULL;
 
     for (i = 0; i < distnum; ++i)
         distsort[i] = i;
@@ -1663,9 +1743,11 @@ Usage(void)
     fprintf(stderr, "     (4)  Cauchy,       (5)  Uniform,   (6)  Weibull,  (7)  Gamma, \n");
     fprintf(stderr, "     (8)  ChiSqrGen,    (9)  Lognormal, (10) InvGamma, (11) InvGauss, \n");
     fprintf(stderr, "     (12) RecInvGauss,  (13) Pareto,    (14) Exp,      (15) InvChiSqr, \n");
-    fprintf(stderr, "     (16) ChiSqr,       (17) Chi,       (18) Rayleigh  (19) Rice, \n"); 
+    fprintf(stderr, "     (16) ChiSqr,       (17) Chi,       (18) Rayleigh  (19) Rice, \n");
     fprintf(stderr, "     (20) Maxwell,      (21) Beta,      (22) BetaSymm, (23) BetaPrime \n");
     fprintf(stderr, "  -D {distribution} -- distribution to simulate, use w/ -np \n");
+    fprintf(stderr, "  -g {x} -- calculate digamma(x) \n");
+    fprintf(stderr, "  -G {x} -- calculate inverse digamma(x) (i.e., find y for x = digamma(y)) \n");
     fprintf(stderr, "  -m {# of mixtures} -- fit a normal mixture distribution \n");
     fprintf(stderr, "  -n {# replicates} -- number of variates to simulate \n");
     fprintf(stderr, "  -p {p1:p2} -- two parameters for a specified distribution (ran # gen) \n");
@@ -1676,6 +1758,7 @@ Usage(void)
     fprintf(stderr, "  -S {x:p1:p2} -- Calculate SDF for x and params p1 and p2 \n");
     fprintf(stderr, "  -s {seed} -- specify a random seed, must be an integer \n");
     fprintf(stderr, "  -t -- do a series of simple data transformations and refit \n");
+    fprintf(stderr, "  -T {x} -- calculate trigamma(x) \n");
     fprintf(stderr, "  -z -- \"fix\" zeros by setting to DBL_EPSILON (%e) \n", DBL_EPSILON);
     fprintf(stderr, "  -o -- \"fix\" ones by setting to 1.0 - DBL_EPSILON \n");
     fprintf(stderr, "  -v -- version \n");
@@ -1719,6 +1802,207 @@ gethistvals(FILE *listfile, double *data, double *freq, int length)
 }
 
 
+static int
+GetFileLen(FILE *fp)
+{
+    int            ch, filelen = 0;
+
+    rewind(fp);
+
+    while(!feof(fp))
+    {
+        ch = getc(fp);
+
+        if (ch == EOF || ch == '\n')
+            ++filelen;
+
+        if (ch == EOF)
+            break;
+    }
+
+    return(filelen);
+}
+
+
+static int
+GetFileColLen(FILE *fp)
+{
+    int            linelen = 4096;
+    char           line[linelen];
+    char           element[linelen];
+    int            i, j, ch, elemlen, nvals, nscan;
+    double         tmp;
+
+    rewind(fp);
+
+    /* keep getting lines as long as the first data element is not a number */
+    while(fgets(line, linelen, fp) != NULL)
+    {
+        nscan = sscanf(line, "%le", &tmp);
+        if (nscan > 0)
+            break;
+    }
+
+    /* null-terminate the line, instead of newline */
+    for (i = 0; i < strlen(line); ++i)
+        if (line[i] == '\r' || line[i] == '\n' || line[i] == '#')
+            line[i] = '\0';
+
+    i = 0; /* column counter */
+    j = 0; /* line position counter */
+    ch = line[0];
+    while(ch != EOF && ch != '\0' && j < linelen)
+    {
+        /* move through whitespace */
+        while (isspace(ch) && ch != EOF && ch != '\0' && j < linelen)
+        {
+            ++j;
+            ch = line[j];
+        }
+
+        nscan = sscanf(&line[j], "%s", element);
+
+        if (nscan > 0)
+        {
+            nvals = sscanf(element, "%le", &tmp);
+            //printf("\ni:%d  j:%d  nvals:%d  elemlen:%d  \n%s %g\n", i, j, nvals, elemlen, element, tmp);
+
+            if(nvals > 0 && isfinite(tmp) && (fabs(tmp) < DBL_MAX))
+                ++i;
+        }
+
+        elemlen = strlen(element);
+
+        //printf("\ni:%d  j:%d  nvals:%d  elemlen:%d  \n%s\n", i, j, nvals, elemlen, element);
+
+        j += elemlen;
+        ch = line[j];
+    }
+
+    return(i);
+}
+
+
+/*
+Reads an entire multi-record, multi-column file of floating point numbers.
+Columns are free-form, separated by white space.
+Allows comments (midline OK) using '#'.
+Also allows blank internal lines.
+Actually, it ignores any lines beginning with a word (i.e., a non-number).
+Longest line allowed is 4096 chars.
+In principle, the number of records and columns is unlimited.
+Returns a (col x recordlen) array of numbers.
+Each column in the file ends up being a contiguous vector of floats.
+*/
+static double
+**ReadValsMulti(const char *listfile_name, int *col, int *len)
+{
+    int            i, j, k, m;
+    int            ch, elemlen, breakout, nscan, nvals, cnt, filelen;
+    int            linelen = 4096;
+    FILE          *listfile = NULL;
+    double       **array = NULL;
+    char           line[linelen];
+    char           element[linelen];
+    double         tmp;
+
+
+    /* Open the file */
+    listfile = fopen(listfile_name, "r");
+    if (listfile == NULL)
+    {
+        fprintf(stderr,
+                "\n ERROR_069: cannot open first file \"%s\" \n",
+                listfile_name);
+        exit(EXIT_FAILURE);
+    }
+
+    /* Count the number of lines in the file; serves as initial (max) guess at number of records */
+    filelen = GetFileLen(listfile);
+
+    /* Now get the number of columns in the first real data record */
+    *col = GetFileColLen(listfile);
+
+    array = MatAlloc(*col, filelen);
+
+    /* Start over --- read the data into the array */
+    rewind(listfile);
+
+    breakout = 0;
+    cnt = 0; /* counter for actual number of data records (not including blank lines, comments, other crap) */
+    for(k = 0; k < filelen; ++k)
+    {
+        nscan = -1;
+        while(nscan <= 0)
+        {
+            if (fgets(line, linelen, listfile) == NULL)
+            {
+                breakout = 1;
+                break;
+            }
+            else
+            {
+                nscan = sscanf(line, "%le", &tmp);
+            }
+        }
+
+        for (m = 0; m < strlen(line); ++m)
+            if (line[m] == '\r' || line[m] == '\n' || line[m] == '#')
+                line[m] = '\0';
+
+        i = 0; /* column counter */
+        j = 0; /* line position counter */
+        ch = line[0];
+        while(breakout == 0 && ch != EOF && ch != '\0' && j < linelen)
+        {
+            while (isspace(ch) && ch != EOF && ch != '\0' && j < linelen)
+            {
+                ++j;
+                ch = line[j];
+            }
+
+            nscan = sscanf(&line[j], "%s", element);
+
+            if (nscan > 0)
+            {
+                nvals = sscanf(element, "%le", &tmp);
+                //printf("\ni:%d  j:%d  nvals:%d  elemlen:%d  \n%s %g\n", i, j, nvals, elemlen, element, tmp);
+
+                if(nvals <= 0 || !isfinite(tmp) || fabs(tmp) > DBL_MAX)
+                {
+                    fprintf(stderr, "\n ERROR_169: value line %d column %d has a problem: %g\n", k, i, tmp);
+                }
+                else
+                {
+                    if (i == 0)
+                        cnt++;
+
+                    array[i][k] = tmp;
+                    ++i;
+                }
+            }
+
+            elemlen = strlen(element);
+            j += elemlen;
+            ch = line[j];
+        }
+//         printf("\n");
+//         for (i = 0; i < *col; ++i)
+//             printf("%g ", array[i][k]);
+    }
+
+    *len = cnt;
+
+    fclose(listfile);
+
+    printf("\nFile length:            %d", filelen);
+    printf("\nNumber of data records: %d", *len);
+    printf("\nNumber of data columns: %d\n", *col);
+
+    return(array);
+}
+
+
 double
 *getvals(char *listfile_name, int *length, int column)
 {
@@ -1841,9 +2125,9 @@ CalcMixProbs(double **probs, const int n, double *mixp, const int mixn)
     for (j = 0; j < mixn; ++j)
     {
         mixp[j] = 0.0;
-		for (i = 0; i < n; ++i)
-			mixp[j] += probs[j][i];
-			
+        for (i = 0; i < n; ++i)
+            mixp[j] += probs[j][i];
+
         mixp[j] /= n;
     }
 }
@@ -1916,13 +2200,13 @@ DistFitMix(DistPDF distpdf, DistFitW distfitw, InitMixParams distinit,
         for (j = 0; j < mixn; ++j)
             printf("%5d:%-2d % f % f % f\n", i, j, param1[j], param2[j], mixp[j]);
 
-		CalcProbs(distpdf, x, probs, n, mixp, mixn, param1, param2);
-		CalcMixProbs(probs, n, mixp, mixn);
+        CalcProbs(distpdf, x, probs, n, mixp, mixn, param1, param2);
+        CalcMixProbs(probs, n, mixp, mixn);
 
         for (j = 0; j < mixn; ++j)
             distfitw(x, n, probs[j], &param1[j], &param2[j], &logL);
 
-        if (VecEq(oldprobs, probs[0], n, tol) == 1 && i > 4)
+        if (VecEq(oldprobs, probs[0], n, tol) && i > 4)
             break;
     }
 
