@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -129,6 +129,10 @@ typedef struct
     int             mix;
     int             fixzeros;
     int             fixones;
+    double          digamma;
+    double          trigamma;
+    double          invdigamma;
+    int             neg;
 } DFParams;
 
 
