@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -547,7 +547,7 @@ gamma_fit(const double *data, const int num, double *b, double *c, double *logL)
 void
 gamma_fit_no_stats(const double *data, const int num, double *b, double *c)
 {
-    double          ave, /* var,  */logterm, logdata, fx, dfx, fxdfx, guess_b, guess_c;
+    double          ave, /* var,  */logterm, logdata, fx, dfx, fxdfx;
     int             i, maxiter = 500;
     double          tol = FLT_EPSILON;
 
@@ -604,8 +604,6 @@ gamma_fit_no_stats(const double *data, const int num, double *b, double *c)
     if (*c > FLT_MAX)
         *c = FLT_MAX;
 
-    guess_b = *b;
-    guess_c = *c;
     /* Maximum likelihood fit. */
     /* Use Newton-Raphson to find ML estimate of c
        Based on _Statistical Distributions_ 3rd ed. Evans, Hastings, and Peacock, p 41.
