@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2008 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@
 */
 
 
-/* 
-static double 
+/*
+static double
 pseudo_vonmises_target(const double a, const double b, const double x)
 {
     return(a * cos(x) + b * cos(x));
@@ -57,8 +57,8 @@ pseudo_vonmises_target(const double a, const double b, const double x)
 
 
 
-/* 
-static double 
+/*
+static double
 mardia_gadsden_target(const double a, const double b, const double x)
 {
     return((a * cos(x) + b * cos(x)) * cos(x));
@@ -67,7 +67,7 @@ mardia_gadsden_target(const double a, const double b, const double x)
 
 
 
-/* 
+/*
 double
 pseudo_vonmises_met(const double a, const double b, const double x)
 {
@@ -89,7 +89,7 @@ pseudo_vonmises_met(const double a, const double b, const double x)
 
 
 
-/* 
+/*
 double
 mardia_gadsden_met(const double a, const double b, const double x)
 {
@@ -124,7 +124,7 @@ wrap_0_2PI(double x)
 }
 
 
-/* 
+/*
 double
 vonmises_dev2(const double k)
 {
@@ -147,7 +147,7 @@ vonmises_dev2(const double k)
         z = cos(MY_PI * u);
         w = (1.0 + s*z) / (s + z);
         y = k * (s - w);
-        
+
         if (w * (2.0 - w) - v > DBL_MIN)
             accept = 1;
         else if (log(w/v) + 1.0 > DBL_MIN)
@@ -164,6 +164,67 @@ vonmises_dev2(const double k)
  */
 
 
+double
+vonmises_dev2(const double mean, const double k, const gsl_rng *r2)
+{
+    double result = 0.0;
+
+    double a = 1.0 + sqrt(1 + 4.0 * (k * k));
+    double b = (a - sqrt(2.0 * a))/(2.0 * k);
+    double r = (1.0 + b * b)/(2.0 * b);
+
+    while (1)
+    {
+        double U1 = gsl_ran_flat(r2, 0.0, 1.0);
+        double z = cos(MY_PI * U1);
+        double f = (1.0 + r * z)/(r + z);
+        double c = k * (r - f);
+        double U2 = gsl_ran_flat(r2, 0.0, 1.0);
+
+        if (c * (2.0 - c) - U2 > 0.0)
+        {
+            double U3 = gsl_ran_flat(r2, 0.0, 1.0);
+            double sign = 0.0;
+
+            if (U3 - 0.5 < 0.0)
+                sign = -1.0;
+
+            if (U3 - 0.5 > 0.0)
+                sign = 1.0;
+
+            result = sign * acos(f) + mean;
+
+            while (result >= 2.0 * MY_PI)
+                result -= 2.0 * MY_PI;
+
+            break;
+        }
+        else
+        {
+            if(log(c/U2) + 1.0 - c >= 0.0)
+            {
+                double U3 = gsl_ran_flat(r2, 0.0, 1.0);
+                double sign = 0.0;
+
+                if (U3 - 0.5 < 0.0)
+                    sign = -1.0;
+
+                if (U3 - 0.5 > 0.0)
+                    sign = 1.0;
+
+                result = sign * acos(f) + mean;
+
+                while (result >= 2.0 * MY_PI)
+                    result -= 2.0 * MY_PI;
+
+                break;
+            }
+        }
+    }
+
+    return(result);
+}
+
 
 /* D. J. Best and N. I. Fisher (1979)
    "Efficient simulation of the von Mises distribution."
@@ -173,6 +234,9 @@ vonmises_dev(const double a, const double b, const gsl_rng *r2)
 {
     double          z, f, c, t, p, r;
 
+    if (b < DBL_EPSILON)
+        return(a);
+
     t = 1.0 + sqrt(1.0 + 4.0*b*b);
     p = 0.5*(t - sqrt(2.0*t))/b;
     r = 0.5*(1.0 + p*p)/p;
@@ -272,7 +336,7 @@ vonmises_logL(const double a, const double b)
        F1' = I_0(b) [\Sum{cos(x-a)} - N] - (N/2) I_1(b)
 */
 void
-evalvonmisesML(const double cosdif, const double b, const int num, 
+evalvonmisesML(const double cosdif, const double b, const int num,
                    double *fx, double *dfx)
 {
     double          i0b = BesselI0(b);
@@ -284,7 +348,7 @@ evalvonmisesML(const double cosdif, const double b, const int num,
 
 
 void
-evalvonmisesML_EHP(const double sincosterm, const double b, const int num, 
+evalvonmisesML_EHP(const double sincosterm, const double b, const int num,
                double *fx, double *dfx)
 {
     double          i0b = BesselI0(b);
@@ -296,7 +360,7 @@ evalvonmisesML_EHP(const double sincosterm, const double b, const int num,
 
 
 static void
-evalvonmisesMLmu(const double *data, const double a, const int num, 
+evalvonmisesMLmu(const double *data, const double a, const int num,
                  double *fx, double *dfx)
 {
     double          sinsum, cossum;
@@ -357,19 +421,19 @@ vonmises_fit(const double *data, const int num, double *a, double *b, double *pr
     }
 
     /* For a (mu), well, we use my own derivation that I've never seen
-       anywhere but it seems straight-forward to me. 
+       anywhere but it seems straight-forward to me.
        Evans, Hastings, and Peacock 2000 (_Statistical Distributions_) give
        the MLE as:
-       
+
            \hat{mu} = arctan[\Sum{sin x_i}/\Sum{cos x_i}]
-           
+
        but this has problems, it gives a negative answer for real
        mu = 3, 4 etc. Part of the problem is fixed by using atan2,
        which computes the correct quadrant, but it still doesn't
        always work. So, I simply did the standard MLE derivation --
-       take the log of the PDF, take the first derivative, set it 
+       take the log of the PDF, take the first derivative, set it
        to zero, and you get:
-       
+
             \Sum{sin(x - mu)} = 0
 
         which can't be solved analytically, but can easily be solved
