@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ double
 **Mat3Ident(double **matrix)
 {
     matrix[0][0] = matrix[1][1] = matrix[2][2] = 1.0;
-    matrix[0][1] = matrix[0][2] = matrix[1][0] = 
+    matrix[0][1] = matrix[0][2] = matrix[1][0] =
     matrix[1][2] = matrix[2][0] = matrix[2][1] = 0.0;
 
     return(matrix);
@@ -83,6 +83,26 @@ Mat3Eq(const double **matrix1, const double **matrix2, const double precision)
 }
 
 
+double
+Mat3FrobDiff(const double **mat1, const double **mat2)
+{
+    int             i, j;
+    double          frobnorm, tmp;
+
+    frobnorm = 0.0;
+    for (i = 0; i < 3; ++i)
+    {
+        for (j = 0; j < 3; ++j)
+        {
+            tmp = mat2[i][j] - mat1[i][j];
+            frobnorm += tmp * tmp;
+        }
+    }
+
+    return(sqrt(frobnorm / 3.0));
+}
+
+
 /* check for the equivalence of two matrices based on the Frobenius
    norm criterion (more statistically justified than the above) */
 int
@@ -101,7 +121,7 @@ Mat3FrobEq(const double **mat1, const double **mat2, const double precision)
         }
     }
 
-    if (sqrt(frobnorm / 9.0) < precision)
+    if (sqrt(frobnorm / 3.0) < precision)
         return(1);
     else
         return(0);
@@ -118,15 +138,15 @@ Mat3Cpy(double **matrix2, const double **matrix1)
 /* A x B = C */
 void
 Mat3MultOp(double **C, const double **A, const double **B)
-{   
+{
     C[0][0] = A[0][0]*B[0][0] + A[0][1]*B[1][0] + A[0][2]*B[2][0];
     C[1][0] = A[1][0]*B[0][0] + A[1][1]*B[1][0] + A[1][2]*B[2][0];
-    C[2][0] = A[2][0]*B[0][0] + A[2][1]*B[1][0] + A[2][2]*B[2][0]; 
-    
+    C[2][0] = A[2][0]*B[0][0] + A[2][1]*B[1][0] + A[2][2]*B[2][0];
+
     C[0][1] = A[0][0]*B[0][1] + A[0][1]*B[1][1] + A[0][2]*B[2][1];
     C[1][1] = A[1][0]*B[0][1] + A[1][1]*B[1][1] + A[1][2]*B[2][1];
     C[2][1] = A[2][0]*B[0][1] + A[2][1]*B[1][1] + A[2][2]*B[2][1];
-    
+
     C[0][2] = A[0][0]*B[0][2] + A[0][1]*B[1][2] + A[0][2]*B[2][2];
     C[1][2] = A[1][0]*B[0][2] + A[1][1]*B[1][2] + A[1][2]*B[2][2];
     C[2][2] = A[2][0]*B[0][2] + A[2][1]*B[1][2] + A[2][2]*B[2][2];
@@ -141,16 +161,16 @@ Mat3MultIp(double **A, const double **B)
 
     C00 = A[0][0]*B[0][0] + A[0][1]*B[1][0] + A[0][2]*B[2][0];
     C10 = A[1][0]*B[0][0] + A[1][1]*B[1][0] + A[1][2]*B[2][0];
-    C20 = A[2][0]*B[0][0] + A[2][1]*B[1][0] + A[2][2]*B[2][0]; 
-    
+    C20 = A[2][0]*B[0][0] + A[2][1]*B[1][0] + A[2][2]*B[2][0];
+
     C01 = A[0][0]*B[0][1] + A[0][1]*B[1][1] + A[0][2]*B[2][1];
     C11 = A[1][0]*B[0][1] + A[1][1]*B[1][1] + A[1][2]*B[2][1];
     C21 = A[2][0]*B[0][1] + A[2][1]*B[1][1] + A[2][2]*B[2][1];
-    
+
     C02 = A[0][0]*B[0][2] + A[0][1]*B[1][2] + A[0][2]*B[2][2];
     C12 = A[1][0]*B[0][2] + A[1][1]*B[1][2] + A[1][2]*B[2][2];
     C22 = A[2][0]*B[0][2] + A[2][1]*B[1][2] + A[2][2]*B[2][2];
-    
+
     A[0][0] = C00;
     A[1][0] = C10;
     A[2][0] = C20;
@@ -168,15 +188,15 @@ Mat3MultIp(double **A, const double **B)
 /* C = USV, where S is diagonal */
 void
 Mat3MultUSVOp(double **C, const double **U, double *S, const double **V)
-{   
+{
     C[0][0] = (U[0][0] * S[0]) * V[0][0] + (U[0][1] * S[1]) * V[1][0] + (U[0][2] * S[2]) * V[2][0];
     C[1][0] = (U[1][0] * S[0]) * V[0][0] + (U[1][1] * S[1]) * V[1][0] + (U[1][2] * S[2]) * V[2][0];
-    C[2][0] = (U[2][0] * S[0]) * V[0][0] + (U[2][1] * S[1]) * V[1][0] + (U[2][2] * S[2]) * V[2][0]; 
-    
+    C[2][0] = (U[2][0] * S[0]) * V[0][0] + (U[2][1] * S[1]) * V[1][0] + (U[2][2] * S[2]) * V[2][0];
+
     C[0][1] = (U[0][0] * S[0]) * V[0][1] + (U[0][1] * S[1]) * V[1][1] + (U[0][2] * S[2]) * V[2][1];
     C[1][1] = (U[1][0] * S[0]) * V[0][1] + (U[1][1] * S[1]) * V[1][1] + (U[1][2] * S[2]) * V[2][1];
     C[2][1] = (U[2][0] * S[0]) * V[0][1] + (U[2][1] * S[1]) * V[1][1] + (U[2][2] * S[2]) * V[2][1];
-    
+
     C[0][2] = (U[0][0] * S[0]) * V[0][2] + (U[0][1] * S[1]) * V[1][2] + (U[0][2] * S[2]) * V[2][2];
     C[1][2] = (U[1][0] * S[0]) * V[0][2] + (U[1][1] * S[1]) * V[1][2] + (U[1][2] * S[2]) * V[2][2];
     C[2][2] = (U[2][0] * S[0]) * V[0][2] + (U[2][1] * S[1]) * V[1][2] + (U[2][2] * S[2]) * V[2][2];
@@ -191,16 +211,16 @@ Mat3PreMultIp(const double **A, double **B)
 
     C00 = B[0][0]*A[0][0] + B[0][1]*A[1][0] + B[0][2]*A[2][0];
     C10 = B[1][0]*A[0][0] + B[1][1]*A[1][0] + B[1][2]*A[2][0];
-    C20 = B[2][0]*A[0][0] + B[2][1]*A[1][0] + B[2][2]*A[2][0]; 
-    
+    C20 = B[2][0]*A[0][0] + B[2][1]*A[1][0] + B[2][2]*A[2][0];
+
     C01 = B[0][0]*A[0][1] + B[0][1]*A[1][1] + B[0][2]*A[2][1];
     C11 = B[1][0]*A[0][1] + B[1][1]*A[1][1] + B[1][2]*A[2][1];
     C21 = B[2][0]*A[0][1] + B[2][1]*A[1][1] + B[2][2]*A[2][1];
-    
+
     C02 = B[0][0]*A[0][2] + B[0][1]*A[1][2] + B[0][2]*A[2][2];
     C12 = B[1][0]*A[0][2] + B[1][1]*A[1][2] + B[1][2]*A[2][2];
     C22 = B[2][0]*A[0][2] + B[2][1]*A[1][2] + B[2][2]*A[2][2];
-    
+
     B[0][0] = C00;
     B[1][0] = C10;
     B[2][0] = C20;
@@ -218,15 +238,15 @@ Mat3PreMultIp(const double **A, double **B)
 /* A x A = C */
 void
 Mat3Sqr(double **C, const double **A)
-{   
+{
     C[0][0] = A[0][0]*A[0][0] + A[0][1]*A[1][0] + A[0][2]*A[2][0];
     C[1][0] = A[1][0]*A[0][0] + A[1][1]*A[1][0] + A[1][2]*A[2][0];
-    C[2][0] = A[2][0]*A[0][0] + A[2][1]*A[1][0] + A[2][2]*A[2][0]; 
-    
+    C[2][0] = A[2][0]*A[0][0] + A[2][1]*A[1][0] + A[2][2]*A[2][0];
+
     C[0][1] = A[0][0]*A[0][1] + A[0][1]*A[1][1] + A[0][2]*A[2][1];
     C[1][1] = A[1][0]*A[0][1] + A[1][1]*A[1][1] + A[1][2]*A[2][1];
     C[2][1] = A[2][0]*A[0][1] + A[2][1]*A[1][1] + A[2][2]*A[2][1];
-    
+
     C[0][2] = A[0][0]*A[0][2] + A[0][1]*A[1][2] + A[0][2]*A[2][2];
     C[1][2] = A[1][0]*A[0][2] + A[1][1]*A[1][2] + A[1][2]*A[2][2];
     C[2][2] = A[2][0]*A[0][2] + A[2][1]*A[1][2] + A[2][2]*A[2][2];
@@ -236,15 +256,15 @@ Mat3Sqr(double **C, const double **A)
 /* A x ~A = C */
 void
 Mat3SqrTrans2(double **C, const double **A)
-{   
+{
     C[0][0] = A[0][0]*A[0][0] + A[0][1]*A[0][1] + A[0][2]*A[0][2];
     C[1][0] = A[1][0]*A[0][0] + A[1][1]*A[0][1] + A[1][2]*A[0][2];
-    C[2][0] = A[2][0]*A[0][0] + A[2][1]*A[0][1] + A[2][2]*A[0][2]; 
-    
+    C[2][0] = A[2][0]*A[0][0] + A[2][1]*A[0][1] + A[2][2]*A[0][2];
+
     C[0][1] = A[0][0]*A[1][0] + A[0][1]*A[1][1] + A[0][2]*A[1][2];
     C[1][1] = A[1][0]*A[1][0] + A[1][1]*A[1][1] + A[1][2]*A[1][2];
     C[2][1] = A[2][0]*A[1][0] + A[2][1]*A[1][1] + A[2][2]*A[1][2];
-    
+
     C[0][2] = A[0][0]*A[2][0] + A[0][1]*A[2][1] + A[0][2]*A[2][2];
     C[1][2] = A[1][0]*A[2][0] + A[1][1]*A[2][1] + A[1][2]*A[2][2];
     C[2][2] = A[2][0]*A[2][0] + A[2][1]*A[2][1] + A[2][2]*A[2][2];
@@ -254,15 +274,15 @@ Mat3SqrTrans2(double **C, const double **A)
 /* ~A x A = C */
 void
 Mat3SqrTrans1(double **C, const double **A)
-{   
+{
     C[0][0] = A[0][0]*A[0][0] + A[1][0]*A[1][0] + A[2][0]*A[2][0];
     C[1][0] = A[0][1]*A[0][0] + A[1][1]*A[1][0] + A[2][1]*A[2][0];
-    C[2][0] = A[0][2]*A[0][0] + A[1][2]*A[1][0] + A[2][2]*A[2][0]; 
-    
+    C[2][0] = A[0][2]*A[0][0] + A[1][2]*A[1][0] + A[2][2]*A[2][0];
+
     C[0][1] = A[0][0]*A[0][1] + A[1][0]*A[1][1] + A[2][0]*A[2][1];
     C[1][1] = A[0][1]*A[0][1] + A[1][1]*A[1][1] + A[2][1]*A[2][1];
     C[2][1] = A[0][2]*A[0][1] + A[1][2]*A[1][1] + A[2][2]*A[2][1];
-    
+
     C[0][2] = A[0][0]*A[0][2] + A[1][0]*A[1][2] + A[2][0]*A[2][2];
     C[1][2] = A[0][1]*A[0][2] + A[1][1]*A[1][2] + A[2][1]*A[2][2];
     C[2][2] = A[0][2]*A[0][2] + A[1][2]*A[1][2] + A[2][2]*A[2][2];
@@ -272,15 +292,15 @@ Mat3SqrTrans1(double **C, const double **A)
 /* ~A x ~A = C */
 void
 Mat3TransSqr(double **C, const double **A)
-{   
+{
     C[0][0] = A[0][0]*A[0][0] + A[0][1]*A[1][0] + A[0][2]*A[2][0];
     C[0][1] = A[1][0]*A[0][0] + A[1][1]*A[1][0] + A[1][2]*A[2][0];
-    C[0][2] = A[2][0]*A[0][0] + A[2][1]*A[1][0] + A[2][2]*A[2][0]; 
-    
+    C[0][2] = A[2][0]*A[0][0] + A[2][1]*A[1][0] + A[2][2]*A[2][0];
+
     C[1][0] = A[0][0]*A[0][1] + A[0][1]*A[1][1] + A[0][2]*A[2][1];
     C[1][1] = A[1][0]*A[0][1] + A[1][1]*A[1][1] + A[1][2]*A[2][1];
     C[1][2] = A[2][0]*A[0][1] + A[2][1]*A[1][1] + A[2][2]*A[2][1];
-    
+
     C[2][0] = A[0][0]*A[0][2] + A[0][1]*A[1][2] + A[0][2]*A[2][2];
     C[2][1] = A[1][0]*A[0][2] + A[1][1]*A[1][2] + A[1][2]*A[2][2];
     C[2][2] = A[2][0]*A[0][2] + A[2][1]*A[1][2] + A[2][2]*A[2][2];
@@ -290,15 +310,15 @@ Mat3TransSqr(double **C, const double **A)
 /* ~A x B = C */
 void
 Mat3MultTransA(double **C, const double **A, const double **B)
-{   
+{
     C[0][0] = A[0][0]*B[0][0] + A[1][0]*B[1][0] + A[2][0]*B[2][0];
     C[1][0] = A[0][1]*B[0][0] + A[1][1]*B[1][0] + A[2][1]*B[2][0];
-    C[2][0] = A[0][2]*B[0][0] + A[1][2]*B[1][0] + A[2][2]*B[2][0]; 
-    
+    C[2][0] = A[0][2]*B[0][0] + A[1][2]*B[1][0] + A[2][2]*B[2][0];
+
     C[0][1] = A[0][0]*B[0][1] + A[1][0]*B[1][1] + A[2][0]*B[2][1];
     C[1][1] = A[0][1]*B[0][1] + A[1][1]*B[1][1] + A[2][1]*B[2][1];
     C[2][1] = A[0][2]*B[0][1] + A[1][2]*B[1][1] + A[2][2]*B[2][1];
-    
+
     C[0][2] = A[0][0]*B[0][2] + A[1][0]*B[1][2] + A[2][0]*B[2][2];
     C[1][2] = A[0][1]*B[0][2] + A[1][1]*B[1][2] + A[2][1]*B[2][2];
     C[2][2] = A[0][2]*B[0][2] + A[1][2]*B[1][2] + A[2][2]*B[2][2];
@@ -308,15 +328,15 @@ Mat3MultTransA(double **C, const double **A, const double **B)
 /* A x ~B = C */
 void
 Mat3MultTransB(double **C, const double **A, const double **B)
-{   
+{
     C[0][0] = A[0][0]*B[0][0] + A[0][1]*B[0][1] + A[0][2]*B[0][2];
     C[1][0] = A[1][0]*B[0][0] + A[1][1]*B[0][1] + A[1][2]*B[0][2];
-    C[2][0] = A[2][0]*B[0][0] + A[2][1]*B[0][1] + A[2][2]*B[0][2]; 
-    
+    C[2][0] = A[2][0]*B[0][0] + A[2][1]*B[0][1] + A[2][2]*B[0][2];
+
     C[0][1] = A[0][0]*B[1][0] + A[0][1]*B[1][1] + A[0][2]*B[1][2];
     C[1][1] = A[1][0]*B[1][0] + A[1][1]*B[1][1] + A[1][2]*B[1][2];
     C[2][1] = A[2][0]*B[1][0] + A[2][1]*B[1][1] + A[2][2]*B[1][2];
-    
+
     C[0][2] = A[0][0]*B[2][0] + A[0][1]*B[2][1] + A[0][2]*B[2][2];
     C[1][2] = A[1][0]*B[2][0] + A[1][1]*B[2][1] + A[1][2]*B[2][2];
     C[2][2] = A[2][0]*B[2][0] + A[2][1]*B[2][1] + A[2][2]*B[2][2];
@@ -325,15 +345,15 @@ Mat3MultTransB(double **C, const double **A, const double **B)
 
 void
 Mat3Add(double **C, const double **A, const double **B)
-{   
+{
     C[0][0] = A[0][0] + B[0][0];
     C[1][0] = A[1][0] + B[1][0];
-    C[2][0] = A[2][0] + B[2][0]; 
-    
+    C[2][0] = A[2][0] + B[2][0];
+
     C[0][1] = A[0][1] + B[0][1];
     C[1][1] = A[1][1] + B[1][1];
     C[2][1] = A[2][1] + B[2][1];
-    
+
     C[0][2] = A[0][2] + B[0][2];
     C[1][2] = A[1][2] + B[1][2];
     C[2][2] = A[2][2] + B[2][2];
@@ -342,15 +362,15 @@ Mat3Add(double **C, const double **A, const double **B)
 
 void
 Mat3Sub(double **A, double **B, double **C)
-{   
+{
     C[0][0] = A[0][0] - B[0][0];
     C[1][0] = A[1][0] - B[1][0];
-    C[2][0] = A[2][0] - B[2][0]; 
-    
+    C[2][0] = A[2][0] - B[2][0];
+
     C[0][1] = A[0][1] - B[0][1];
     C[1][1] = A[1][1] - B[1][1];
     C[2][1] = A[2][1] - B[2][1];
-    
+
     C[0][2] = A[0][2] - B[0][2];
     C[1][2] = A[1][2] - B[1][2];
     C[2][2] = A[2][2] - B[2][2];
@@ -407,7 +427,7 @@ double
 Mat3Det(const double **matrix)
 {
     double det;
-    
+
     det =  matrix[0][0] * (matrix[1][1] * matrix[2][2] - matrix[1][2] * matrix[2][1])
          - matrix[1][0] * (matrix[0][1] * matrix[2][2] - matrix[0][2] * matrix[2][1])
          + matrix[2][0] * (matrix[0][1] * matrix[1][2] - matrix[0][2] * matrix[1][1]);
@@ -492,6 +512,7 @@ VerifyRotMat(double **rotmat, double tol)
             printf(" ERROR: rotation matrix not normalized\n");
             printf("        row %d sum = %f, column %d sum = %f\n", i, sum1, j, sum2);
             fflush(NULL);
+
             return(0);
         }
     }
@@ -537,11 +558,12 @@ VerifyRotMat(double **rotmat, double tol)
     }
 
     MatDestroy(&testmat);
+
     return(1);
 }
 
 
-/* returns the closest orthogonal, normalized, rotation matrix to the 
+/* returns the closest orthogonal, normalized, rotation matrix to the
    input matrix */
 void
 ClosestRotMatIp(double **inmat)
@@ -555,7 +577,7 @@ ClosestRotMatIp(double **inmat)
     Mat3TransposeIp(vt);
     Mat3Cpy(u, (const double **) inmat);
 
-    //dgesvd_opt_dest(inmat, 3, 3, u, s, vt);
+    // dgesvd_opt_dest(inmat, 3, 3, u, s, vt);
 
     /* this guarantees that the determinant of the rot mat is positive,
        as required */
@@ -568,123 +590,124 @@ ClosestRotMatIp(double **inmat)
 
     MatDestroy(&u);
     MatDestroy(&vt);
+
     free(s);
 }
 
 
 /* Converts an orthogonal 3x3 rotation matrix to its axis/angle
    representation.  It returns the angle, and the axis unit
-   vector is supplied in v[] 
+   vector is supplied in v[]
    Based on:
    http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/index.htm
 */
 double
 RotMat2AxisAngle(double **rot, double *v)
 {
-	double          epsilon = FLT_EPSILON;
-	double          angle, x, y, z, s, tx, ty, tz;
-	int             xZero, yZero, zZero, xyPos, xzPos, yzPos;
+    double          epsilon = FLT_EPSILON;
+    double          angle, x, y, z, s, tx, ty, tz;
+    int             xZero, yZero, zZero, xyPos, xzPos, yzPos;
 
 //MatPrint(rot, 3);
 
-	if (fabs(rot[0][1] - rot[1][0]) < epsilon && 
-	    fabs(rot[0][2] - rot[2][0]) < epsilon && 
-	    fabs(rot[1][2] - rot[2][1]) < epsilon)
-	{// singularity found
+    if (fabs(rot[0][1] - rot[1][0]) < epsilon &&
+        fabs(rot[0][2] - rot[2][0]) < epsilon &&
+        fabs(rot[1][2] - rot[2][1]) < epsilon)
+    {// singularity found
         if (rot[0][0] > 0.0 && rot[1][1] > 0.0 && rot[2][2] > 0.0)
-		{
-			// this singularity is identity matrix so angle = 0
-			// note epsilon is greater in this case since we only have to distinguish between 0 and 180 degrees
-			//angle = 0.0;
-			v[0] = 1.0;  // axis is arbitrary
-			v[1] = 0.0;
-			v[2] = 0.0;
+        {
+            // this singularity is identity matrix so angle = 0
+            // note epsilon is greater in this case since we only have to distinguish between 0 and 180 degrees
+            //angle = 0.0;
+            v[0] = 1.0;  // axis is arbitrary
+            v[1] = 0.0;
+            v[2] = 0.0;
 
-			return(0.0);
-		}
-		else
-		{
-			// otherwise this singularity is angle = 180
-			angle = MY_PI;
-
-			x = 0.5 * (rot[0][0] + 1.0);
-
-			if (x > 0.0) // can only take square root of positive number, always true for orthogonal matrix
-				x = sqrt(x);
-			else
-				x = 0.0; // in case matrix has become de-orthogonalised
-
-			y = 0.5 * (rot[1][1] + 1.0);
-
-			if (y > 0.0) // can only take square root of positive number, always true for orthogonal matrix
-				y = sqrt(y);
-			else
-				y = 0.0; // in case matrix has become de-orthogonalised
-
-			z = 0.5 * (rot[2][2] + 1.0);
-
-			if (z > 0.0) // can only take square root of positive number, always true for orthogonal matrix
-				z = sqrt(z);
-			else
-				z = 0.0; // in case matrix has become de-orthogonalised
-
-			xZero = (fabs(x) < epsilon);
-			yZero = (fabs(y) < epsilon);
-			zZero = (fabs(z) < epsilon);
-			xyPos = (rot[0][1] > 0.0);
-			xzPos = (rot[0][2] > 0.0);
-			yzPos = (rot[1][2] > 0.0);
-
-			if (xZero && !yZero && !zZero) // implements  last 6 rows of above table
-			{
-				if (!yzPos)
-					y = -y;
-			}
-			else if (yZero && !zZero)
-			{
-				if (!xzPos)
-					z = -z;
-			}
-			else if (zZero)
-			{
-				if (!xyPos)
-					x = -x;
-			}
-
-			v[0] = x;
-			v[1] = y;
-			v[2] = z;
-
-			return(angle);
+            return(0.0);
         }
-	}
-	else
-	{
-	    tx = rot[2][1] - rot[1][2];
-	    ty = rot[0][2] - rot[2][0];
-	    tz = rot[1][0] - rot[0][1];
-		s = sqrt(tx*tx + ty*ty + tz*tz); // used to normalise
+        else
+        {
+            // otherwise this singularity is angle = 180
+            angle = MY_PI;
 
-		if (fabs(s) < epsilon)
-			s = 1.0; // prevent divide by zero, should not happen if matrix is orthogonal
+            x = 0.5 * (rot[0][0] + 1.0);
 
-		angle = acos(0.5 * (rot[0][0] + rot[1][1] + rot[2][2] - 1.0));
-		x = (rot[2][1] - rot[1][2]) / s;
-		y = (rot[0][2] - rot[2][0]) / s;
-		z = (rot[1][0] - rot[0][1]) / s;
+            if (x > 0.0) // can only take square root of positive number, always true for orthogonal matrix
+                x = sqrt(x);
+            else
+                x = 0.0; // in case matrix has become de-orthogonalised
 
-		v[0] = x;
-		v[1] = y;
-		v[2] = z;
+            y = 0.5 * (rot[1][1] + 1.0);
 
-		return(angle);
+            if (y > 0.0) // can only take square root of positive number, always true for orthogonal matrix
+                y = sqrt(y);
+            else
+                y = 0.0; // in case matrix has become de-orthogonalised
+
+            z = 0.5 * (rot[2][2] + 1.0);
+
+            if (z > 0.0) // can only take square root of positive number, always true for orthogonal matrix
+                z = sqrt(z);
+            else
+                z = 0.0; // in case matrix has become de-orthogonalised
+
+            xZero = (fabs(x) < epsilon);
+            yZero = (fabs(y) < epsilon);
+            zZero = (fabs(z) < epsilon);
+            xyPos = (rot[0][1] > 0.0);
+            xzPos = (rot[0][2] > 0.0);
+            yzPos = (rot[1][2] > 0.0);
+
+            if (xZero && !yZero && !zZero) // implements  last 6 rows of above table
+            {
+                if (!yzPos)
+                    y = -y;
+            }
+            else if (yZero && !zZero)
+            {
+                if (!xzPos)
+                    z = -z;
+            }
+            else if (zZero)
+            {
+                if (!xyPos)
+                    x = -x;
+            }
+
+            v[0] = x;
+            v[1] = y;
+            v[2] = z;
+
+            return(angle);
+        }
+    }
+    else
+    {
+        tx = rot[2][1] - rot[1][2];
+        ty = rot[0][2] - rot[2][0];
+        tz = rot[1][0] - rot[0][1];
+        s = sqrt(tx*tx + ty*ty + tz*tz); // used to normalise
+
+        if (fabs(s) < epsilon)
+            s = 1.0; // prevent divide by zero, should not happen if matrix is orthogonal
+
+        angle = acos(0.5 * (rot[0][0] + rot[1][1] + rot[2][2] - 1.0));
+        x = (rot[2][1] - rot[1][2]) / s;
+        y = (rot[0][2] - rot[2][0]) / s;
+        z = (rot[1][0] - rot[0][1]) / s;
+
+        v[0] = x;
+        v[1] = y;
+        v[2] = z;
+
+        return(angle);
     }
 }
 
 
 /* Converts an orthogonal 3x3 rotation matrix to its axis/angle
    representation.  It returns the angle, and the axis unit
-   vector is supplied in v[] 
+   vector is supplied in v[]
    Based on:
    http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/index.htm
    First converts a rot matrix to a quaternion, then to the angle/axis representation.
@@ -696,42 +719,42 @@ RotMat2AxisAngleQuat(double **rot, double *v)
     double              trace, angle, s, t, invt, w, x, y, z;
 
     /* convert to quaternion */
-    trace = rot[0][0] + rot[1][1] + rot[2][2] + 1.0; 
+    trace = rot[0][0] + rot[1][1] + rot[2][2] + 1.0;
 
     if( trace > FLT_EPSILON )
     {
-		s = 0.5 / sqrt(trace);
-		w = 0.25 / s;
-		x = ( rot[2][1] - rot[1][2] ) * s;
-		y = ( rot[0][2] - rot[2][0] ) * s;
-		z = ( rot[1][0] - rot[0][1] ) * s;
+        s = 0.5 / sqrt(trace);
+        w = 0.25 / s;
+        x = ( rot[2][1] - rot[1][2] ) * s;
+        y = ( rot[0][2] - rot[2][0] ) * s;
+        z = ( rot[1][0] - rot[0][1] ) * s;
     }
     else
     {
-		if (rot[0][0] > rot[1][1] && rot[0][0] > rot[2][2])
-		{
-			s = 2.0 * sqrt( 1.0 + rot[0][0] - rot[1][1] - rot[2][2]);
-			x = 0.25 * s;
-			y = (rot[0][1] + rot[1][0] ) / s;
-			z = (rot[0][2] + rot[2][0] ) / s;
-			w = (rot[1][2] - rot[2][1] ) / s;
-	    }
-	    else if (rot[1][1] > rot[2][2])
-	    {
-			s = 2.0 * sqrt(1.0 + rot[1][1] - rot[0][0] - rot[2][2]);
-			x = (rot[0][1] + rot[1][0] ) / s;
-			y = 0.25 * s;
-			z = (rot[1][2] + rot[2][1] ) / s;
-			w = (rot[0][2] - rot[2][0] ) / s;
-		}
-		else
-		{
-			s = 2.0 * sqrt(1.0 + rot[2][2] - rot[0][0] - rot[1][1]);
-			x = (rot[0][2] + rot[2][0] ) / s;
-			y = (rot[1][2] + rot[2][1] ) / s;
-			z = 0.25 * s;
-			w = (rot[0][1] - rot[1][0] ) / s;
-		}
+        if (rot[0][0] > rot[1][1] && rot[0][0] > rot[2][2])
+        {
+            s = 2.0 * sqrt( 1.0 + rot[0][0] - rot[1][1] - rot[2][2]);
+            x = 0.25 * s;
+            y = (rot[0][1] + rot[1][0] ) / s;
+            z = (rot[0][2] + rot[2][0] ) / s;
+            w = (rot[1][2] - rot[2][1] ) / s;
+        }
+        else if (rot[1][1] > rot[2][2])
+        {
+            s = 2.0 * sqrt(1.0 + rot[1][1] - rot[0][0] - rot[2][2]);
+            x = (rot[0][1] + rot[1][0] ) / s;
+            y = 0.25 * s;
+            z = (rot[1][2] + rot[2][1] ) / s;
+            w = (rot[0][2] - rot[2][0] ) / s;
+        }
+        else
+        {
+            s = 2.0 * sqrt(1.0 + rot[2][2] - rot[0][0] - rot[1][1]);
+            x = (rot[0][2] + rot[2][0] ) / s;
+            y = (rot[1][2] + rot[2][1] ) / s;
+            z = 0.25 * s;
+            w = (rot[0][1] - rot[1][0] ) / s;
+        }
     }
 
     /* Now convert that quaternion to angle/axis */
