@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@ double
 int
 Mat3Eq(const double **matrix1, const double **matrix2, const double precision);
 
+double
+Mat3FrobDiff(const double **matrix1, const double **matrix2);
+
 int
 Mat3FrobEq(const double **matrix1, const double **matrix2, const double precision);
 
@@ -104,4 +107,7 @@ ClosestRotMatIp(double **inmat);
 double
 RotMat2AxisAngle(double **rot, double *v);
 
-#endif /* !MATRIXUTILS_SEEN */ 
+double
+RotMat2AxisAngleQuat(double **rot, double *v);
+
+#endif
