@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
-#include "eigen.h"
+#include "eigen_gsl.h"
 #include "MatUtils.h"
 
 
@@ -58,7 +58,7 @@ MatPrintRec(double **matrix, const int n, const int m)
     printf("\n");
     for (i = 0; i < n; ++i)
     {
-        printf(" [\n");
+        printf(" [");
         for (j = 0; j < m; ++j)
             printf(" % 14.8f", matrix[i][j]);
         printf(" ]\n");
@@ -76,11 +76,11 @@ MatDestroy(double ***matrix_ptr)
 
     if (matrix != NULL)
     {
-		if (matrix[0] != NULL)
-		{
-			free(matrix[0]);
-			matrix[0] = NULL;
-		}
+        if (matrix[0] != NULL)
+        {
+            free(matrix[0]);
+            matrix[0] = NULL;
+        }
 
         free(matrix);
         *matrix_ptr = NULL;
@@ -99,7 +99,7 @@ double
     if (matspace == NULL)
     {
         perror("\n ERROR");
-        printf("\n ERROR: Failure to allocate matrix space in MatAlloc(): (%d x %d)\n", rows, cols);
+        printf("\n ERROR: Failure to allocate matrix in MatAlloc(): (%d x %d)\n", rows, cols);
         exit(EXIT_FAILURE);
     }
 
@@ -108,14 +108,14 @@ double
     if (matrix == NULL)
     {
         perror("\n ERROR");
-        printf("\n ERROR: Failure to allocate room for row pointers in MatAlloc(): (%d)\n", rows);
+        printf("\n ERROR: Failure to allocate row pointers in MatAlloc(): (%d)\n", rows);
         exit(EXIT_FAILURE);
     }
 
     /*  now 'point' the pointers */
     for (i = 0; i < rows; i++)
         matrix[i] = matspace + (i * cols);
-    
+
     return(matrix);
 }
 
@@ -127,11 +127,11 @@ MatIntDestroy(int ***matrix_ptr)
 
     if (matrix != NULL)
     {
-		if (matrix[0] != NULL)
-		{
-			free(matrix[0]);
-			matrix[0] = NULL;
-		}
+        if (matrix[0] != NULL)
+        {
+            free(matrix[0]);
+            matrix[0] = NULL;
+        }
 
         free(matrix);
         *matrix_ptr = NULL;
@@ -150,7 +150,7 @@ int
     if (matspace == NULL)
     {
         perror("\n ERROR");
-        printf("\n ERROR: Failure to allocate room for pointers (%d x %d)\n", rows, cols);
+        printf("\n ERROR: Failure to allocate matrix (%d x %d)\n", rows, cols);
         exit(EXIT_FAILURE);
     }
 
@@ -159,14 +159,14 @@ int
     if (matrix == NULL)
     {
         perror("\n ERROR");
-        printf("\n ERROR: Failure to allocate room for pointers (%d)\n", rows);
+        printf("\n ERROR: Failure to allocate pointers (%d)\n", rows);
         exit(EXIT_FAILURE);
     }
 
     /*  now 'point' the pointers */
     for (i = 0; i < rows; i++)
         matrix[i] = matspace + (i * cols);
-    
+
     return(matrix);
 }
 
@@ -193,7 +193,7 @@ Matrix3D
         matrix3d->matrixd == NULL)
     {
         perror("\n ERROR");
-        puts("\n ERROR: Failure to allocate room for pointers \n\n");
+        puts("\n ERROR: Failure to allocate pointers \n\n");
         exit(EXIT_FAILURE);
     }
 
@@ -270,7 +270,7 @@ MatCpySym(double **matrix2, const double **matrix1, const int dim)
 
 
 void
-MatCpySymgen(double **matrix2, const double **matrix1, const int rows, const int cols)
+MatCpyGen(double **matrix2, const double **matrix1, const int rows, const int cols)
 {
     memcpy(&matrix2[0][0], &matrix1[0][0], rows * cols * sizeof(double));
 }
@@ -343,7 +343,7 @@ MatMultGenIp(double **A, const int nk, const int ni, const double **B, const int
         }
     }
 
-    MatCpySymgen(A, (const double **) tmpmat, ni, nj);
+    MatCpyGen(A, (const double **) tmpmat, ni, nj);
     MatDestroy(&tmpmat);
 }
 
@@ -384,7 +384,7 @@ MatTransMultGenIp(double **A, const int nk, const int ni, const double **B, cons
         }
     }
 
-    MatCpySymgen(A, (const double **) tmpmat, ni, nj);
+    MatCpyGen(A, (const double **) tmpmat, ni, nj);
     MatDestroy(&tmpmat);
 }
 
@@ -451,7 +451,7 @@ MatTransOp(double **outmat, const double **inmat, const int dim)
 }
 
 
-void 
+void
 cholesky(double **mat, const int dim, double *p)
 {
     int             i, j, k;
@@ -500,7 +500,8 @@ MatSymLnDet(const double **mat, const int dim)
     int             i;
     double          lndet;
 
-    eigensym(mat, evals, evecs, dim);
+    //eigensym(mat, evals, evecs, dim);
+    EigenGSL((const double **) mat, dim, evals, evecs, 0);
 
     lndet = 0.0;
     for (i = 0; i < dim; ++i)
@@ -540,7 +541,7 @@ TestZeroOffDiag(const double **mat, const int dim, const double precision)
             if (i !=j && mat[i][j] > precision)
                 return(0);
 
-    return(1);                
+    return(1);
 }
 
 
@@ -557,13 +558,13 @@ TestIdentMat(const double **mat, const int dim, const double precision)
         {
             if (i == j)
             {
-				tmp = 1.0 - mat[i][i];
-				frobnorm += tmp * tmp;
+                tmp = 1.0 - mat[i][i];
+                frobnorm += tmp * tmp;
             }
             else
             {
-				tmp = mat[i][j];
-				frobnorm += tmp * tmp;
+                tmp = mat[i][j];
+                frobnorm += tmp * tmp;
             }
         }
     }
@@ -590,13 +591,13 @@ FrobDiffNormIdentMat(const double **mat, const int dim)
         {
             if (i == j)
             {
-				tmp = 1.0 - mat[i][i];
-				frobnorm += tmp * tmp;
+                tmp = 1.0 - mat[i][i];
+                frobnorm += tmp * tmp;
             }
             else
             {
-				tmp = mat[i][j];
-				frobnorm += tmp * tmp;
+                tmp = mat[i][j];
+                frobnorm += tmp * tmp;
             }
         }
     }
