@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ void
 MatCpySym(double **matrix2, const double **matrix1, const int dim);
 
 void
-MatCpySymgen(double **matrix2, const double **matrix1, const int rows, const int cols);
+MatCpyGen(double **matrix2, const double **matrix1, const int rows, const int cols);
 
 void
 MatMultGenUSVOp(double **c, const double **u, double *s, const double **v,
