@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,247 +53,23 @@ pythag(double a, double b)
     Reuction to tridiagonal of real, symmetric matrix a with dimension 3.
     z = input matrix -- is replace by orthogonal matrix Q of transformation on output
     eigenval = diagonal elements of Q (order 3)
-    
-    This part of the function takes less than 60% of the time of the Numerical Recipes 
+
+    This part of the function takes less than 60% of the time of the Numerical Recipes
     tred2 function for a matrix of order 3.
-    
+
     Tridiagonal QL implicit:
     returns eigenvalues and eigenvectors of a real, symmetric,
     tridiagonal matrix (such as output by tred2)
-    
+
     eigenval = holds diagonal elements of tridiagonal matrix, order n;
                returns eigenvalues
     z = tred2 output matrix z (else identity matrix to get eigenvectors)
-    
+
     z[k] returns normalized eigenvector for eigenvalue eigenval[k]
 */
 
 /* normalize a vector and return a pointer to it */
 /* It changes the value of the vector!!          */
-double
-*NormalizeVec(double *vect)
-{
-    double          len;
-
-    len = 1.0 / sqrt(vect[0]*vect[0] + vect[1]*vect[1] + vect[2]*vect[2]);
-
-    vect[0] *= len;
-    vect[1] *= len;
-    vect[2] *= len;
-
-    return (vect);
-}
-
-
-void
-EigenSort(double **eigenvectors, double *eigenvalues)
-{
-    double          v;
-
-    if (eigenvalues[0] < eigenvalues[1])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[1];
-        eigenvalues[1] = v;
-        SwapEvec(eigenvectors[0], eigenvectors[1], 3);
-    }
-
-    if (eigenvalues[0] < eigenvalues[2])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[2];
-        eigenvalues[2] = v;
-        SwapEvec(eigenvectors[0], eigenvectors[2], 3);
-    }
-
-    if (eigenvalues[1] < eigenvalues[2])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[2];
-        eigenvalues[2] = v;
-        SwapEvec(eigenvectors[1], eigenvectors[2], 3);
-    }
-}
-
-
-void
-EigenSort3(double **eigenvectors, double *eigenvalues, double *tmpevec)
-{
-    double          v;
-
-    if (eigenvalues[0] < eigenvalues[1])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[1];
-        eigenvalues[1] = v;
-        Swap3Evec(eigenvectors[0], eigenvectors[1], tmpevec);
-    }
-
-    if (eigenvalues[0] < eigenvalues[2])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[2];
-        eigenvalues[2] = v;
-        Swap3Evec(eigenvectors[0], eigenvectors[2], tmpevec);
-    }
-
-    if (eigenvalues[1] < eigenvalues[2])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[2];
-        eigenvalues[2] = v;
-        Swap3Evec(eigenvectors[1], eigenvectors[2], tmpevec);
-    }
-}
-
-
-void
-EigenSort3b(double **eigenvectors, double *eigenvalues)
-{
-    double          v, tmpevec[3];
-
-    if (eigenvalues[0] < eigenvalues[1])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[1];
-        eigenvalues[1] = v;
-        Swap3Evec(eigenvectors[0], eigenvectors[1], &tmpevec[0]);
-    }
-
-    if (eigenvalues[0] < eigenvalues[2])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[2];
-        eigenvalues[2] = v;
-        Swap3Evec(eigenvectors[0], eigenvectors[2], &tmpevec[0]);
-    }
-
-    if (eigenvalues[1] < eigenvalues[2])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[2];
-        eigenvalues[2] = v;
-        Swap3Evec(eigenvectors[1], eigenvectors[2], &tmpevec[0]);
-    }
-}
-
-
-void
-EigenSort4(double **eigenvectors, double *eigenvalues)
-{
-    double          v;
-
-    if (eigenvalues[0] < eigenvalues[1])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[1];
-        eigenvalues[1] = v;
-        SwapEvec(eigenvectors[0], eigenvectors[1], 4);
-    }
-    if (eigenvalues[0] < eigenvalues[2])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[2];
-        eigenvalues[2] = v;
-        SwapEvec(eigenvectors[0], eigenvectors[2], 4);
-    }
-    if (eigenvalues[0] < eigenvalues[3])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[3];
-        eigenvalues[3] = v;
-        SwapEvec(eigenvectors[0], eigenvectors[3], 4);
-    }
-    if (eigenvalues[1] < eigenvalues[2])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[2];
-        eigenvalues[2] = v;
-        SwapEvec(eigenvectors[1], eigenvectors[2], 4);
-    }
-    if (eigenvalues[1] < eigenvalues[3])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[3];
-        eigenvalues[3] = v;
-        SwapEvec(eigenvectors[1], eigenvectors[3], 4);
-    }
-    if (eigenvalues[2] < eigenvalues[3])
-    {
-        v = eigenvalues[2];
-        eigenvalues[2] = eigenvalues[3];
-        eigenvalues[3] = v;
-        SwapEvec(eigenvectors[2], eigenvectors[3], 4);
-    }
-}
-
-
-void
-EvalSort4(double *eigenvalues)
-{
-    double          v;
-
-    if (eigenvalues[0] < eigenvalues[1])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[1];
-        eigenvalues[1] = v;
-    }
-    if (eigenvalues[0] < eigenvalues[2])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[2];
-        eigenvalues[2] = v;
-    }
-    if (eigenvalues[0] < eigenvalues[3])
-    {
-        v = eigenvalues[0];
-        eigenvalues[0] = eigenvalues[3];
-        eigenvalues[3] = v;
-    }
-    if (eigenvalues[1] < eigenvalues[2])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[2];
-        eigenvalues[2] = v;
-    }
-    if (eigenvalues[1] < eigenvalues[3])
-    {
-        v = eigenvalues[1];
-        eigenvalues[1] = eigenvalues[3];
-        eigenvalues[3] = v;
-    }
-    if (eigenvalues[2] < eigenvalues[3])
-    {
-        v = eigenvalues[2];
-        eigenvalues[2] = eigenvalues[3];
-        eigenvalues[3] = v;
-    }
-}
-
-
-void
-SwapEvec(double *evec1, double *evec2, int length)
-{
-    double         *tmpevec = (double *) malloc(length * sizeof(double));
-
-    memcpy(tmpevec, evec1, length * sizeof(double));
-    memcpy(evec1,   evec2, length * sizeof(double));
-    memcpy(evec2, tmpevec, length * sizeof(double));
-
-    free(tmpevec);
-}
-
-
-void
-Swap3Evec(double *evec1, double *evec2, double *tmpevec)
-{
-    memcpy(tmpevec, evec1, 3 * sizeof(double));
-    memcpy(evec1,   evec2, 3 * sizeof(double));
-    memcpy(evec2, tmpevec, 3 * sizeof(double));
-}
-
-
 void
 eigen3(double **z, double *eigenval)
 {
@@ -389,7 +165,7 @@ eigen3(double **z, double *eigenval)
 
         if (iter++ == 300)
         {
-            fprintf(stderr, 
+            fprintf(stderr,
                     "\n ERROR: Too many iterations in tqli eigen3() in eigen3.c \n");
             exit(EXIT_FAILURE);
         }
@@ -483,7 +259,7 @@ eigen3(double **z, double *eigenval)
 
         if (iter++ == 300)
         {
-            fprintf(stderr, 
+            fprintf(stderr,
                     "\n ERROR: Too many iterations in tqli eigen3() in eigen3.c \n");
             exit(EXIT_FAILURE);
         }
@@ -544,47 +320,20 @@ eigen3(double **z, double *eigenval)
     z = input matrix -- is replace by orthogonal matrix Q
     of transformation on output
     eigenval = diagonal elements of Q (order 4)
-    
+
     Tridiagonal QL implicit = tqli():
     returns eigenvalues and eigenvectors of a real, symmetric,
     tridiagonal matrix (such as output by tred2)
-    
+
     eigenval = holds diagonal elements of tridiagonal matrix, order n;
                returns eigenvalues
     z = tred2() output matrix z (else identity matrix to get eigenvectors)
-    
+
     z[k] or *evals returns normalized eigenvector for eigenvalue eigenval[k]
-    
+
     eigen4() uses only lower left half of matrix, whereas jacobi4() needs
     upper right (at least)
 */
-void
-Eigen4Min(double **eigenvector, double *eigenvalue)
-{
-    double           smallestval;
-    double          *smallestvec;
-    int             i, index = 0;
-
-    smallestval = eigenvalue[0];
-    smallestvec = eigenvector[0];
-
-    for (i = 1; i < 4; ++i)
-    {
-        if (eigenvalue[i] < smallestval)
-        {
-            smallestval = eigenvalue[i];
-            smallestvec = eigenvector[i];
-            index = i;
-        }
-    }
-
-    eigenvalue[index] = eigenvalue[3];
-    eigenvector[index] = eigenvector[3];
-    eigenvalue[3] = smallestval;
-    eigenvector[3] = smallestvec;
-}
-
-
 void
 eigen4(double **Q, double *evals)
 {
@@ -621,7 +370,7 @@ tred24(double **a, double *d, double *e)
         {
             for (k = 0; k < l + 1; k++)
                 scale += fabs(a[i][k]);
-    
+
             if (scale == 0.0)
                 e[i] = a[i][l];
             else
@@ -631,13 +380,13 @@ tred24(double **a, double *d, double *e)
                     a[i][k] /= scale;
                     h += a[i][k] * a[i][k];
                 }
-    
+
                 f = a[i][l];
                 g = (f >= 0.0 ? -sqrt(h) : sqrt(h));
                 e[i] = scale * g;
                 h -= f * g;
                 a[i][l] = f - g;
-        
+
                 f = 0.0;
                 for (j = 0; j < l + 1; j++)
                 {
@@ -715,7 +464,7 @@ tred24vals(double **a, double *d, double *e)
         {
             for (k = 0; k < l + 1; k++)
                 scale += fabs(a[i][k]);
-    
+
             if (scale == 0.0)
                 e[i] = a[i][l];
             else
@@ -725,13 +474,13 @@ tred24vals(double **a, double *d, double *e)
                     a[i][k] /= scale;
                     h += a[i][k] * a[i][k];
                 }
-    
+
                 f = a[i][l];
                 g = (f >= 0.0 ? -sqrt(h) : sqrt(h));
                 e[i] = scale * g;
                 h -= f * g;
                 a[i][l] = f - g;
-        
+
                 f = 0.0;
                 for (j = 0; j < l + 1; j++)
                 {
@@ -977,7 +726,7 @@ jacobi4(double **a, double *d, double **v)
                     {
                         t = (a[j][k]) / h;
                     }
-                    else 
+                    else
                     {
                         theta = 0.5 * h / (a[j][k]);
                         t = 1.0 / (fabs(theta) + sqrt(1.0 + theta * theta));
@@ -1068,7 +817,7 @@ SymSchur2(double **a, const int j, const int k,
    than the cyclic Jacobi.
    On output, elements of a above the diagonal are destroyed
    (i.e. The matrix a gets trashed.  If you need to keep the
-   values of a, call jacobi with a copy of a). 
+   values of a, call jacobi with a copy of a).
    d[3] returns the eigenvalues of a.
    v[3][3] is a matrix whose rows contain,
    on output, the normalized eigenvectors of a.
@@ -1174,7 +923,7 @@ jacobi3(double **a, double *d, double **v, double tol)
    as the cyclic Jacobi.
    On output, elements of a above the diagonal are destroyed
    (i.e. The matrix a gets trashed.  If you need to keep the
-   values of a, call jacobi with a copy of a). 
+   values of a, call jacobi with a copy of a).
    d[3] returns the eigenvalues of a.
    v[3][3] is a matrix whose rows contain,
    on output, the normalized eigenvectors of a.
@@ -1303,8 +1052,6 @@ InvSymEigenOp(double **invmat, const double **mat, int n,
 
     memcpy(tmpmat[0], mat[0], n * n * sizeof(double));
 
-    //DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
-
     EigenGSLDest(tmpmat, n, evals, evecs, 0);
 
     cond = evals[n-1] / evals[0];
@@ -1334,234 +1081,8 @@ InvSymEigenOp(double **invmat, const double **mat, int n,
 }
 
 
-/* Entire decomposition, evals and evecs */
-/* eigensym evals are small to large */
-/* Symmetric matrix decomposition, using LAPACK dsyev
-   Obviously it doesn't matter if you pass the matrix or its transpose;
-   however, LAPACK matrix ordering is FORTRAN-style, not C, so the
-   eigenvectors need to be transposed. */
-void
-eigensym(const double **mat, double *evals, double **evecs, int n)
-{
-    EigenGSL((double **) mat, n, evals, evecs, 0);
-}
 
-
-/* Entire decomposition, evals and evecs */
-/* eigensym evals are small to large */
-/* exactly the same as eigensym above, but work space is passed */
-/* void */
-/* eigensym2(const double **mat, double *evals, double **evecs, int n, double *work) */
-/* { */
-/*     int                 info = 0; */
-/*     char                     jobz_v = 'V', uplo_u = 'U'; */
-/*     int                 lwork = n * n; */
-/*     double                   tmp; */
-/*     int                      i, j; */
-/*  */
-/*     memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double)); */
-/*     DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info); */
-/*  */
-/*     for (i = 0; i < n; ++i) */
-/*     { */
-/*         for (j = 0; j < i; ++j) */
-/*         { */
-/*             tmp = evecs[i][j]; */
-/*             evecs[i][j] = evecs[j][i]; */
-/*             evecs[j][i] = tmp; */
-/*         } */
-/*     } */
-/* } */
-
-
-void
-eigenvalsym(const double **mat, double *evals, double **evecs, int n)
-{
-    EigenvalsGSL((double **) mat, n, evals);
-}
-
-
-/* void */
-/* eigenvalsym2(const double **mat, double *evals, double **evecs, int n, double *work) */
-/* { */
-/*     int                 info = 0; */
-/*     char                     jobz_v = 'N', uplo_u = 'U'; */
-/*     int                 lwork = n * n; */
-/*  */
-/*     memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double)); */
-/*     DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info); */
-/* } */
-
-
-#define CUTOFF 15
-
-#define GT(x, y) ((x) > (y))
-#define LT(x, y) ((x) < (y))
-#define GE(x, y) ((x) >= (y))
-#define LE(x, y) ((x) <= (y))
-#define EQ(x, y) ((x) == (y))
-#define NE(x, y) ((x) != (y))
- 
-double              tempd;
-
-#define SWAPD(x, y) tempd = (x); (x) = (y); (y) = tempd
-
-
-static void
-myswapd(double *x, double *y)
-{
-    double         tempd;
-
-    tempd = *x;
-    *x = *y;
-    *y = tempd;
-}
-
-
-static void
-myswapdd(double **x, double **y)
-{
-    double        *tempd;
-
-    tempd = *x;
-    *x = *y;
-    *y = tempd;
-}
-
-
-static void
-partial_eigen_quicksort(double *array1, double **array2, int lower, int upper)
-{
-    int             i, j, random_index;
-    double          pivot;
-
-    if (upper - lower > CUTOFF)
-    {
-        myswapd(&array1[lower], &array1[(upper+lower)/2]);
-        myswapdd(&array2[lower], &array2[(upper+lower)/2]);
-        i = lower;
-        j = upper + 1;
-
-        /* pivot = array1[lower]; */
-        srand(time(NULL));
-        random_index = (int) ( (double)(upper - lower) * (double) rand() / (double) RAND_MAX ) + lower;
-        pivot = array1[random_index];
-
-        while (1)
-        {
-            do
-            {
-                ++i;
-            }
-            while (LT(array1[i], pivot));
-
-            do
-            {
-                --j;
-            }
-            while (GT(array1[j], pivot));
-
-            if (j > i)
-            {
-                myswapd(&array1[i], &array1[j]);
-                myswapdd(&array2[i], &array2[j]);
-            }
-            else
-            {
-                break;
-            }
-        }
-
-        myswapd(&array1[lower], &array1[j]);
-        myswapdd(&array2[lower], &array2[j]);
-
-        partial_eigen_quicksort(array1, array2, lower, j - 1);
-        partial_eigen_quicksort(array1, array2, i,     upper);
-    }
-}
-
-
-static void
-eigen_insort(double *array1, double **array2, int len)
-{
-    int             i, j;
-    double          temp1;
-    double         *temp2;
-
-    for (i = 1; i < len; ++i)
-    {
-        j = i;
-        temp1 = array1[j];
-        temp2 = array2[j];
-
-        while ((j > 0) && GT(array1[j-1], temp1))
-        {
-            array1[j] = array1[j-1];
-            array2[j] = array2[j-1];
-            --j;
-        }
-
-        array1[j] = temp1;
-        array2[j] = temp2;
-    }
-}
-
-
-void
-transevecs(double **mat, int len)
-{
-    int            i, j;
-    double         tmp;
-
-    for (i = 0; i < len; ++i)
-    {
-        for (j = 0; j < i; ++j)
-        {
-            tmp = mat[i][j];
-            mat[i][j] = mat[j][i];
-            mat[j][i] = tmp;
-        }
-    }
-}
-
-
-void
-eigen_quicksort(double *evals, double **evecs, int len)
-{
-    double         *tmpvals;
-
-    tmpvals = malloc((len+1) * sizeof(double));
-    memcpy(tmpvals, evals, len * sizeof(double));
-    tmpvals[len] = DBL_MAX;
-    partial_eigen_quicksort(tmpvals, evecs, 0, len - 1);
-    eigen_insort(tmpvals, evecs, len);
-    memcpy(evals, tmpvals, len * sizeof(double));
-
-    free(tmpvals);
-}
-
-
-/* Calculates A = LDL^t, where L is a matrix of right eigenvectors and D is 
-   a diagonal matrix of eigenvalues, in one fell swoop. Except here the
-   eigenvalues are delivered as a 1 x n vector. */
-/* void */
-/* EigenReconSym(double **mat, const double **evecs, const double *evals, const int n) */
-/* { */
-/*     int             i, j, k; */
-/*  */
-/*     for (i = 0; i < n; ++i) */
-/*     { */
-/*         for (j = 0; j < n; ++j) */
-/*         { */
-/*             mat[i][j] = 0.0; */
-/*             for (k = 0; k < n; ++k) */
-/*                 mat[i][j] += (evecs[k][i] * evals[k] * evecs[k][j]); */
-/*         } */
-/*     } */
-/* } */
-
-
-/* Calculates A = LDL^t, where L is a matrix of right eigenvectors and D is 
+/* Calculates A = LDL^t, where L is a matrix of right eigenvectors and D is
    a diagonal matrix of eigenvalues, in one fell swoop. Except here the
    eigenvalues are delivered as a 1 x n vector. */
 /* This function is consistent with eigensym() above - 2006-05-10 */
