@@ -26,24 +26,30 @@
 #define EIGEN_GSL_SEEN
 
 void
-EigenvalsGSL(double **mat, const int dim, double *eval);
+EigenvalsGSL(const double **mat, const int dim, double *eval);
 
 void
 EigenvalsGSLDest(double **mat, const int dim, double *eval);
 
 void
-EigenGSL(double **mat, const int dim, double *eval, double **evec, int order);
+EigenGSL(const double **mat, const int dim, double *eval, double **evec, int order);
 
 void
 EigenGSLDest(double **mat, const int dim, double *eval, double **evec, int order);
 
+void
+CalcGSLSVD3(double **a, double **u, double *s, double **vt);
+
 void
 svdGSLDest(double **A, const int dim, double *singval, double **V);
 
+void
+svdGSLJacobiDest(double **A, const int dim, double *singval, double **V);
+
 void
 CholeskyGSLDest(double **A, const int dim);
 
 void
-PseudoinvSymGSL(double **inmat, double **outmat, int n, double tol);
+PseudoinvSymGSL(const double **inmat, double **outmat, int n, double tol);
 
 #endif
