@@ -3,7 +3,7 @@
 *                                                                      *
 *  dssplite v.0.8                                                      *
 *                                                                      *
-*  Copyright (C) 2003-2009  Douglas L. Theobald                        *
+*  Copyright (C) 2003-2014  Douglas L. Theobald                        *
 *                                                                      *
 *  dssplite is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published   *
@@ -167,7 +167,7 @@ char
           int vlen) /* used to be that len = # of CA atoms, not full x vector length */
 {
     DSSP           *dssp = NULL;
-    int             Hbonds, len;
+    int             len;
     char           *summary;
 
     /* Setup DSSP structure */
@@ -184,7 +184,7 @@ char
 
     /* do the DSSP algorithm, Doug-style */
     GetCONHCA(dssp);
-    Hbonds = FlagHBonds(dssp);
+    FlagHBonds(dssp);
 
     FlagBends(dssp);
     FlagTurns(dssp);
