@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -125,6 +125,18 @@ AlgorithmDestroy(Algorithm *algo)
         free(algo->argv);
     }
 
+    if (algo->selection != NULL)
+    {
+        free(algo->selection);
+        algo->selection = NULL;
+    }
+
+    if (algo->atomslxn != NULL)
+    {
+        free(algo->atomslxn);
+        algo->atomslxn = NULL;
+    }
+
     free(algo);
 }
 
@@ -146,17 +158,13 @@ Algorithm
     mystrcpy(algo->rootname, "theseus");
     algo->weight       = 0;
     algo->verbose      = 0; /* verbose behavior = 1 */
-    algo->method       = 3; /* 7: LAPACK SVD, 10: my classic Jacobi SVD */
-    algo->print_trans  = 0;
     algo->write_file   = 1;
-    algo->print_weight = 0;
     algo->precision    = 1e-7;
-    algo->iterations   = 200;
+    algo->iterations   = 400;
     algo->selection    = NULL;
     algo->atomslxn     = NULL;
     algo->revsel       = 0;
     algo->atoms        = 0;
-    algo->reflection   = 0;
     algo->embedave     = 0; /* 2 = biased ML embedded structure */
     algo->landmarks    = 0;
     algo->writestats   = 1;
@@ -172,24 +180,22 @@ Algorithm
     algo->princaxes    = 1;
     algo->nullrun      = 0;
     algo->binary       = 0;
-    algo->modelpca     = 0;
-    algo->raxes[0] =
-    algo->raxes[1] = 
-    algo->raxes[2] =   1.0;
     algo->mbias        = 0;
-    algo->notrans      = 0;
-    algo->norot        = 0;
+    algo->doave        = 1;
+    algo->domp         = 1;
+    algo->dotrans      = 1;
+    algo->dorot        = 1;
+    algo->dohierarch   = 1;
+    algo->docovars     = 1;
     algo->alignment    = 0;
     algo->fmodel       = 0;
     algo->covweight    = 0;
     algo->varweight    = 1;
-    algo->hierarch     = 1;
+    algo->hierarch     = 5;
     algo->leastsquares = 0;
     algo->filenum      = 0;
     algo->infiles      = NULL;
-    algo->noave        = 0;
     algo->noinnerloop  = 0;
-    algo->htrans       = 0;
     algo->rounds       = 0;
     algo->innerrounds  = 0;
     algo->fasta        = 0;
@@ -204,10 +210,8 @@ Algorithm
     algo->param[0] = algo->param[1] = 1.0;
     algo->radii[0] = algo->radii[1] = algo->radii[2] = 50.0;
     algo->ssm          = 0;
-    algo->lele5        = 0;
     algo->bayes        = 0;
     algo->ipmat        = 0;
-    algo->commandeur   = 0;
     algo->missing      = 0;
     algo->scale        = 0;
     algo->instfile     = 0;
@@ -216,6 +220,10 @@ Algorithm
     algo->amber        = 0;
     algo->atom_names   = 0;
     algo->scalefactor  = 1.0;
+    algo->morphfile    = 0;
+    algo->scaleanchor  = 0;
+    algo->randgibbs    = 0;
+    algo->covnu        = 1;
 
     return(algo);
 }
@@ -273,17 +281,17 @@ CdsArray
 
     cdsA->cds = NULL;
     cdsA->avecds = NULL;
+    cdsA->ac = NULL;
     cdsA->tcds = NULL;
-    cdsA->jkcds = NULL;
+    cdsA->tc = NULL;
 
     cdsA->w = NULL;
     cdsA->var = NULL;
+    cdsA->evals = NULL;
+    cdsA->samplevar3N = NULL;
     cdsA->df = NULL;
     cdsA->S2 = NULL;
 
-    cdsA->algo = AlgorithmInit();
-    cdsA->stats = StatsInit();
-
     cdsA->residuals = NULL;
 
     cdsA->Var_matrix = NULL;
@@ -292,28 +300,21 @@ CdsArray
     cdsA->CovMat = NULL;
     cdsA->WtMat = NULL;
     cdsA->FullCovMat = NULL;
-    cdsA->MVCovMat = NULL;
-    cdsA->SCovMat = NULL;
 
     cdsA->pcamat = NULL;
     cdsA->pcavals = NULL;
-    cdsA->modpcamat = NULL;
-    cdsA->modpcavals = NULL;
 
-    cdsA->tmpmat1 = NULL;
-    cdsA->tmpmat2 = NULL;
     cdsA->tmpmatKK1 = NULL;
     cdsA->tmpmatKK2 = NULL;
     cdsA->tmpvecK = NULL;
-    cdsA->tmpmat3K = NULL;
-    cdsA->tmpmatK3a = NULL;
-    cdsA->tmpmatK3b = NULL;
 
     cdsA->tmpmat3a = MatAlloc(3, 3);
     cdsA->tmpmat3b = MatAlloc(3, 3);
     cdsA->tmpmat3c = MatAlloc(3, 3);
     cdsA->tmpmat3d = MatAlloc(3, 3);
 
+    cdsA->tmpvec3a = malloc(3 * sizeof(double));
+
     return(cdsA);
 }
 
@@ -350,12 +351,14 @@ CdsArrayAllocLen(CdsArray *cdsA, const int vlen)
 
     cdsA->avecds = CdsInit();
     CdsAlloc(cdsA->avecds, vlen);
+    cdsA->ac = MatAlloc(3, vlen);
     cdsA->tcds = CdsInit();
+    cdsA->tc = MatAlloc(3, vlen);
     CdsAlloc(cdsA->tcds, vlen);
-    cdsA->jkcds = CdsInit();
-    CdsAlloc(cdsA->jkcds, vlen);
 
     cdsA->var = (double *) calloc(vlen, sizeof(double));
+    cdsA->evals = (double *) calloc(vlen, sizeof(double));
+    cdsA->samplevar3N = (double *) calloc(vlen, sizeof(double));
     cdsA->w   = (double *) calloc(vlen, sizeof(double));
     cdsA->df  = (int *) calloc(vlen, sizeof(int));
 }
@@ -373,6 +376,8 @@ void
 CdsArraySetup(CdsArray *cdsA)
 {
     memsetd(cdsA->var, 1.0, cdsA->vlen);
+    memsetd(cdsA->evals, 1.0, cdsA->vlen);
+    memsetd(cdsA->samplevar3N, 1.0, cdsA->vlen);
     memsetd(cdsA->w, 1.0, cdsA->vlen);
 }
 
@@ -399,29 +404,16 @@ CdsArrayDestroy(CdsArray **cdsA_ptr)
 
     CdsDestroy(&(cdsA->avecds));
     CdsDestroy(&(cdsA->tcds));
-    CdsDestroy(&(cdsA->jkcds));
 
-    free(cdsA->stats);
-    cdsA->stats = NULL;
-
-    if (cdsA->algo->selection != NULL)
-    {
-        free(cdsA->algo->selection);
-        cdsA->algo->selection = NULL;
-    }
-
-    if (cdsA->algo->atomslxn != NULL)
-    {
-        free(cdsA->algo->atomslxn);
-        cdsA->algo->atomslxn = NULL;
-    }
-
-    AlgorithmDestroy(cdsA->algo);
+    MatDestroy(&(cdsA->ac));
+    MatDestroy(&(cdsA->tc));
 
     DistMatsDestroy(cdsA);
     CovMatsDestroy(cdsA);
     PCADestroy(cdsA);
 
+    free(cdsA->tmpvec3a);
+
     if (cdsA->residuals != NULL)
     {
         free(cdsA->residuals);
@@ -432,6 +424,10 @@ CdsArrayDestroy(CdsArray **cdsA_ptr)
     cdsA->w = NULL;
     free(cdsA->var);
     cdsA->var = NULL;
+    free(cdsA->evals);
+    cdsA->evals = NULL;
+    free(cdsA->samplevar3N);
+    cdsA->samplevar3N = NULL;
     free(cdsA->df);
     cdsA->df = NULL;
 
@@ -482,10 +478,6 @@ CovMatsDestroy(CdsArray *cdsA)
         MatDestroy(&(cdsA->tmpmatKK2));
     if (cdsA->tmpvecK != NULL)
         free(cdsA->tmpvecK);
-    if (cdsA->tmpmat1 != NULL)
-        MatDestroy(&(cdsA->tmpmat1));
-    if (cdsA->tmpmat2 != NULL)
-        MatDestroy(&(cdsA->tmpmat2));
     if (cdsA->tmpmat3a != NULL)
         MatDestroy(&(cdsA->tmpmat3a));
     if (cdsA->tmpmat3b != NULL)
@@ -494,16 +486,6 @@ CovMatsDestroy(CdsArray *cdsA)
         MatDestroy(&(cdsA->tmpmat3c));
     if (cdsA->tmpmat3d != NULL)
         MatDestroy(&(cdsA->tmpmat3d));
-    if (cdsA->MVCovMat != NULL)
-        MatDestroy(&(cdsA->MVCovMat));
-    if (cdsA->SCovMat != NULL)
-        MatDestroy(&(cdsA->SCovMat));
-    if (cdsA->tmpmatK3a != NULL)
-        MatDestroy(&(cdsA->tmpmatK3a));
-    if (cdsA->tmpmatK3b != NULL)
-        MatDestroy(&(cdsA->tmpmatK3b));
-    if (cdsA->tmpmat3K != NULL)
-        MatDestroy(&(cdsA->tmpmat3K));
 }
 
 
@@ -531,7 +513,7 @@ PCADestroy(CdsArray *cdsA)
 Cds
 *CdsInit(void)
 {
-    int             i, j;
+    int             i;
     Cds         *cds = NULL;
 
     cds = (Cds *) malloc(sizeof(Cds));
@@ -542,37 +524,43 @@ Cds
     cds->resName_space = NULL;
     cds->chainID    = NULL;
     cds->resSeq     = NULL;
+    cds->wc         = NULL;
     cds->x          = NULL;
     cds->y          = NULL;
     cds->z          = NULL;
     cds->o          = NULL;
     cds->b          = NULL;
-    cds->residual_x = NULL;
-    cds->residual_y = NULL;
-    cds->residual_z = NULL;
+    cds->nu         = NULL;
+    cds->mu         = NULL;
+    cds->sc         = NULL;
+    cds->sx         = NULL;
+    cds->sy         = NULL;
+    cds->sz         = NULL;
+    cds->so         = NULL;
+    cds->sb         = NULL;
+    cds->cc         = NULL;
     cds->covx       = NULL;
     cds->covy       = NULL;
     cds->covz       = NULL;
 
-    cds->innerprod = NULL;
-    cds->vlen = 0;
-    cds->innerprod2 = NULL;
+    cds->residual_x = NULL;
+    cds->residual_y = NULL;
+    cds->residual_z = NULL;
 
+    cds->outerprod = NULL;
+
+    cds->vlen = 0;
+    cds->innerprod = MatAlloc(3, 3);
     cds->matrix = MatAlloc(3, 3);
     cds->last_matrix = MatAlloc(3, 3);
+    cds->last_outer_matrix = MatAlloc(3, 3);
     cds->evecs = MatAlloc(4,4);
 
     for (i = 0; i < 4; ++i)
         cds->evecs[i][0] = 1.0;
 
     for (i = 0; i < 3; ++i)
-        for (j = 0; j < 3; ++j)
-            cds->matrix[i][j] = cds->last_matrix[i][j] = 0.0;
-
-    cds->tmpmat3a = MatAlloc(3, 3);
-    cds->tmpmat3b = MatAlloc(3, 3);
-    cds->tmpmat3c = MatAlloc(3, 3);
-    cds->tmpmat3d = MatAlloc(3, 3);
+        cds->matrix[i][i] = cds->last_matrix[i][i] = cds->last_outer_matrix[i][i] = 1.0;
 
     cds->bfact_c = 1.0;
     cds->scale = 1.0;
@@ -588,39 +576,44 @@ CdsAlloc(Cds *cds, const int vlen)
 
     cds->vlen = vlen;
 
-    cds->resName    = (char **)  calloc(vlen, sizeof(char *));
-    cds->resName_space = (char *)  calloc(4 * vlen, sizeof(char));
-    cds->chainID    = (char *)   calloc(vlen, sizeof(char));
-    cds->resSeq     = (int *)    calloc(vlen, sizeof(int));
-    cds->x          = (double *) calloc(vlen, sizeof(double));
-    cds->y          = (double *) calloc(vlen, sizeof(double));
-    cds->z          = (double *) calloc(vlen, sizeof(double));
-    cds->o          = (double *) calloc(vlen, sizeof(double));
-    cds->b          = (double *) calloc(vlen, sizeof(double));
-    cds->prvar      = (double *) calloc(vlen, sizeof(double));
-    cds->residual_x = (double *) calloc(vlen, sizeof(double));
-    cds->residual_y = (double *) calloc(vlen, sizeof(double));
-    cds->residual_z = (double *) calloc(vlen, sizeof(double));
-    cds->covx       = (double *) calloc(vlen, sizeof(double));
-    cds->covy       = (double *) calloc(vlen, sizeof(double));
-    cds->covz       = (double *) calloc(vlen, sizeof(double));
+    cds->resName       = (char **)  calloc(vlen, sizeof(char *));
+    cds->resName_space = (char *)   calloc(4 * vlen, sizeof(char));
+    cds->chainID       = (char *)   calloc(vlen, sizeof(char));
+    cds->resSeq        = (int *)    calloc(vlen, sizeof(int));
+    cds->wc            = MatAlloc(5, vlen);
+    cds->x             = cds->wc[0];
+    cds->y             = cds->wc[1];
+    cds->z             = cds->wc[2];
+    cds->o             = cds->wc[3];
+    cds->b             = cds->wc[4];
+    cds->nu            = (int *) calloc(vlen, sizeof(int));
+    cds->mu            = (int *) calloc(vlen, sizeof(int));
+    cds->sc            = MatAlloc(5, vlen);
+    cds->sx            = cds->sc[0];
+    cds->sy            = cds->sc[1];
+    cds->sz            = cds->sc[2];
+    cds->so            = cds->sc[3];
+    cds->sb            = cds->sc[4];
+    cds->cc            = MatAlloc(3, vlen);// DLT could be moved to CovMatAlloc
+    cds->covx          = cds->cc[0];
+    cds->covy          = cds->cc[1];
+    cds->covz          = cds->cc[2];
+    cds->prvar         = (double *) calloc(vlen, sizeof(double));
+    cds->residual_x    = (double *) calloc(vlen, sizeof(double));
+    cds->residual_y    = (double *) calloc(vlen, sizeof(double));
+    cds->residual_z    = (double *) calloc(vlen, sizeof(double));
 
     if (   cds->resName       == NULL
         || cds->resName_space == NULL
         || cds->chainID       == NULL
         || cds->resSeq        == NULL
-        || cds->x             == NULL
-        || cds->y             == NULL
-        || cds->z             == NULL
-        || cds->o             == NULL
-        || cds->b             == NULL
+        || cds->wc            == NULL
+        || cds->sc            == NULL
+        || cds->cc            == NULL
         || cds->prvar         == NULL
         || cds->residual_x    == NULL
         || cds->residual_y    == NULL
-        || cds->residual_z    == NULL
-        || cds->covx          == NULL
-        || cds->covy          == NULL
-        || cds->covz          == NULL)
+        || cds->residual_z    == NULL)
     {
         perror("\n  ERROR");
         fprintf(stderr, "\n  ERROR5: could not allocate memory in function CdsAlloc(). \n");
@@ -641,14 +634,12 @@ CdsSetup(Cds *cds)
     int             i;
 
     memsetd(cds->translation, 0.0, 3);
-    memsetd(cds->jktranslation, 0.0, 3);
-    memsetd(cds->transsum, 0.0, 3);
 
     for (i = 0; i < 4; ++i)
         cds->evecs[i][0] = 1.0;
 
     for (i = 0; i < 3; ++i)
-        cds->matrix[i][i] = cds->last_matrix[i][i] = 1.0;
+        cds->matrix[i][i] = cds->last_matrix[i][i] = cds->last_outer_matrix[i][i] = 1.0;
 }
 
 
@@ -661,34 +652,25 @@ CdsDestroy(Cds **cds_ptr)
     free(cds->resName_space);
     free(cds->chainID);
     free(cds->resName);
-    free(cds->x);
-    free(cds->y);
-    free(cds->z);
-    free(cds->o);
-    free(cds->b);
+    MatDestroy(&(cds->wc));
+    MatDestroy(&(cds->sc));
+    MatDestroy(&(cds->cc));
+    free(cds->nu);
+    free(cds->mu);
     free(cds->prvar);
     free(cds->residual_x);
     free(cds->residual_y);
     free(cds->residual_z);
-    free(cds->covx);
-    free(cds->covy);
-    free(cds->covz);
     MatDestroy(&(cds->matrix));
     MatDestroy(&(cds->last_matrix));
+    MatDestroy(&(cds->last_outer_matrix));
+    MatDestroy(&(cds->innerprod));
 
-    if (cds->innerprod != NULL)
-        MatDestroy(&(cds->innerprod));
-
-    if (cds->innerprod2 != NULL)
-        MatDestroy(&(cds->innerprod2));
+    if (cds->outerprod != NULL)
+        MatDestroy(&(cds->outerprod));
 
     MatDestroy(&(cds->evecs));
 
-    MatDestroy(&(cds->tmpmat3a));
-    MatDestroy(&(cds->tmpmat3b));
-    MatDestroy(&(cds->tmpmat3c));
-    MatDestroy(&(cds->tmpmat3d));
-
     free(cds);
     *cds_ptr = NULL;
 }
@@ -697,7 +679,7 @@ CdsDestroy(Cds **cds_ptr)
 PDBCdsArray
 *PDBCdsArrayInit(void)
 {
-    PDBCdsArray *pdbA = NULL; 
+    PDBCdsArray *pdbA = NULL;
 
     pdbA = (PDBCdsArray *) malloc(sizeof(PDBCdsArray));
     if (pdbA == NULL)
@@ -805,6 +787,7 @@ PDBCds
 
     pdbcds = (PDBCds *) malloc(sizeof(PDBCds));
     pdbcds->vlen = 0; /* so that we know later if this has been allocated or not */
+    pdbcds->scale = 1.0;
     pdbcds->translation = calloc(3, sizeof(double));
     pdbcds->matrix = MatAlloc(3, 3);
     memset(&pdbcds->matrix[0][0], 0, 9 * sizeof(double));
@@ -840,6 +823,8 @@ PDBCdsAlloc(PDBCds *pdbcds, const int vlen)
     pdbcds->element    = (char **)  calloc(vlen, sizeof(char *));
     pdbcds->charge     = (char **)  calloc(vlen, sizeof(char *));
 
+    pdbcds->nu         = (int *)    calloc(vlen, sizeof(int));
+
     /* allocate space for the fields in total */
     pdbcds->record_space  = (char *)  calloc(8 * vlen, sizeof(char));
     pdbcds->name_space    = (char *)  calloc(4 * vlen, sizeof(char));
@@ -866,6 +851,7 @@ PDBCdsAlloc(PDBCds *pdbcds, const int vlen)
         || pdbcds->segID         == NULL
         || pdbcds->element       == NULL
         || pdbcds->charge        == NULL
+        || pdbcds->nu            == NULL
         || pdbcds->record_space  == NULL
         || pdbcds->name_space    == NULL
         || pdbcds->resName_space == NULL
@@ -926,6 +912,8 @@ PDBCdsDestroy(PDBCds **pdbcds_ptr)
     free(pdbcds->element);
     free(pdbcds->charge);
 
+    free(pdbcds->nu);
+
     free(pdbcds);
     *pdbcds_ptr = NULL;
 }
