@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@
 #include "distfit.h"
 #include "DLTmath.h"
 #include "pdbStats.h"
+#include "myassert.h"
+#include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_math.h>
 
-extern int
-MultiPose(CdsArray *baseA); /* theseus.c */
