@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2013 Douglas L. Theobald
+    Copyright (C) 2004-2014 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,18 +36,9 @@ CdsCopyXYZ(Cds *cds1, const Cds *cds2);
 void
 CdsCopyAll(Cds *cds1, const Cds *cds2);
 
-void
-CdsDelete(CdsArray *cdsA, int omit);
-
 void
 CdsArrayCopy(CdsArray *cdsA1, const CdsArray *cdsA2);
 
-void
-AlgorithmCopy(Algorithm *algo1, const Algorithm *algo2);
-
-void
-StatisticsCopy(Statistics *stats1, const Statistics *stats2);
-
 void
 CdsCopy(Cds *cds1, const Cds *cds2);
 
@@ -55,10 +46,10 @@ void
 PDBCdsCopyAll(PDBCds *cds1, const PDBCds *cds2);
 
 void
-CdsAdd(Cds *cds1, const Cds *cds2);
+MatMultCdsMultMatDiag(Cds *outcds, const double **matK, const Cds *cds);
 
 void
-RotMatAddIp(double **mat1, const double **mat2);
+MatDiagMultCdsMultMatDiag(Cds *outcds, const double *wtK, const Cds *cds);
 
 void
 CopyCds2PDB(PDBCds *pdbcds, const Cds *cds);
@@ -70,13 +61,16 @@ void
 TransformPDBCdsIp(PDBCds *pdbcds);
 
 void
-RotateCdsIp(Cds *cds, const double **U);
+RotateCdsIp(Cds *cds, const double **rmat);
+
+void
+RotateCdsIp2(double **c1, const int vlen, const double **rmat);
 
 void
 RotateCdsArrayIp(CdsArray *cdsA, const double **rmat);
 
 void
-RotateCdsOp(const Cds *cds1, const double **U, Cds *cds2);
+RotateCdsOp(double **c2, const double **c1, const double **rmat, const int vlen);
 
 void
 TransformCdsIp(Cds *cds);
@@ -84,27 +78,33 @@ TransformCdsIp(Cds *cds);
 void
 ScaleCds(Cds *cds, const double scale);
 
-double
-NormalizeWeights(double *w, int vlen);
-
-double
-NormalizeWeightsOcc(double *w, double *o, int vlen);
-
-void
-UnityWeightsCdsArray(CdsArray *cdsA);
-
 void
 CenMass(Cds *cds);
 
 void
 CenMassWtOp(Cds *cds, const CdsArray *weights);
 
+void
+CenMass2(const double **cds, const int vlen, double *center);
+
+void
+CenMassWt2(const double **cds, const double *wts, const int vlen, double *center);
+
 void
 CenMassWtIp(Cds *cds, const double *weights);
 
 void
 CenMassCovOp(Cds *cds, const CdsArray *weights);
 
+void
+CalcCovCds(Cds *cds, const double **wtmat);
+
+void
+CenMassCov(Cds *cds, const double **wtmat);
+
+void
+CenMassCov2(const double **c, double **cc, const double **wtmat, const int vlen, double *center);
+
 void
 CenMassCov(Cds *cds, const double **wtmat);
 
@@ -112,10 +112,13 @@ void
 CenMassWt(Cds *cds);
 
 void
-CenMassOccVec(Cds *cds, double *cenmass);
+CenMassNuVec(const double **c, const int *nu, double *cenmass, const int vlen);
 
 void
-CenMassWtIpOcc(Cds *cds, const double *wts);
+CenMassWtNu2(const double **cds, const double **ave, const int *nu, const double *wts, const int vlen, const double **rmat, double *center);
+
+void
+CenMassWtIpNu(Cds *cds, const double *wts);
 
 void
 CenMassWtIpEM(Cds *cds, const Cds *avecds, const double *wts);
@@ -133,10 +136,13 @@ void
 ApplyCenterOp(Cds *cds1, const Cds *cds2);
 
 void
-TransCdsIp(Cds *cds, const double *trans);
+TranslateCdsOp2(double **cds2, const double **cds1, const int vlen, const double *center);
 
 void
-NegTransCdsIp(Cds *cds, const double *trans);
+TransCdsIp(double **c, const double *trans, const int vlen);
+
+void
+NegTransCdsIp(double **c, const double *trans, const int vlen);
 
 void
 EM_MissingCds(CdsArray *cdsA);
@@ -155,15 +161,12 @@ void
 AveCdsTB(CdsArray *cdsA, int omit);
 
 void
-AveCdsOcc(CdsArray *cdsA);
+AveCdsNu(CdsArray *cdsA);
 
 void
-CalcCdsPrincAxes(Cds *cds, double **rotmat);
+CalcCdsPrincAxes(Cds *cds, double **r, double **u, double **vt, double *lambda, const double *wts);
 
 void
 SumCdsTB(CdsArray *cdsA, const int exclude);
 
-double
-*ConcatQuatsIp(const double *quat1, double *quat2);
-
 #endif
